#**********************************************************************
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (c) Copyright IBM Corp. 2003, 2011. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#**********************************************************************


package UserConfig;


@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();
use AudLog;

#-------------------------------------------------------------------------------

my $tmp_SubNetwork = "";
my $tmp_MeContext = "";

my @rules = (

# START : IMA_GROUP
# Unpegger for IMA_GROUP NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
		MAX_PEG_PIF_AGE            => 'DURATION*4+60',
        DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmGrFc$' => 4294967295,
         '^pmGrFcFe$' => 4294967295,
         '^pmGrUasIma$' => 4294967295,
        },
},

# Remove initial PIF after unpegger for IMA_GROUP NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_GROUP RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmGrFc$' => 4294967295,
         '^pmGrFcFe$' => 4294967295,
         '^pmGrUasIma$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_GROUP RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_GROUP RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_GROUP RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IMA_GROUP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_IMA_GROUP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmGrFc$' => 4294967295,
         '^pmGrFcFe$' => 4294967295,
         '^pmGrUasIma$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IMA_GROUP RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IMA_GROUP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IMA_GROUP

# START : IMA_LINK
# Unpegger for IMA_LINK NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIvIma$' => 2147483647,
         '^pmOifIma$' => 2147483647,
         '^pmRxFc$' => 2147483647,
         '^pmRxFcFe$' => 2147483647,
         '^pmRxStuffIma$' => 2147483647,
         '^pmRxUusIma$' => 2147483647,
         '^pmRxUusImaFe$' => 2147483647,
         '^pmSesIma$' => 2147483647,
         '^pmSesImaFe$' => 2147483647,
         '^pmTxFc$' => 2147483647,
         '^pmTxFcFe$' => 2147483647,
         '^pmTxStuffIma$' => 2147483647,
         '^pmTxUusIma$' => 2147483647,
         '^pmTxUusImaFe$' => 2147483647,
         '^pmUasIma$' => 2147483647,
         '^pmUasImaFe$' => 2147483647,
        },
},
# Remove initial PIF after unpegger for IMA_LINK NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IMA_LINK-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_LINK RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIvIma$' => 2147483647,
         '^pmOifIma$' => 2147483647,
         '^pmRxFc$' => 2147483647,
         '^pmRxFcFe$' => 2147483647,
         '^pmRxStuffIma$' => 2147483647,
         '^pmRxUusIma$' => 2147483647,
         '^pmRxUusImaFe$' => 2147483647,
         '^pmSesIma$' => 2147483647,
         '^pmSesImaFe$' => 2147483647,
         '^pmTxFc$' => 2147483647,
         '^pmTxFcFe$' => 2147483647,
         '^pmTxStuffIma$' => 2147483647,
         '^pmTxUusIma$' => 2147483647,
         '^pmTxUusImaFe$' => 2147483647,
         '^pmUasIma$' => 2147483647,
         '^pmUasImaFe$' => 2147483647,
        },
},
# Remove initial PIF after unpegger for IMA_LINK RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IMA_LINK-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IMA_LINK RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IMA_LINK RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IMA_LINK-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_IMA_LINK-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_ImaGroup','moid_ImaLink' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIvIma$' => 2147483647,
         '^pmOifIma$' => 2147483647,
         '^pmRxFc$' => 2147483647,
         '^pmRxFcFe$' => 2147483647,
         '^pmRxStuffIma$' => 2147483647,
         '^pmRxUusIma$' => 2147483647,
         '^pmRxUusImaFe$' => 2147483647,
         '^pmSesIma$' => 2147483647,
         '^pmSesImaFe$' => 2147483647,
         '^pmTxFc$' => 2147483647,
         '^pmTxFcFe$' => 2147483647,
         '^pmTxStuffIma$' => 2147483647,
         '^pmTxUusIma$' => 2147483647,
         '^pmTxUusImaFe$' => 2147483647,
         '^pmUasIma$' => 2147483647,
         '^pmUasImaFe$' => 2147483647,
        },
},
# Remove initial PIF after unpegger for IMA_LINK RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_LINK RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IMA_LINK-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IMA_LINK

# START : ME_TN_Mtp3bSpItu_Mtp3bAp
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bAp
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bAp Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bAp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfAdjacentSPNotAccessible$' => 4294967295,
         '^pmNoOfUserPartUnavailRec$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bAp
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bAp PIF files',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bAp-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bAp

# START : ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSlItu','moid_Mtp3bSls' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfMSURec$' => 4294967295,
         '^pmNoOfMSUSent$' => 4294967295,
         '^pmNoOfAALINServiceInd$' => 4294967295,
         '^pmNoOfAALOUTInd$' => 4294967295,
         '^pmNoOfCBDSent$' => 4294967295,
         '^pmNoOfCOOXCOSent$' => 4294967295,
         '^pmNoOfLocalLinkCongestCeaseRec$' => 4294967295,
         '^pmNoOfLocalLinkCongestRec$' => 4294967295, 
		 '^pmNoOfSentUserData$' => 4294967295, # P7.1
		 '^pmNoOfRecUserData$' => 4294967295, # P7.1
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu PIF files',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu

# START : RNC_Mtp3bSpItu_Signaling
# Unpegger for RNC_Mtp3bSpItu_Signaling
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Mtp3bSpItu_Signaling Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Mtp3bSpItu_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Mtp3bSpItu_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfECARec$' => 4294967295,
         '^pmNoOfECASent$' => 4294967295,
         '^pmNoOfECOSent$' => 4294967295,
         '^pmNoOfEmergencyChangeOverRec$' => 4294967295,
         '^pmNoOfLowerPrioMsgDiscarded$' => 4294967295,
         '^pmNoOfForcedRerouteSuccessPerf$' => 4294967295,
         '^pmNoOfCBARec$' => 4294967295,
         '^pmNoOfCBASent$' => 4294967295,
         '^pmNoOfChangeBackDeclRec$' => 4294967295,
         '^pmNoOfChangeOverRec$' => 4294967295,
         '^pmNoOfCOAXCARec$' => 4294967295,
         '^pmNoOfCOAXCASent$' => 4294967295,
         '^pmNoOfControlledRerouteSuccessPerf$' => 4294967295,
         '^pmNoOfInAssEstReqStDownStEstBl$' => 4294967295,
         '^pmNoOfMaxTrialsForAssocActivReached$' => 4294967295,
         '^pmNoOfMaxTrialsForAssocEstabReached$' => 4294967295,
         '^pmNoOfSctpAssociationRestart$' => 4294967295,
         '^pmNoOfSctpBufOverflow$' => 4294967295,
         '^pmNoOfSctpCommunicationErr$' => 4294967295,
         '^pmNoOfSctpNetworkStatusChange$' => 4294967295,
         '^pmNoOfSctpResumeSending$' => 4294967295,
         '^pmNoOfSctpSendFailure$' => 4294967295,
         '^pmNoOfSLTAFirstTimeOutRec$' => 4294967295,
         '^pmNoOfSLTASecondTimeOutRec$' => 4294967295,
         '^pmNoOfSuccessAssocAbort$' => 4294967295,
         '^pmNoOfSuccessAssocEstablish$' => 4294967295,
         '^pmNoOfSuccessAssocShutDown$' => 4294967295,
         '^pmNoOfTimerT21WasStarted$' => 4294967295,
         '^pmNoOfTRARec$' => 4294967295,
         '^pmNoOfTRASent$' => 4294967295,
         '^pmNoOfUnsuccessAssocAbort$' => 4294967295,
         '^pmNoOfUnsuccessAssocEstablish$' => 4294967295,
         '^pmNoOfUnsuccessAssocShutDown$' => 4294967295,
         '^pmNoOfUnsuccessControlledRerouting$' => 4294967295,
         '^pmNoOfUnsuccessForcedRerouting$' => 4294967295,
         '^pmNoOfUPMsgDiscardedDueToRoutingErr$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Mtp3bSpItu_Signaling
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Mtp3bSpItu_Signaling PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Mtp3bSpItu_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Mtp3bSpItu_Signaling

# START : ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSrs', 'moid_Mtp3bSr' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfSecondsAccumulatedRouteUnavailable$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr PIF files',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr

# START : ME_TN_Mtp3bSpItu_Mtp3bSrs
# Unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_Mtp3bSrs Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu','moid_Mtp3bSrs' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDiscardedMsgFromBroadToNarrow$' => 4294967295,
         '^pmNoOfTransferAllowedRec$' => 4294967295,
         '^pmNoOfTransferControlledRec$' => 4294967295,
         '^pmNoOfTransferProhibitedRec$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_Mtp3bSrs
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs PIF files',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_Mtp3bSrs-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_Mtp3bSrs

# START : RNC_Signaling_Connection_Control
# Unpegger for RNC_Signaling_Connection_Control
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Signaling_Connection_Control-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp','moid_SccpScrc' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfConnectFailure$' => 4294967295,
         '^pmNoOfRoutingFailSubsysUnavail$' => 4294967295,
         '^pmNoOfRoutingFailure$' => 4294967295,
         '^pmNoOfHopCounterViolation$' => 4294967295,
         '^pmNoOfRoutingFailNetworkCongest$' => 4294967295,
         '^pmNoOfRoutingFailNoTransAddrOfSuchNature$' => 4294967295,
         '^pmNoOfRoutingFailNoTransSpecificAddr$' => 4294967295,
         '^pmNoOfRoutingFailReasonUnknown$' => 4294967295,
         '^pmNoOfRoutingFailUnequippedSubsys$' => 4294967295,
         '^pmNoOfRoutingFailurePointCodeUnAvail$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_Mtp3bSrs PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control

# START : RNC_Signaling_Connection_Control_SccpSp
# Unpegger for RNC_Signaling_Connection_Control_SccpSp
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control_SccpSp Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfLUDTRec$' => 4294967295,
         '^pmNoOfLUDTSSent$' => 4294967295,
         '^pmNoOfConInUseExceedHighWaterMark$' => 4294967295,
         '^pmNoOfConInUseReceededLowWaterMark$' => 4294967295,
         '^pmNoOfCREFRecFromNL$' => 4294967295,
         '^pmNoOfCREFSentToNL$' => 4294967295,
         '^pmNoOfCRRec$' => 4294967295,
         '^pmNoOfCRSent$' => 4294967295,
         '^pmNoOfDT1Rec$' => 4294967295,
         '^pmNoOfDT1Sent$' => 4294967295,
         '^pmNoOfERRRec$' => 4294967295,
         '^pmNoOfERRSent$' => 4294967295,
         '^pmNoOfRLSDRecFromNL$' => 4294967295,
         '^pmNoOfRLSDSentToNL$' => 4294967295,
         '^pmNoOfSubsysAllowedSent$' => 4294967295,
         '^pmNoOfUDTRec$' => 4294967295,
         '^pmNoOfUDTSent$' => 4294967295,
         '^pmNoOfUDTSRec$' => 4294967295,
         '^pmNoOfUDTSSent$' => 4294967295,
         '^pmNoOfXUDTRec$' => 4294967295,
         '^pmNoOfXUDTSent$' => 4294967295,
         '^pmNoOfXUDTSRec$' => 4294967295,
         '^pmNoOfXUDTSSent$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control_SccpSp
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Control_SccpSp PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control_SccpSp-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control_SccpSp

# START : SCTP
# Unpegger for SCTP NODEB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg SCTP NODEB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_SCTP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_SCTP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Sctp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmSctpAborted$' => 4294967295,
         '^pmSctpActiveEstab$' => 4294967295,
         '^pmSctpCurrEstab$' => 4294967295,
         '^pmSctpPassiveEstab$' => 4294967295,
         '^pmSctpShutdowns$' => 4294967295,
         '^pmSctpStatAssocOutOfBlue$' => 4294967295,
         '^pmSctpStatChecksumErrorCounter$' => 4294967295,
         '^pmSctpStatCommResume$' => 4294967295,
         '^pmSctpStatCommStop$' => 4294967295,
         '^pmSctpStatFragmentedUserMsg$' => 4294967295,
         '^pmSctpStatOutOfOrderRecChunks$' => 4294967295,
         '^pmSctpStatOutOfOrderSendChunks$' => 4294967295,
         '^pmSctpStatReassembledUserMsg$' => 4294967295,
         '^pmSctpStatRecChunks$' => 4294967295,
         '^pmSctpStatRecChunksDropped$' => 4294967295,
         '^pmSctpStatReceivedControlChunks$' => 4294967295,
         '^pmSctpStatReceivedPackages$' => 4294967295,
         '^pmSctpStatRetransChunks$' => 4294967295,
         '^pmSctpStatSentChunks$' => 4294967295,
         '^pmSctpStatSentChunksDropped$' => 4294967295,
         '^pmSctpStatSentControlChunks$' => 4294967295,
         '^pmSctpStatSentPackages$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for SCTP NODEB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial SCTP NODEB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_SCTP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for SCTP RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg SCTP RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_SCTP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_SCTP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Sctp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmSctpAborted$' => 4294967295,
         '^pmSctpActiveEstab$' => 4294967295,
         '^pmSctpCurrEstab$' => 4294967295,
         '^pmSctpPassiveEstab$' => 4294967295,
         '^pmSctpShutdowns$' => 4294967295,
         '^pmSctpStatAssocOutOfBlue$' => 4294967295,
         '^pmSctpStatChecksumErrorCounter$' => 4294967295,
         '^pmSctpStatCommResume$' => 4294967295,
         '^pmSctpStatCommStop$' => 4294967295,
         '^pmSctpStatFragmentedUserMsg$' => 4294967295,
         '^pmSctpStatOutOfOrderRecChunks$' => 4294967295,
         '^pmSctpStatOutOfOrderSendChunks$' => 4294967295,
         '^pmSctpStatReassembledUserMsg$' => 4294967295,
         '^pmSctpStatRecChunks$' => 4294967295,
         '^pmSctpStatRecChunksDropped$' => 4294967295,
         '^pmSctpStatReceivedControlChunks$' => 4294967295,
         '^pmSctpStatReceivedPackages$' => 4294967295,
         '^pmSctpStatRetransChunks$' => 4294967295,
         '^pmSctpStatSentChunks$' => 4294967295,
         '^pmSctpStatSentChunksDropped$' => 4294967295,
         '^pmSctpStatSentControlChunks$' => 4294967295,
         '^pmSctpStatSentPackages$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for SCTP RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial SCTP RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_SCTP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : SCTP

# START : ME_TN_Mtp3bSpItu_M3uAssociation
# Unpegger for ME_TN_Mtp3bSpItu_M3uAssociation
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_TN_Mtp3bSpItu_M3uAssociation Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp3bSpItu', 'moid_M3uAssociation' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfAspacAckReceived$' => 4294967295,
         '^pmNoOfAspacAckSent$' => 4294967295,
         '^pmNoOfAspacReceived$' => 4294967295,
         '^pmNoOfAspacSent$' => 4294967295,
         '^pmNoOfAspdnAckReceived$' => 4294967295,
         '^pmNoOfAspdnAckSent$' => 4294967295,
         '^pmNoOfAspdnReceived$' => 4294967295,
         '^pmNoOfAspdnSent$' => 4294967295,
         '^pmNoOfAspiaAckReceived$' => 4294967295,
         '^pmNoOfAspiaAckSent$' => 4294967295,
         '^pmNoOfAspiaReceived$' => 4294967295,
         '^pmNoOfAspiaSent$' => 4294967295,
         '^pmNoOfAspupAckReceived$' => 4294967295,
         '^pmNoOfAspupAckSent$' => 4294967295,
         '^pmNoOfAspupReceived$' => 4294967295,
         '^pmNoOfAspupSent$' => 4294967295,
         '^pmNoOfCommunicationLost$' => 4294967295,
         '^pmNoOfCongestions$' => 4294967295,
         '^pmNoOfDataMsgRec$' => 4294967295,
         '^pmNoOfDataMsgSent$' => 4294967295,
         '^pmNoOfDaudMsgRec$' => 4294967295,
         '^pmNoOfDaudMsgSent$' => 4294967295,
         '^pmNoOfDavaRec$' => 4294967295,
         '^pmNoOfDavaSent$' => 4294967295,
         '^pmNoOfDunaRec$' => 4294967295,
         '^pmNoOfDunaSent$' => 4294967295,
         '^pmNoOfDupuRec$' => 4294967295,
         '^pmNoOfDupuSent$' => 4294967295,
         '^pmNoOfErrorMsgRec$' => 4294967295,
         '^pmNoOfErrorMsgSent$' => 4294967295,
         '^pmNoOfM3uaDataMsgDiscarded$' => 4294967295,
         '^pmNoOfNotifyMsgRec$' => 4294967295,
         '^pmNoOfSconRec$' => 4294967295,
		 '^pmNoOfSentUserData$' => 4294967295, # P7.1
		 '^pmNoOfRecUserData$' => 4294967295,  #P7.1
        },
},
# Remove initial PIF after unpegger for ME_TN_Mtp3bSpItu_M3uAssociation
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_TN_Mtp3bSpItu_M3uAssociation PIF files',
        INPUT_FILE_DESCRIPTION     => '^(ME_TN_Mtp3bSpItu_M3uAssociation-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ME_TN_Mtp3bSpItu_M3uAssociation

# START : RNC_Signaling_Connection_Ctrl_Acc_Criteria
# Unpegger for RNC_Signaling_Connection_Ctrl_Acc_Criteria
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Ctrl_Acc_Criteria Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp', 'moid_SccpScrc','SccpAccountingCriteria' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfMsg$' => 4294967295,
         '^pmNoOfOctets$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Ctrl_Acc_Criteria
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Ctrl_Acc_Criteria PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Ctrl_Acc_Criteria-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Ctrl_Acc_Criteria

# START : RNC_Signaling_Connection_Control_Policing
# Unpegger for RNC_Signaling_Connection_Control_Policing
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_Signaling_Connection_Control_Policing Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control_Policing-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Signaling_Connection_Control_Policing-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_SccpSp', 'moid_SccpScrc','SccpPolicing' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfRejectMsg$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_Signaling_Connection_Control_Policing
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_Signaling_Connection_Control_Policing PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Signaling_Connection_Control_Policing-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_Signaling_Connection_Control_Policing

# START : ME_RNC_Eqpt_FastEthernet
# Unpegger for ME_RNC_Eqpt_FastEthernet
{
    RULE_TYPE                  => 'PERLIZE',
    RULE_DESC                  => 'Calculate Tot_pmIfInOctets & Tot_pmIfOutOctets for ME_RNC_Eqpt_FastEthernet',
    INPUT_FILE_DESCRIPTION     => '^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
    DATA_COUNTERS_OP           => sub
    {
        my $c_ref = shift;
	my $power31 = 2 ** 31;
        $c_ref->{Tot_pmIfInOctets} = "";
        $c_ref->{Tot_pmIfOutOctets} = "";
	if ($c_ref->{pmIfInOctetsHi} =~ /^\d+$/ || $c_ref->{pmIfInOctetsLo} =~ /^\d+$/) {
            $c_ref->{Tot_pmIfInOctets} = ( $power31 * $c_ref->{pmIfInOctetsHi} ) + $c_ref->{pmIfInOctetsLo};
	}
	if ($c_ref->{pmIfOutOctetsHi} =~ /^\d+$/ || $c_ref->{pmIfOutOctetsLo} =~ /^\d+$/) {
            $c_ref->{Tot_pmIfOutOctets } = ( $power31 * $c_ref->{pmIfOutOctetsHi} ) + $c_ref->{pmIfOutOctetsLo};
        }
        return 0;
    },
    FILENAME_SUFFIX            => 'PZ',
    PRODUCE_PIF                => 'True',
},

{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ME_RNC_Eqpt_FastEthernet Counters',
        INPUT_FILE_DESCRIPTION     => '^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I-#-PZ\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^ME_RNC_Eqpt_FastEthernet-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I-#-PZ\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack', 'moid_Slot','moid_PlugInUnit','moid_GeneralProcessingUnit','moid_FastEthernet' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIfInBroadcastPkts$' => 4294967295,
         '^pmIfInDiscards$' => 4294967295,
         '^pmIfInErrors$' => 4294967295,
         '^pmIfInMulticastPkts$' => 4294967295,
         #'pmIfInOctetsHi' => 2147483647,
         #'pmIfInOctetsLo' => 2147483647,
         '^Tot_pmIfInOctets$' => 4611686018427387904,
         '^pmIfInUcastPkts$' => 4294967295,
         '^pmIfInUnknownProtos$' => 4294967295,
         '^pmIfOutBroadcastPkts$' => 4294967295,
         '^pmIfOutDiscards$' => 4294967295,
         '^pmIfOutErrors$' => 4294967295,
         '^pmIfOutMulticastPkts$' => 4294967295,
         #'pmIfOutOctetsHi' => 2147483647,
         #'pmIfOutOctetsLo' => 2147483647,
         '^Tot_pmIfOutOctets$' => 4611686018427387904,
         '^pmIfOutUcastPkts$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ME_RNC_Eqpt_FastEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ME_RNC_Eqpt_FastEthernet PIF files',
        INPUT_FILE_DESCRIPTION     => ['^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
                                       '^(ME_RNC_Eqpt_FastEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I-#-PZ\.pif$',],
},
# END : ME_RNC_Eqpt_FastEthernet

# START : ME_RNC_Eqpt_GigaBitEthernet - For handing P6 data
# Bug 59076: Join all ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet PIFs prior to unpegging
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join all ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet PIFs prior to unpegging',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-(.+-#-.+-#-\d{14}\w)-#-.+-#-I\.pif$'],
        COUNTERS_TO_JOIN_ON    => [ qw( moid_ManagedElement moid_Equipment moid_Subrack moid_Slot moid_PlugInUnit moid_EtMfg moid_GigaBitEthernet mts ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet',
        OUTPUT_FILENAME_START  => 'ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork','nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
        OUTPUT_FORMAT          => 'LIF_Writer',
},

# P7.1 Remark for nolonger need of Unpegger
# Unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet
#{
#        RULE_TYPE                  => 'UNPEGGER',
#        RULE_DESC                  => 'Unpeg ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet Counters',
#        INPUT_FILE_DESCRIPTION     => '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-J\.pif$',
#        INPUT_FILE_DATETIME_KEY    => '^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-J\.pif$',
#        INPUT_DATE_FORMAT          => 'YMD',
#        PEG_FILENAME_PREFIX        => 'SAVED',
#        UNPEG_FILENAME_PREFIX      => 'UNPEG',
#        CALCULATE_ROLLOVER         => 'True',
#        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack', 'moid_Slot','moid_PlugInUnit','moid_EtMfg','moid_GigaBitEthernet' ],
#        DEFAULT_NULL_VALUE         => '',
#        UNPEG_FILE_TYPE            => 'HEADER',
#        PRODUCE_PIF                => 'True',
#        OUTPUT_FORMAT              => 0,
#        KEEP_RAW_GRANULARITY       => 0,
#        MAX_PEG_PIF_AGE            => '3600',
#        DATETIME_COUNTERS          => {
#             STARTDATE => 'StartDate',
#             STARTTIME => 'StartTime',
#             DURATION  => 'gp',
#             FORMAT    => 'seconds',
#        },
#        PEG_COUNTERS => {
#         'pmDot1qTpVlanPortInDiscardsLink1' => 4294967295,
#         'pmDot1qTpVlanPortInDiscardsLink2' => 4294967295,
#         'pmIfInBroadcastPktsLink1' => 4294967295,
#         'pmIfInBroadcastPktsLink2' => 4294967295,
#         'pmIfInDiscardsLink1' => 4294967295,
#         'pmIfInDiscardsLink2' => 4294967295,
#         'pmIfInErrorsLink1' => 4294967295,
#         'pmIfInErrorsLink2' => 4294967295,
#         'pmIfInMulticastPktsLink1' => 4294967295,
#         'pmIfInMulticastPktsLink2' => 4294967295,
#         'pmIfInOctetsLink1Hi' => 4294967295,
#         'pmIfInOctetsLink1Lo' => 4294967295,
#         'pmIfInOctetsLink2Hi' => 4294967295,
#         'pmIfInOctetsLink2Lo' => 4294967295,
#         'pmIfInUcastPktsLink1' => 4294967295,
#         'pmIfInUcastPktsLink2' => 4294967295,
#         'pmIfInUnknownProtosLink1' => 4294967295,
#         'pmIfInUnknownProtosLink2' => 4294967295,
#         'pmIfOutBroadcastPktsLink1' => 4294967295,
#         'pmIfOutBroadcastPktsLink2' => 4294967295,
#         'pmIfOutDiscardsLink1' => 4294967295,
#         'pmIfOutDiscardsLink2' => 4294967295,
#         'pmIfOutErrorsLink1' => 4294967295,
#         'pmIfOutErrorsLink2' => 4294967295,
#         'pmIfOutMulticastPktsLink1' => 4294967295,
#         'pmIfOutMulticastPktsLink2' => 4294967295,
#         'pmIfOutOctetsLink1Hi' => 4294967295,
#         'pmIfOutOctetsLink1Lo' => 4294967295,
#         'pmIfOutOctetsLink2Hi' => 4294967295,
#         'pmIfOutOctetsLink2Lo' => 4294967295,
#         'pmIfOutUcastPktsLink1' => 4294967295,
#         'pmIfOutUcastPktsLink2' => 4294967295,
#        },
#},
# Rename Block to ME_RNC_Eqpt_GigaBitEthernet
{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Rename Block to ME_RNC_Eqpt_GigaBitEthernet',
		INPUT_FILE_DESCRIPTION     => '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#)-\d{14}\w-#-.+-#-J\.pif$',
		# INPUT_FILE_DESCRIPTION  => '^UNPEG-#-ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#-\d{14}\w-#-.+-#-J\.pif$',
        OUTPUT_BLOCK_NAME       => 'ME_RNC_Eqpt_GigaBitEthernet',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
},
# Remove initial PIF after unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            '^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#-\d{14}\w-#-.+-#-J\.pif$'
            #'^UNPEG-#-ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-.+-#-.+-#-\d{14}\w-#-.+-#-J\.pif$'
        ]
},
# END : ME_RNC_Eqpt_GigaBitEthernet - For handling P6 data

# START : ME_RNC_Eqpt_GigaBitEthernet - For handing P7 data
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join all ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet PIFs prior to unpegging',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet-#-(.+-#-.+-#-\d{14}\w)-#-.+-#-I\.pif$'],
        COUNTERS_TO_JOIN_ON    => [ qw( moid_ManagedElement moid_Equipment moid_Subrack moid_Slot moid_PlugInUnit moid_ExchangeTerminalIp moid_GigaBitEthernet mts ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet',
        OUTPUT_FILENAME_START  => 'ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork','nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
},
# Rename Block to ME_RNC_Eqpt_GigaBitEthernet
{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Rename Block to ME_RNC_Eqpt_GigaBitEthernet',
        INPUT_FILE_DESCRIPTION  => '^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet-#-.+-#-.+-#-\d{14}\w-#-.+-#-J\.pif$',
        OUTPUT_BLOCK_NAME       => 'ME_RNC_Eqpt_GigaBitEthernet',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
},
# Remove initial PIF after unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
        ]
},
# END : ME_RNC_Eqpt_GigaBitEthernet - For handling P7 data

# START : RNC_IP_Access_Spb
# Unpegger for RNC_IP_Access_Spb
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg RNC_IP_Access_Spb Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IP_Access_Spb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IP_Access_Spb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostSpb' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIcmpInDestUnreachs$' => 4294967295,
         '^pmIcmpInEchoReps$' => 4294967295,
         '^pmIcmpInEchos$' => 4294967295,
         '^pmIcmpInErrors$' => 4294967295,
         '^pmIcmpInMsgs$' => 4294967295,
         '^pmIcmpInParamProbs$' => 4294967295,
         '^pmIcmpInRedirects$' => 4294967295,
         '^pmIcmpInSrcQuenchs$' => 4294967295,
         '^pmIcmpInTimeExcds$' => 4294967295,
         '^pmIcmpOutDestUnreachs$' => 4294967295,
         '^pmIcmpOutEchoReps$' => 4294967295,
         '^pmIcmpOutEchos$' => 4294967295,
         '^pmIcmpOutErrors$' => 4294967295,
         '^pmIcmpOutMsgs$' => 4294967295,
         '^pmIcmpOutParmProbs$' => 4294967295,
         '^pmIpFragCreates$' => 4294967295,
         '^pmIpFragFails$' => 4294967295,
         '^pmIpFragOKs$' => 4294967295,
         '^pmIpInAddrErrors$' => 4294967295,
         '^pmIpInDelivers$' => 4294967295,
         '^pmIpInDiscards$' => 4294967295,
         '^pmIpInHdrErrors$' => 4294967295,
         '^pmIpInReceives$' => 4294967295,
         '^pmIpInUnknownProtos$' => 4294967295,
         '^pmIpOutDiscards$' => 4294967295,
         '^pmIpOutRequests$' => 4294967295,
         '^pmIpReasmFails$' => 4294967295,
         '^pmIpReasmOKs$' => 4294967295,
         '^pmIpReasmReqds$' => 4294967295,
         '^pmUdpInDatagrams$' => 4294967295,
         '^pmUdpInErrors$' => 4294967295,
         '^pmUdpNoPorts$' => 4294967295,
         '^pmUdpOutDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for RNC_IP_Access_Spb
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial RNC_IP_Access_Spb PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IP_Access_Spb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_IP_Access_Spb

# P7.1 Remove Unpegger
# START : PlugInUnit_EtMfg_GigaBitEther_IpIntf - For handling P6 Data
# Unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface
#{
#        RULE_TYPE                  => 'UNPEGGER',
#        RULE_DESC                  => 'Unpeg ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface Counters',
#        INPUT_FILE_DESCRIPTION     => '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
#        INPUT_FILE_DATETIME_KEY    => '^ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
#        INPUT_DATE_FORMAT          => 'YMD',
#        PEG_FILENAME_PREFIX        => 'SAVED',
#        UNPEG_FILENAME_PREFIX      => 'UNPEG',
#        CALCULATE_ROLLOVER         => 'True',
#        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_EtMfg','moid_GigaBitEthernet','moid_IpInterface' ],
#        DEFAULT_NULL_VALUE         => '',
#        UNPEG_FILE_TYPE            => 'HEADER',
#        PRODUCE_PIF                => 'True',
#        OUTPUT_FORMAT              => 0,
#        KEEP_RAW_GRANULARITY       => 0,
#        MAX_PEG_PIF_AGE            => '3600',
#        DATETIME_COUNTERS          => {
#             STARTDATE => 'StartDate',
#             STARTTIME => 'StartTime',
#             DURATION  => 'gp',
#             FORMAT    => 'seconds',
#        },
#        PEG_COUNTERS => {
#         'pmDot1qTpVlanPortInFrames' => 4294967295,
#         'pmDot1qTpVlanPortOutFrames' => 4294967295,
#         'pmIfStatsIpAddrErrors' => 4294967295,
#         'pmIfStatsIpInDiscards' => 4294967295,
#         'pmIfStatsIpInHdrErrors' => 4294967295,
#         'pmIfStatsIpInReceives' => 4294967295,
#         'pmIfStatsIpOutDiscards' => 4294967295,
#         'pmIfStatsIpOutRequests' => 4294967295,
#         'pmIfStatsIpUnknownProtos' => 4294967295,
#        },
#},

# Rename Block to PlugInUnit_EtMfg_GigaBitEther_IpIntf
{
        RULE_TYPE               => 'PIF_2_OUTPUT',
        RULE_DESC               => 'Rename Block to PlugInUnit_EtMfg_GigaBitEther_IpIntf',
        #INPUT_FILE_DESCRIPTION  => '^UNPEG-#-ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+-#-\d{14}\w-#-.+-#-I\.pif$',
		INPUT_FILE_DESCRIPTION => '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        OUTPUT_BLOCK_NAME       => 'PlugInUnit_EtMfg_GigaBitEther_IpIntf',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
},
# Remove initial PIF after unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            #'^UNPEG-#-ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-.+-#-.+-#-\d{14}\w-#-.+-#-I\.pif$'
        ]
},
# END : PlugInUnit_EtMfg_GigaBitEther_IpIntf - For handling P6 data

# Remove initial PIF after unpegger for ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet_IpInterface
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet_IpInterface PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminalIp_GigaBitEthernet_IpInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$'
        ]
},
# END : PlugInUnit_EtMfg_GigaBitEther_IpIntf - For handling P7 data

# START : IP_Link
# Unpegger for IP_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfHdrErrors$' => 4294967295,
         '^pmNoOfIpAddrErrors$' => 4294967295,
         '^pmNoOfIpInDiscards$' => 4294967295,
         '^pmNoOfIpInReceives$' => 4294967295,
         '^pmNoOfIpOutDiscards$' => 4294967295,
         '^pmNoOfIpReasmOKs$' => 4294967295,
         '^pmNoOfIpReasmReqds$' => 4294967295,
         '^pmNoOfIpForwDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfHdrErrors$' => 4294967295,
         '^pmNoOfIpAddrErrors$' => 4294967295,
         '^pmNoOfIpInDiscards$' => 4294967295,
         '^pmNoOfIpInReceives$' => 4294967295,
         '^pmNoOfIpOutDiscards$' => 4294967295,
         '^pmNoOfIpReasmOKs$' => 4294967295,
         '^pmNoOfIpReasmReqds$' => 4294967295,
         '^pmNoOfIpForwDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_Link RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IP_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_IP_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ip' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfHdrErrors$' => 4294967295,
         '^pmNoOfIpAddrErrors$' => 4294967295,
         '^pmNoOfIpInDiscards$' => 4294967295,
         '^pmNoOfIpInReceives$' => 4294967295,
         '^pmNoOfIpOutDiscards$' => 4294967295,
         '^pmNoOfIpReasmOKs$' => 4294967295,
         '^pmNoOfIpReasmReqds$' => 4294967295,
         '^pmNoOfIpForwDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_Link RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IMA_GROUP RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IP_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IP_Link

# START : Ospf
# Unpegger for Ospf NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfOriginateNewLsas$' => 4294967295,
         '^pmNoOfOspfRxNewLsas$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ospf NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfOriginateNewLsas$' => 4294967295,
         '^pmNoOfOspfRxNewLsas$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_Link RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Ospf RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ospf RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Ospf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_Ospf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_Ospf' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfOriginateNewLsas$' => 4294967295,
         '^pmNoOfOspfRxNewLsas$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ospf RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ospf RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Ospf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Ospf

# START : OspfArea
# Unpegger for OspfArea NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfSpfRuns$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IP_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfSpfRuns$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfArea RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfArea RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_OspfArea-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_OspfArea-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfArea' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfSpfRuns$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfArea RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfArea RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : OspfArea

# START : OspfInterface
# Unpegger for OspfInterface NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfIfEvents$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_OspfInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfInterface RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfIfEvents$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_OspfArea-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for OspfInterface RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg OspfInterface RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_OspfInterface-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_OspfInterface-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_OspfInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfOspfIfEvents$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for OspfInterface RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial OspfInterface RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_OspfInterface-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : OspfInterface

# START : IpSystem_IpAccessHostGpb
# Unpegger for IpSystem_IpAccessHostGpb NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessHostGpb NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostGpb' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIcmpInDestUnreachs$' => 4294967295,
         '^pmIcmpInEchoReps$' => 4294967295,
         '^pmIcmpInEchos$' => 4294967295,
         '^pmIcmpInErrors$' => 4294967295,
         '^pmIcmpInMsgs$' => 4294967295,
         '^pmIcmpInParamProbs$' => 4294967295,
         '^pmIcmpInRedirects$' => 4294967295,
         '^pmIcmpInSrcQuenchs$' => 4294967295,
         '^pmIcmpInTimeExcds$' => 4294967295,
         '^pmIcmpOutDestUnreachs$' => 4294967295,
         '^pmIcmpOutEchoReps$' => 4294967295,
         '^pmIcmpOutEchos$' => 4294967295,
         '^pmIcmpOutErrors$' => 4294967295,
         '^pmIcmpOutMsgs$' => 4294967295,
         '^pmIcmpOutParmProbs$' => 4294967295,
         '^pmIpFragCreates$' => 4294967295,
         '^pmIpFragFails$' => 4294967295,
         '^pmIpFragOKs$' => 4294967295,
         '^pmIpInAddrErrors$' => 4294967295,
         '^pmIpInDelivers$' => 4294967295,
         '^pmIpInDiscards$' => 4294967295,
         '^pmIpInHdrErrors$' => 4294967295,
         '^pmIpInReceives$' => 4294967295,
         '^pmIpInUnknownProtos$' => 4294967295,
         '^pmIpOutDiscards$' => 4294967295,
         '^pmIpOutRequests$' => 4294967295,
         '^pmIpReasmFails$' => 4294967295,
         '^pmIpReasmOKs$' => 4294967295,
         '^pmIpReasmReqds$' => 4294967295,
         '^pmUdpInDatagrams$' => 4294967295,
         '^pmUdpInErrors$' => 4294967295,
         '^pmUdpNoPorts$' => 4294967295,
         '^pmUdpOutDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessHostGpb NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessHostGpb NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IpSystem_IpAccessHostGpb RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessHostGpb RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_IpAccessHostGpb' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIcmpInDestUnreachs$' => 4294967295,
         '^pmIcmpInEchoReps$' => 4294967295,
         '^pmIcmpInEchos$' => 4294967295,
         '^pmIcmpInErrors$' => 4294967295,
         '^pmIcmpInMsgs$' => 4294967295,
         '^pmIcmpInParamProbs$' => 4294967295,
         '^pmIcmpInRedirects$' => 4294967295,
         '^pmIcmpInSrcQuenchs$' => 4294967295,
         '^pmIcmpInTimeExcds$' => 4294967295,
         '^pmIcmpOutDestUnreachs$' => 4294967295,
         '^pmIcmpOutEchoReps$' => 4294967295,
         '^pmIcmpOutEchos$' => 4294967295,
         '^pmIcmpOutErrors$' => 4294967295,
         '^pmIcmpOutMsgs$' => 4294967295,
         '^pmIcmpOutParmProbs$' => 4294967295,
         '^pmIpFragCreates$' => 4294967295,
         '^pmIpFragFails$' => 4294967295,
         '^pmIpFragOKs$' => 4294967295,
         '^pmIpInAddrErrors$' => 4294967295,
         '^pmIpInDelivers$' => 4294967295,
         '^pmIpInDiscards$' => 4294967295,
         '^pmIpInHdrErrors$' => 4294967295,
         '^pmIpInReceives$' => 4294967295,
         '^pmIpInUnknownProtos$' => 4294967295,
         '^pmIpOutDiscards$' => 4294967295,
         '^pmIpOutRequests$' => 4294967295,
         '^pmIpReasmFails$' => 4294967295,
         '^pmIpReasmOKs$' => 4294967295,
         '^pmIpReasmReqds$' => 4294967295,
         '^pmUdpInDatagrams$' => 4294967295,
         '^pmUdpInErrors$' => 4294967295,
         '^pmUdpNoPorts$' => 4294967295,
         '^pmUdpOutDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessHostGpb RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessHostGpb RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IpSystem_IpAccessHostGpb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IpSystem_IpAccessHostGpb

# START : IpSystem_IpAccessUdpHostMsb
# Unpegger for IpSystem_IpAccessUdpHostMsb NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessUdpHostMsb NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_UdpHostMainMsb', 'moid_IpAccessUdpHostMsb' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIcmpInDestUnreachs$' => 4294967295,
         '^pmIcmpInErrors$' => 4294967295,
         '^pmIcmpInMsgs$' => 4294967295,
         '^pmIcmpOutDestUnreachs$' => 4294967295,
         '^pmIcmpOutMsgs$' => 4294967295,
         '^pmIpInAddrErrors$' => 4294967295,
         '^pmIpInDelivers$' => 4294967295,
         '^pmIpInDiscards$' => 4294967295,
         '^pmIpInHdrErrors$' => 4294967295,
         '^pmIpInReceives$' => 4294967295,
         '^pmIpInUnknownProtos$' => 4294967295,
         '^pmIpOutDiscards$' => 4294967295,
         '^pmIpOutRequests$' => 4294967295,
         '^pmUdpInDatagrams$' => 4294967295,
         '^pmUdpInErrors$' => 4294967295,
         '^pmUdpNoPorts$' => 4294967295,
         '^pmUdpOutDatagrams$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessUdpHostMsb NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessUdpHostMsb NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for IpSystem_IpAccessUdpHostMsb RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IpSystem_IpAccessUdpHostMsb RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_IpSystem','moid_ManagedElement','moid_UdpHostMainMsb', 'moid_IpAccessUdpHostMsb' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmIcmpInDestUnreachs$' => 4294967295,
         '^pmIcmpInErrors$' => 4294967295,
         '^pmIcmpInMsgs$' => 4294967295,
         '^pmIcmpOutDestUnreachs$' => 4294967295,
         '^pmIcmpOutMsgs$' => 4294967295,
         '^pmIpInAddrErrors$' => 4294967295,
         '^pmIpInDelivers$' => 4294967295,
         '^pmIpInDiscards$' => 4294967295,
         '^pmIpInHdrErrors$' => 4294967295,
         '^pmIpInReceives$' => 4294967295,
         '^pmIpInUnknownProtos$' => 4294967295,
         '^pmIpOutDiscards$' => 4294967295,
         '^pmIpOutRequests$' => 4294967295,
         '^pmUdpInDatagrams$' => 4294967295,
         '^pmUdpInErrors$' => 4294967295,
         '^pmUdpNoPorts$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IpSystem_IpAccessUdpHostMsb RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IpSystem_IpAccessUdpHostMsb RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : IpSystem_IpAccessUdpHostMsb

# START : Mtp2tpItu
# Unpegger for Mtp2tpItu NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Mtp2tpItu NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Mtp2tpItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_Mtp2tpItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp2tpItu' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfMSUReceived$' => 4294967295,
         '^pmNoOfMSUTransmitted$' => 4294967295,
         '^pmNoOfNacks$' => 4294967295,
         '^pmNoOfReTransmittedOctets$' => 4294967295,
         '^pmNoOfSIOSIFReceived$' => 4294967295,
         '^pmNoOfSIOSIFTransmitted$' => 4294967295,
         '^pmNoOfSendBufferOctets$' => 4294967295,
         '^pmNoOfStartedRBCongestion$' => 4294967295,
         '^pmNoOfSuReceivedInError$' => 4294967295,
         '^pmRemoteSIBTime$' => 4294967295,
         '^pmLocalSIBTime$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Mtp2tpItu NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Mtp2tpItu NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Mtp2tpItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Mtp2tpItu RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Mtp2tpItu RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Mtp2tpItu-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Mtp2tpItu-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Mtp2tpItu' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfMSUReceived$' => 4294967295,
         '^pmNoOfMSUTransmitted$' => 4294967295,
         '^pmNoOfNacks$' => 4294967295,
         '^pmNoOfReTransmittedOctets$' => 4294967295,
         '^pmNoOfSIOSIFReceived$' => 4294967295,
         '^pmNoOfSIOSIFTransmitted$' => 4294967295,
         '^pmNoOfSendBufferOctets$' => 4294967295,
         '^pmNoOfStartedRBCongestion$' => 4294967295,
         '^pmNoOfSuReceivedInError$' => 4294967295,
         '^pmRemoteSIBTime$' => 4294967295,
         '^pmLocalSIBTime$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Mtp2tpItu RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Mtp2tpItu RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Mtp2tpItu-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Mtp2tpItu

# START : Processor_Load
# Unpegger for Processor_Load RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Processor_Load RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Processor_Load RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Processor_Load NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Processor_Load RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Processor_Load RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Processor_Load RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Processor_Load RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Processor_Load NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Processor_Load NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Processor_Load NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Processor_Load NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Processor_Load

# START : ATM_Port
# Unpegger for ATM_Port NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0, # P7.1 FP1
        OUTPUT_FORMAT              => 'LIF_Writer', # P7.1 FP1
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmTransmittedAtmCells$' => 4294967295,
         '^pmReceivedAtmCells$' => 4294967295,
         '^pmSecondsWithUnexp$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for ATM_Port RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmTransmittedAtmCells$' => 4294967295,
         '^pmReceivedAtmCells$' => 4294967295,
         '^pmSecondsWithUnexp$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for ATM_Port RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg ATM_Port RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_ATM_Physical_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_ATM_Physical_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0, # P7.1 FP1
        OUTPUT_FORMAT              => 'LIF_Writer', # P7.1 FP1
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmTransmittedAtmCells$' => 4294967295,
         '^pmReceivedAtmCells$' => 4294967295,
         '^pmSecondsWithUnexp$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for ATM_Port RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial ATM_Port RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_ATM_Physical_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : ATM_Port

# START : Ethernet_Link
# Unpegger for Ethernet_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip', 'moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         'pmNoOfIfOutDiscards'  => 4294967295,
         'pmNoOfIfInDiscards'  => 4294967295,
         'pmNoOfIfInErrors'  => 4294967295,
         'pmNoOfIfInNUcastPkts'  => 4294967295,
         'pmNoOfIfInUcastPkts'  => 4294967295,
         'pmNoOfIfOutNUcastPkts'  => 4294967295,
         'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Unpegger for Ethernet_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip','moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         'pmNoOfIfOutDiscards'  => 4294967295,
         'pmNoOfIfInDiscards'  => 4294967295,
         'pmNoOfIfInErrors'  => 4294967295,
         'pmNoOfIfInNUcastPkts'  => 4294967295,
         'pmNoOfIfInUcastPkts'  => 4294967295,
         'pmNoOfIfOutNUcastPkts'  => 4294967295,
         'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Unpegger for Ethernet_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Ethernet_Link RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Ethernet_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_Ethernet_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_EthernetLink','moid_IpSystem','moid_Ip','moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         'pmNoOfIfOutDiscards'  => 4294967295,
         'pmNoOfIfInDiscards'  => 4294967295,
         'pmNoOfIfInErrors'  => 4294967295,
         'pmNoOfIfInNUcastPkts'  => 4294967295,
         'pmNoOfIfInUcastPkts'  => 4294967295,
         'pmNoOfIfOutNUcastPkts'  => 4294967295,
         'pmNoOfIfOutUcastPkts'  => 4294967295,
        },
},
# Remove initial PIF after unpegger for Ethernet_Link NODEB, RNC & RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Ethernet_Link NODEB, RNC & RXI PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(NODEB_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            '^(RNC_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            '^(RXI_Ethernet_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
        ]
},
# END : Ethernet_Link

# START : IP_ATM_Link - For handing P6 data
# Unpegger for IP_ATM_Link NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem', 'moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfIfInDiscards$' => 4294967295,
         '^pmNoOfIfInErrors$' => 4294967295,
         '^pmNoOfIfInNUcastPkts$' => 4294967295,
         '^pmNoOfIfInUcastPkts$' => 4294967295,
         '^pmNoOfIfOutNUcastPkts$' => 4294967295,
         '^pmNoOfIfOutUcastPkts$' => 4294967295,
         '^pmNoOfIfOutDiscards$' => 4294967295,
        },
},
# Unpegger for IP_ATM_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem', 'moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfIfInDiscards$' => 4294967295,
         '^pmNoOfIfInErrors$' => 4294967295,
         '^pmNoOfIfInNUcastPkts$' => 4294967295,
         '^pmNoOfIfInUcastPkts$' => 4294967295,
         '^pmNoOfIfOutNUcastPkts$' => 4294967295,
         '^pmNoOfIfOutUcastPkts$' => 4294967295,
         '^pmNoOfIfOutDiscards$' => 4294967295,
        },
},
# Unpegger for IP_ATM_Link RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg IP_ATM_Link RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_IP_ATM_Link-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_IP_ATM_Link-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement','moid_IpAtmLink', 'moid_Ip' ,'moid_IpSystem', 'moid_IpOam' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfIfInDiscards$' => 4294967295,
         '^pmNoOfIfInErrors$' => 4294967295,
         '^pmNoOfIfInNUcastPkts$' => 4294967295,
         '^pmNoOfIfInUcastPkts$' => 4294967295,
         '^pmNoOfIfOutNUcastPkts$' => 4294967295,
         '^pmNoOfIfOutUcastPkts$' => 4294967295,
         '^pmNoOfIfOutDiscards$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for IP_ATM_Link NODBE, RNC & RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial IP_ATM_Link NODEB, RNC & RXI PIF files',
        INPUT_FILE_DESCRIPTION     => [
            '^(NODEB_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            '^(RNC_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
            '^(RXI_IP_ATM_Link-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
        ]
},
# END : IP_ATM_Link - For handing P6 data

# START : NniSAalTp_Signaling
# Unpegger for NniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for NniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for NniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg NniSAalTp_Signaling RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_NniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_NniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_NniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for NniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial NniSAalTp_Signaling RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_NniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : NniSAalTp_Signaling

# START : UniSAalTp_Signaling
# Unpegger for UniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
         '^FailNoOfSL$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for UniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
         '^FailNoOfSL$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for UniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg UniSAalTp_Signaling RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_UniSAalTp_Signaling-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_UniSAalTp_Signaling-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_TransportNetwork', 'moid_UniSaalTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmLinkInServiceTime$' => 4294967295,
         '^pmNoOfAlignmentFailures$' => 4294967295,
         '^pmNoOfLocalCongestions$' => 4294967295,
         '^pmNoOfNoResponses$' => 4294967295,
         '^pmNoOfOtherErrors$' => 4294967295,
         '^pmNoOfProtocolErrors$' => 4294967295,
         '^pmNoOfReceivedSDUs$' => 4294967295,
         '^pmNoOfRemoteCongestions$' => 4294967295,
         '^pmNoOfSentSDUs$' => 4294967295,
         '^pmNoOfSequenceDataLosses$' => 4294967295,
         '^pmNoOfUnsuccReTransmissions$' => 4294967295,
         '^FailNoOfSL$' => 4294967295,
         '^pmNoOfAllSLFailures$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for UniSAalTp_Signaling RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial UniSAalTp_Signaling RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_UniSAalTp_Signaling-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : UniSAalTp_Signaling

# Removed : Virtual_Channel_Link (VCL_TP) - P6
# Unpegger for Virtual_Channel_Link NodeB (RNC, RBS, RXI)
# Counters:
# pmReceivedAtmCells
# pmTransmittedAtmCells

# START : Virtual_Path_Connection
# Unpegger for Virtual_Path_Connection NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmBwErrBlocks$' => 4294967295,
         '^pmBwLostCells$' => 4294967295,
         '^pmBwMissinsCells$' => 4294967295,
         '^pmFwErrBlocks$' => 4294967295,
         '^pmFwLostCells$' => 4294967295,
         '^pmFwMissinsCells$' => 4294967295,
         '^pmLostBrCells$' => 4294967295,
         '^pmLostFpmCells$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Channel_Link RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmBwErrBlocks$' => 4294967295,
         '^pmBwLostCells$' => 4294967295,
         '^pmBwMissinsCells$' => 4294967295,
         '^pmFwErrBlocks$' => 4294967295,
         '^pmFwLostCells$' => 4294967295,
         '^pmFwMissinsCells$' => 4294967295,
         '^pmLostBrCells$' => 4294967295,
         '^pmLostFpmCells$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for Virtual_Path_Connection RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg Virtual_Path_Connection RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Virtual_Path_Connection-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_Virtual_Path_Connection-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_AtmPort','moid_VplTp','moid_VpcTp' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmBwErrBlocks$' => 4294967295,
         '^pmBwLostCells$' => 4294967295,
         '^pmBwMissinsCells$' => 4294967295,
         '^pmFwErrBlocks$' => 4294967295,
         '^pmFwLostCells$' => 4294967295,
         '^pmFwMissinsCells$' => 4294967295,
         '^pmLostBrCells$' => 4294967295,
         '^pmLostFpmCells$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for Virtual_Path_Connection RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial Virtual_Path_Connection RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_Virtual_Path_Connection-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : Virtual_Channel_Link

# Removed : Virtual_Path_Link (VPL_TP) - P6
# Unpegger for Virtual_Path_Link NodeB (RNC, RBC, RXI)
# Counters:
# pmReceivedAtmCells
# pmTransmittedAtmCells

# START : AAL2_SP
# Unpegger for AAL2_SP RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg AAL2_SP RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_AAL2_SP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_AAL2_SP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Aal2Sp'],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
             '^pmUnsuccessfulConnsInternal$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for AAL2_SP RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial AAL2_SP RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_AAL2_SP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for AAL2_SP NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg AAL2_SP NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_AAL2_SP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_AAL2_SP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Aal2Sp'],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
             '^pmUnsuccessfulConnsInternal$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for AAL2_SP NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial AAL2_SP NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_AAL2_SP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for AAL2_SP RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg AAL2_SP RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_AAL2_SP-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_AAL2_SP-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_TransportNetwork','moid_ManagedElement','moid_Aal2Sp'],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT              => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
             '^pmUnsuccessfulConnsInternal$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for AAL2_SP RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial AAL2_SP RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_AAL2_SP-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : RNC_AAL2_SP

# START : PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf
# Unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork','nedn_MeContext','moid_ManagedElement','moid_Equipment','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_ExchangeTerminalIp','moid_InternalEthernetPort','moid_IpInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmFramesExcTrafDsc$' => 4294967295,
         '^pmOctetsExcTrafDsc$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork','nedn_MeContext','moid_ManagedElement','moid_Equipment','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_ExchangeTerminalIp','moid_InternalEthernetPort','moid_IpInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmFramesExcTrafDsc$' => 4294967295,
         '^pmOctetsExcTrafDsc$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork','nedn_MeContext','moid_ManagedElement','moid_Equipment','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_ExchangeTerminalIp','moid_InternalEthernetPort','moid_IpInterface' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmFramesExcTrafDsc$' => 4294967295,
         '^pmOctetsExcTrafDsc$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_PlugInUnit_ExchangeTerminalIp_InternalEthPrt_IpIntf-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : PlugInUnit_ExchangeTermIp_InternalEthPrt_IpIntf

# START : CBU_Processor_Load
# Unpegger for CBU_Processor_Load RXI
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg CBU_Processor_Load RXI Counters',
        INPUT_FILE_DESCRIPTION     => '^(RXI_CBU_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RXI_CBU_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_Cbu','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for CBU_Processor_Load RXI
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial CBU_Processor_Load RXI PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RXI_CBU_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for CBU_Processor_Load RNC
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg CBU_Processor_Load RNC Counters',
        INPUT_FILE_DESCRIPTION     => '^(RNC_CBU_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^RNC_CBU_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_Cbu','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for CBU_Processor_Load RNC
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial CBU_Processor_Load RNC PIF files',
        INPUT_FILE_DESCRIPTION     => '^(RNC_CBU_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# Unpegger for CBU_Processor_Load NodeB
{
        RULE_TYPE                  => 'UNPEGGER',
        RULE_DESC                  => 'Unpeg CBU_Processor_Load NodeB Counters',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_CBU_Processor_Load-#-.+-#-.+-#)-\d{14}\w-#-.+-#-I\.pif$',
        INPUT_FILE_DATETIME_KEY    => '^NODEB_CBU_Processor_Load-#-.+-#-.+-#-(\d{12})\w{3}-#-.+-#-I\.pif$',
        INPUT_DATE_FORMAT          => 'YMD',
        PEG_FILENAME_PREFIX        => 'SAVED',
        UNPEG_FILENAME_PREFIX      => 'UNPEG',
        CALCULATE_ROLLOVER         => 'True',
        COUNTERS_TO_SORT_ON        => [ 'nedn_SubNetwork', 'nedn_MeContext', 'moid_Equipment','moid_ManagedElement','moid_Subrack','moid_Slot','moid_PlugInUnit','moid_Cbu','moid_GeneralProcessorUnit','moid_MediumAccessUnit' ],
        DEFAULT_NULL_VALUE         => '',
        UNPEG_FILE_TYPE            => 'HEADER',
        PRODUCE_PIF                => 0,
        OUTPUT_FORMAT          => 'LIF_Writer',
        KEEP_RAW_GRANULARITY       => 0,
        #MAX_PEG_PIF_AGE            => '3600',
        MAX_PEG_PIF_AGE            => 'DURATION*4+60',
		DATETIME_COUNTERS          => {
             STARTDATE => 'StartDate',
             STARTTIME => 'StartTime',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
        },
        PEG_COUNTERS => {
         '^pmNoOfDot3StatsFCSErrors$' => 4294967295,
         '^pmNoOfDot3StatsLateCollisions$' => 4294967295,
        },
},
# Remove initial PIF after unpegger for CBU_Processor_Load NodeB
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove initial CBU_Processor_Load NodeB PIF files',
        INPUT_FILE_DESCRIPTION     => '^(NODEB_CBU_Processor_Load-#-.+-#-.+)-#-\d{14}\w-#-.+-#-I\.pif$',
},
# END : CBU_Processor_Load

# START : UeRc
# Join of UeRc
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of RncFunction UeRc files',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-(.+)-#-\d+-#-I\.pif$',],
        COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction', 'moid_UeRc'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Aggregation of UeRc
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_ACCUM',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_ACCUM',
        PRODUCE_PIF            => 'True',
},
# Prepare for CQ aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_4/5/6/7/15/16/26/27/28/29/30/31/32/39 for CQ aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [
            '^4$', '^5$', '^6$', '^7$', '^15$',
            '^16$', '^26$', '^27$', '^28$', '^29$',
            '^30$', '^31$', '^32$', '^39$',
            ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'CQ',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual CQ aggregation
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc CQ blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-CQ-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_CQ',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_CQ',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for TV aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_5/6/7/15/16/26/27/28/29/30/31/32/39 for TV aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [
            '^5$', '^6$', '^7$', '^15$', '^16$',
            '^26$', '^27$', '^28$', '^29$', '^30$',
            '^31$', '^32$', '^39$',
            ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'TV',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual TV aggregation
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc TV blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-TV-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_TV',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_TV',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},

# Prepare for UeRc_2 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_2 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^2$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_2',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_2
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_2 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_2-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_2',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_2',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for UeRc_3 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_3 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^3$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_3',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_3
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_3 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_3-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_3',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_3',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for UeRc_4 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_4 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^4$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_4',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_4
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_4 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_4-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_4',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_4',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for UeRc_8 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_8 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^8$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_8',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_8
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_8 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_8-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_8',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_8',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for UeRc_10 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_10 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^10$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_10',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_10
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_10 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_10-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_10',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_10',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for UeRc_13 aggregation
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_13 for aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [ '^13$', ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'UeRc_13',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual aggregation of UeRc_13
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc_13 blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-UeRc_13-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_13',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_13',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Prepare for PSACCUM aggregation - P7
{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'Dataline to select only UeRc_4/5/6/7/13/15/16/17/18/21/22/25/26/27/28/29/30/31/32/39 for PSACCUM aggregation',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J\.pif$',],
        COUNTER_NAMES          => [
        {
            'COUNTER_NAME'   => 'moid_UeRc',
            'KEEP_WHERE'     => [
                '^4$',  '^5$',  '^6$',  '^7$',  '^13$',
                '^15$', '^16$', '^17$', '^18$', '^21$',
                '^22$', '^25$', '^26$', '^27$', '^28$',
                '^29$', '^30$', '^31$', '^32$', '^39$'
            ],
            'REMOVE_WHERE'   => [],
        }
        ],
        FILENAME_ADDITION   => 'PSACCUM',
        PRODUCE_PIF         => 'True',
        OUTPUT_FORMAT       => 0,
},
# Actual PSACCUM aggregation - P7
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UeRc PSACCUM blocks',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-J-#-PSACCUM-#-DW\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UeRc_PSACCUM',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UeRc_PSACCUM',
        PRODUCE_PIF            => 0,
        OUTPUT_FORMAT   => 'LIF_Writer',
},
# Remove UeRc initial PIFs
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove UeRc initial PIFs',
        INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UeRc-#-.+-#-I\.pif$',],
},
# END : UeRc

# Insert UtranCell_id from hierarchy PIF into CDMA Channel objects
# Note: The "vsDataRbsLocalCell-#-.+-#-J-#-S\.pif" file must be generated using the hierarchy parser first
{
    RULE_TYPE                           => 'INFOINSERT',
    RULE_DESC                           => 'Insert UtranCell_id from hierarchy PIF into CDMA Channel objects',
    INPUT_FILE_DESCRIPTION              => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                            '^ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#-I\.pif$'],
    HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_MeContext'],
    NAMES_USED_TO_ID_DATA_RECORD        => ['moid_ManagedElement','moid_NodeBFunction','moid_Carrier','moid_Sector'],
    INFO_FILE_DESCRIPTION               => ['^vsDataRbsLocalCell-#-.+-#-J-#-S\.pif$'],
    HEADER_NAMES_USED_TO_ID_INFORMATION => [],
    NAMES_USED_TO_ID_INFORMATION        => ['carrierRef_MeContext','carrierRef_ManagedElement','carrierRef_NodeBFunction','carrierRef_vsDataCarrier','carrierRef_vsDataSector'],
    REDUNDANT_DATA_COUNTERS             => [],
    ONLY_INSERT                         => ['UtranCell_id'],
    WRITE_DATA_LINE                     => 'True',
    PRODUCE_PIF                         => 'True',
    REMOVE_INPUT_FILES                  => 'True',
},

# No need to join initial pif and pif after INFORINSERT - P7.1 FP1
# Join all ME_NodeBFunction_HsDschResources PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
#{
#    RULE_TYPE                  => 'JOIN',
#    RULE_DESC                  => 'Join all ME_NodeBFunction_HsDschResources PIF files into one single PIF file',
#    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+)-#-.+-#-(I|I-#-S)\.pif$' ],
#    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector moid_HsDschResources ) ],
#    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_HsDschResources',
#    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
#    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_HsDschResources',
#    PRODUCE_PIF                => 'True',
#},
#
# No need to join initial pif and pif after INFORINSERT, just use the last PIF_2_OUTPUT to output the lif file - P7.1 FP1
# Join all ManagedElement_NodeBFunction_Sector_Carrier_Aich PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
#{
#    RULE_TYPE                  => 'JOIN',
#    RULE_DESC                  => 'Join all ManagedElement_NodeBFunction_Sector_Carrier_Aich PIF files into one single PIF file',
#    INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
#    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector moid_Aich ) ],
#    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#    OUTPUT_FILENAME_START      => 'ManagedElement_NodeBFunction_Sector_Carrier_Aich',
#    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
#    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Sector_Carrier_Aich',
#    PRODUCE_PIF                => 'True',
#},

# No need to join initial pif and pif after INFORINSERT, just use the last PIF_2_OUTPUT to output the lif file - P7.1 FP1
# Join all ME_NodeBFunction_Sector_Carrier_EDchResources PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
#{
#    RULE_TYPE                  => 'JOIN',
#    RULE_DESC                  => 'Join all ME_NodeBFunction_Sector_Carrier_EDchResources PIF files into one single PIF file',
#    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
#    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector moid_EDchResources ) ],
#    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
#    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
#    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
#    PRODUCE_PIF                => 'True',
#},

# START: ME_NodeBFunction_Sector_Carrier_EDchResources set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_Sector_Carrier_EDchResources',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmCapacityServEDchUsers|pmCommonChPowerEul|pmLEDchTot|pmLMaxEDch|pmNoiseFloor|pmNoSchEdchEul|pmOwnUuLoad|pmTotalRotCoverage)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmCapacityServEDchUsers_0 pmCapacityServEDchUsers_1 pmCapacityServEDchUsers_2 pmCapacityServEDchUsers_3
        pmCapacityServEDchUsers_4 pmCapacityServEDchUsers_5 pmCapacityServEDchUsers_6 pmCapacityServEDchUsers_7
        pmCapacityServEDchUsers_8 pmCapacityServEDchUsers_9 pmCapacityServEDchUsers_10
        pmCommonChPowerEul_0 pmCommonChPowerEul_1 pmCommonChPowerEul_2 pmCommonChPowerEul_3 pmCommonChPowerEul_4
        pmCommonChPowerEul_5 pmCommonChPowerEul_6 pmCommonChPowerEul_7 pmCommonChPowerEul_8 pmCommonChPowerEul_9
        pmCommonChPowerEul_10 pmCommonChPowerEul_11 pmCommonChPowerEul_12 pmCommonChPowerEul_13 pmCommonChPowerEul_14
        pmCommonChPowerEul_15 pmCommonChPowerEul_16 pmCommonChPowerEul_17 pmCommonChPowerEul_18 pmCommonChPowerEul_19
        pmCommonChPowerEul_20 pmCommonChPowerEul_21 pmCommonChPowerEul_22 pmCommonChPowerEul_23 pmCommonChPowerEul_24
        pmCommonChPowerEul_25 pmCommonChPowerEul_26 pmCommonChPowerEul_27 pmCommonChPowerEul_28 pmCommonChPowerEul_29
        pmCommonChPowerEul_30 pmCommonChPowerEul_31 pmCommonChPowerEul_32 pmCommonChPowerEul_33 pmCommonChPowerEul_34
        pmCommonChPowerEul_35 pmCommonChPowerEul_36 pmCommonChPowerEul_37 pmCommonChPowerEul_38 pmCommonChPowerEul_39
        pmCommonChPowerEul_40
        pmLEDchTot_0 pmLEDchTot_1 pmLEDchTot_2 pmLEDchTot_3 pmLEDchTot_4 pmLEDchTot_5 pmLEDchTot_6 pmLEDchTot_7
        pmLEDchTot_8 pmLEDchTot_9 pmLEDchTot_10 pmLEDchTot_11 pmLEDchTot_12 pmLEDchTot_13 pmLEDchTot_14 pmLEDchTot_15
        pmLEDchTot_16 pmLEDchTot_17 pmLEDchTot_18 pmLEDchTot_19 pmLEDchTot_20 pmLEDchTot_21 pmLEDchTot_22 pmLEDchTot_23
        pmLEDchTot_24 pmLEDchTot_25 pmLEDchTot_26 pmLEDchTot_27 pmLEDchTot_28 pmLEDchTot_29 pmLEDchTot_30 pmLEDchTot_31
        pmLEDchTot_32 pmLEDchTot_33 pmLEDchTot_34 pmLEDchTot_35 pmLEDchTot_36 pmLEDchTot_37 pmLEDchTot_38 pmLEDchTot_39
        pmLEDchTot_40 pmLEDchTot_41 pmLEDchTot_42 pmLEDchTot_43 pmLEDchTot_44 pmLEDchTot_45 pmLEDchTot_46 pmLEDchTot_47
        pmLEDchTot_48 pmLEDchTot_49
        pmLMaxEDch_0 pmLMaxEDch_1 pmLMaxEDch_2 pmLMaxEDch_3 pmLMaxEDch_4 pmLMaxEDch_5 pmLMaxEDch_6 pmLMaxEDch_7
        pmLMaxEDch_8 pmLMaxEDch_9 pmLMaxEDch_10 pmLMaxEDch_11 pmLMaxEDch_12 pmLMaxEDch_13 pmLMaxEDch_14 pmLMaxEDch_15
        pmLMaxEDch_16 pmLMaxEDch_17 pmLMaxEDch_18 pmLMaxEDch_19 pmLMaxEDch_20 pmLMaxEDch_21 pmLMaxEDch_22 pmLMaxEDch_23
        pmLMaxEDch_24 pmLMaxEDch_25 pmLMaxEDch_26 pmLMaxEDch_27 pmLMaxEDch_28 pmLMaxEDch_29 pmLMaxEDch_30 pmLMaxEDch_31
        pmLMaxEDch_32 pmLMaxEDch_33 pmLMaxEDch_34 pmLMaxEDch_35 pmLMaxEDch_36 pmLMaxEDch_37 pmLMaxEDch_38 pmLMaxEDch_39
        pmLMaxEDch_40 pmLMaxEDch_41 pmLMaxEDch_42 pmLMaxEDch_43 pmLMaxEDch_44 pmLMaxEDch_45 pmLMaxEDch_46 pmLMaxEDch_47
        pmLMaxEDch_48 pmLMaxEDch_49
        pmNoiseFloor_0 pmNoiseFloor_1 pmNoiseFloor_2 pmNoiseFloor_3 pmNoiseFloor_4 pmNoiseFloor_5 pmNoiseFloor_6
        pmNoiseFloor_7 pmNoiseFloor_8 pmNoiseFloor_9 pmNoiseFloor_10 pmNoiseFloor_11 pmNoiseFloor_12 pmNoiseFloor_13
        pmNoiseFloor_14 pmNoiseFloor_15 pmNoiseFloor_16 pmNoiseFloor_17 pmNoiseFloor_18 pmNoiseFloor_19 pmNoiseFloor_20
        pmNoiseFloor_21 pmNoiseFloor_22 pmNoiseFloor_23 pmNoiseFloor_24 pmNoiseFloor_25 pmNoiseFloor_26 pmNoiseFloor_27
        pmNoiseFloor_28 pmNoiseFloor_29 pmNoiseFloor_30 pmNoiseFloor_31 pmNoiseFloor_32 pmNoiseFloor_33 pmNoiseFloor_34
        pmNoiseFloor_35 pmNoiseFloor_36 pmNoiseFloor_37 pmNoiseFloor_38 pmNoiseFloor_39 pmNoiseFloor_40 pmNoiseFloor_41
        pmNoiseFloor_42 pmNoiseFloor_43 pmNoiseFloor_44 pmNoiseFloor_45 pmNoiseFloor_46 pmNoiseFloor_47 pmNoiseFloor_48
        pmNoiseFloor_49 pmNoiseFloor_50 pmNoiseFloor_51 pmNoiseFloor_52 pmNoiseFloor_53 pmNoiseFloor_54 pmNoiseFloor_55
        pmNoSchEdchEul_0 pmNoSchEdchEul_1 pmNoSchEdchEul_2 pmNoSchEdchEul_3 pmNoSchEdchEul_4 pmNoSchEdchEul_5
        pmNoSchEdchEul_6 pmNoSchEdchEul_7 pmNoSchEdchEul_8 pmNoSchEdchEul_9 pmNoSchEdchEul_10 pmNoSchEdchEul_11
        pmNoSchEdchEul_12 pmNoSchEdchEul_13 pmNoSchEdchEul_14 pmNoSchEdchEul_15 pmNoSchEdchEul_16 pmNoSchEdchEul_17
        pmNoSchEdchEul_18 pmNoSchEdchEul_19 pmNoSchEdchEul_20
        pmOwnUuLoad_0 pmOwnUuLoad_1 pmOwnUuLoad_2 pmOwnUuLoad_3 pmOwnUuLoad_4 pmOwnUuLoad_5 pmOwnUuLoad_6 pmOwnUuLoad_7
        pmOwnUuLoad_8 pmOwnUuLoad_9 pmOwnUuLoad_10 pmOwnUuLoad_11 pmOwnUuLoad_12 pmOwnUuLoad_13 pmOwnUuLoad_14 pmOwnUuLoad_15
        pmOwnUuLoad_16 pmOwnUuLoad_17 pmOwnUuLoad_18 pmOwnUuLoad_19 pmOwnUuLoad_20 pmOwnUuLoad_21 pmOwnUuLoad_22 pmOwnUuLoad_23
        pmOwnUuLoad_24 pmOwnUuLoad_25 pmOwnUuLoad_26 pmOwnUuLoad_27 pmOwnUuLoad_28 pmOwnUuLoad_29 pmOwnUuLoad_30 pmOwnUuLoad_31
        pmOwnUuLoad_32 pmOwnUuLoad_33 pmOwnUuLoad_34 pmOwnUuLoad_35 pmOwnUuLoad_36 pmOwnUuLoad_37 pmOwnUuLoad_38 pmOwnUuLoad_39
        pmOwnUuLoad_40 pmOwnUuLoad_41 pmOwnUuLoad_42 pmOwnUuLoad_43 pmOwnUuLoad_44 pmOwnUuLoad_45 pmOwnUuLoad_46 pmOwnUuLoad_47
        pmOwnUuLoad_48 pmOwnUuLoad_49 pmOwnUuLoad_50
        pmTotalRotCoverage_0 pmTotalRotCoverage_1 pmTotalRotCoverage_2 pmTotalRotCoverage_3 pmTotalRotCoverage_4
        pmTotalRotCoverage_5 pmTotalRotCoverage_6 pmTotalRotCoverage_7 pmTotalRotCoverage_8 pmTotalRotCoverage_9
        pmTotalRotCoverage_10 pmTotalRotCoverage_11 pmTotalRotCoverage_12 pmTotalRotCoverage_13 pmTotalRotCoverage_14
        pmTotalRotCoverage_15 pmTotalRotCoverage_16 pmTotalRotCoverage_17 pmTotalRotCoverage_18 pmTotalRotCoverage_19
        pmTotalRotCoverage_20 pmTotalRotCoverage_21 pmTotalRotCoverage_22 pmTotalRotCoverage_23 pmTotalRotCoverage_24
        pmTotalRotCoverage_25 pmTotalRotCoverage_26 pmTotalRotCoverage_27 pmTotalRotCoverage_28 pmTotalRotCoverage_29
        pmTotalRotCoverage_30 pmTotalRotCoverage_31 pmTotalRotCoverage_32 pmTotalRotCoverage_33 pmTotalRotCoverage_34
        pmTotalRotCoverage_35 pmTotalRotCoverage_36 pmTotalRotCoverage_37 pmTotalRotCoverage_38 pmTotalRotCoverage_39
        pmTotalRotCoverage_40 pmTotalRotCoverage_41 pmTotalRotCoverage_42 pmTotalRotCoverage_43 pmTotalRotCoverage_44
        pmTotalRotCoverage_45 pmTotalRotCoverage_46 pmTotalRotCoverage_47 pmTotalRotCoverage_48 pmTotalRotCoverage_49
        pmTotalRotCoverage_50
        pmTotRateGrantedEul_0 pmTotRateGrantedEul_1 pmTotRateGrantedEul_2 pmTotRateGrantedEul_3 pmTotRateGrantedEul_4
        pmTotRateGrantedEul_5 pmTotRateGrantedEul_6 pmTotRateGrantedEul_7 pmTotRateGrantedEul_8 pmTotRateGrantedEul_9
        pmTotRateGrantedEul_10 pmTotRateGrantedEul_11 pmTotRateGrantedEul_12 pmTotRateGrantedEul_13 pmTotRateGrantedEul_14
        pmTotRateGrantedEul_15 pmTotRateGrantedEul_16 pmTotRateGrantedEul_17 pmTotRateGrantedEul_18 pmTotRateGrantedEul_19
        pmTotRateGrantedEul_20 pmTotRateGrantedEul_21 pmTotRateGrantedEul_22 pmTotRateGrantedEul_23 pmTotRateGrantedEul_24
        pmTotRateGrantedEul_25 pmTotRateGrantedEul_26 pmTotRateGrantedEul_27 pmTotRateGrantedEul_28 pmTotRateGrantedEul_29
        pmTotRateGrantedEul_30 pmTotRateGrantedEul_31 pmTotRateGrantedEul_32 pmTotRateGrantedEul_33 pmTotRateGrantedEul_34
        pmTotRateGrantedEul_35 pmTotRateGrantedEul_36 pmTotRateGrantedEul_37 pmTotRateGrantedEul_38 pmTotRateGrantedEul_39
        pmTotRateGrantedEul_40 pmTotRateGrantedEul_41 pmTotRateGrantedEul_42 pmTotRateGrantedEul_43 pmTotRateGrantedEul_44
        pmTotRateGrantedEul_45 pmTotRateGrantedEul_46 pmTotRateGrantedEul_47 pmTotRateGrantedEul_48 pmTotRateGrantedEul_49
        pmTotRateGrantedEul_50 pmTotRateGrantedEul_51 pmTotRateGrantedEul_52 pmTotRateGrantedEul_53 pmTotRateGrantedEul_54
        pmTotRateGrantedEul_55 pmTotRateGrantedEul_56 pmTotRateGrantedEul_57 pmTotRateGrantedEul_58 pmTotRateGrantedEul_59
        pmTotRateGrantedEul_60
        pmWaitingTimeEul_0 pmWaitingTimeEul_1 pmWaitingTimeEul_2 pmWaitingTimeEul_3 pmWaitingTimeEul_4 pmWaitingTimeEul_5
        pmWaitingTimeEul_6 pmWaitingTimeEul_7 pmWaitingTimeEul_8 pmWaitingTimeEul_9 pmWaitingTimeEul_10 pmWaitingTimeEul_11
        pmWaitingTimeEul_12 pmWaitingTimeEul_13 pmWaitingTimeEul_14 pmWaitingTimeEul_15 pmWaitingTimeEul_16 pmWaitingTimeEul_17
        pmWaitingTimeEul_18 pmWaitingTimeEul_19 pmWaitingTimeEul_20 pmWaitingTimeEul_21 pmWaitingTimeEul_22 pmWaitingTimeEul_23
        pmWaitingTimeEul_24 pmWaitingTimeEul_25 pmWaitingTimeEul_26 pmWaitingTimeEul_27 pmWaitingTimeEul_28
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_Sector_Carrier_EDchResources',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [
            '^(pmCapacityServEDchUsers|pmCommonChPowerEul|pmLEDchTot|pmLMaxEDch|pmNoiseFloor|pmNoSchEdchEul|pmOwnUuLoad|pmTotalRotCoverage)_\d+$',
        ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier', 'moid_EDchResources',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_Sector_Carrier_EDchResources',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-PDF-#-FSC)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_EDchResources',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_Sector_Carrier_EDchResources set

# No need to join initial pif and pif after INFORINSERT, just use the last PIF_2_OUTPUT to output the lif file - P7.1 FP1
# Join all ME_NodeBFunction_Sector_Carrier_Prach PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
#{
#    RULE_TYPE                  => 'JOIN',
#    RULE_DESC                  => 'Join all ME_NodeBFunction_Sector_Carrier_Prach PIF files into one single PIF file',
#    INPUT_FILE_DESCRIPTION     => [ '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
#    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector moid_Prach ) ],
#    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#    OUTPUT_FILENAME_START      => 'ME_NodeBFunction_Sector_Carrier_Prach',
#    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
#    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_Prach',
#    PRODUCE_PIF                => 'True',
#},

# START: ME_NodeBFunction_Sector_Carrier_Prach set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_Sector_Carrier_Prach',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_Prach',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmPropagationDelay|pmReceivedPreambleSir)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmPropagationDelay_0 pmPropagationDelay_1 pmPropagationDelay_2 pmPropagationDelay_3 pmPropagationDelay_4
        pmPropagationDelay_5 pmPropagationDelay_6 pmPropagationDelay_7 pmPropagationDelay_8 pmPropagationDelay_9
        pmPropagationDelay_10 pmPropagationDelay_11 pmPropagationDelay_12 pmPropagationDelay_13 pmPropagationDelay_14
        pmPropagationDelay_15 pmPropagationDelay_16 pmPropagationDelay_17 pmPropagationDelay_18 pmPropagationDelay_19
        pmPropagationDelay_20 pmPropagationDelay_21 pmPropagationDelay_22 pmPropagationDelay_23 pmPropagationDelay_24
        pmPropagationDelay_25 pmPropagationDelay_26 pmPropagationDelay_27 pmPropagationDelay_28 pmPropagationDelay_29
        pmPropagationDelay_30 pmPropagationDelay_31 pmPropagationDelay_32 pmPropagationDelay_33 pmPropagationDelay_34
        pmPropagationDelay_35 pmPropagationDelay_36 pmPropagationDelay_37 pmPropagationDelay_38 pmPropagationDelay_39
        pmPropagationDelay_40
        pmReceivedPreambleSir_0 pmReceivedPreambleSir_1 pmReceivedPreambleSir_2 pmReceivedPreambleSir_3
        pmReceivedPreambleSir_4 pmReceivedPreambleSir_5 pmReceivedPreambleSir_6 pmReceivedPreambleSir_7
        pmReceivedPreambleSir_8 pmReceivedPreambleSir_9 pmReceivedPreambleSir_10 pmReceivedPreambleSir_11
        pmReceivedPreambleSir_12 pmReceivedPreambleSir_13 pmReceivedPreambleSir_14 pmReceivedPreambleSir_15
        pmReceivedPreambleSir_16 pmReceivedPreambleSir_17 pmReceivedPreambleSir_18 pmReceivedPreambleSir_19
        pmReceivedPreambleSir_20 pmReceivedPreambleSir_21 pmReceivedPreambleSir_22 pmReceivedPreambleSir_23
        pmReceivedPreambleSir_24 pmReceivedPreambleSir_25 pmReceivedPreambleSir_26
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_Sector_Carrier_Prach',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmPropagationDelay|pmReceivedPreambleSir)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier', 'moid_Prach',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_Sector_Carrier_Prach',
    INPUT_FILE_DESCRIPTION     => '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-PDF-#-FSC)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Sector_Carrier_Prach',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_Sector_Carrier_Prach set

# No need to join initial pif and pif after INFORINSERT, just use the last PIF_2_OUTPUT to output the lif file - P7.1 FP1
# Join all ManagedElement_NodeBFunction_Carrier_Sccpch PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
#{
#    RULE_TYPE                  => 'JOIN',
#    RULE_DESC                  => 'Join all ManagedElement_NodeBFunction_Carrier_Sccpch PIF files into one single PIF file',
#    INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$' ],
#    COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_NodeBFunction moid_Carrier moid_Sector moid_Sccpch ) ],
#    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#    OUTPUT_FILENAME_START      => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
#    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
#    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
#    PRODUCE_PIF                => 'True',
#},

# START: ManagedElement_NodeBFunction_Carrier_Sccpch set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_NodeBFunction_Carrier_Sccpch',
    INPUT_FILE_DESCRIPTION     => '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmMbmsSccpchTransmittedTfc)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmMbmsSccpchTransmittedTfc_0 pmMbmsSccpchTransmittedTfc_1 pmMbmsSccpchTransmittedTfc_2 pmMbmsSccpchTransmittedTfc_3
        pmMbmsSccpchTransmittedTfc_4 pmMbmsSccpchTransmittedTfc_5 pmMbmsSccpchTransmittedTfc_6 pmMbmsSccpchTransmittedTfc_7
        pmMbmsSccpchTransmittedTfc_8 pmMbmsSccpchTransmittedTfc_9 pmMbmsSccpchTransmittedTfc_10 pmMbmsSccpchTransmittedTfc_11
        pmMbmsSccpchTransmittedTfc_12 pmMbmsSccpchTransmittedTfc_13 pmMbmsSccpchTransmittedTfc_14 pmMbmsSccpchTransmittedTfc_15
        pmMbmsSccpchTransmittedTfc_16 pmMbmsSccpchTransmittedTfc_17 pmMbmsSccpchTransmittedTfc_18 pmMbmsSccpchTransmittedTfc_19
        pmMbmsSccpchTransmittedTfc_20 pmMbmsSccpchTransmittedTfc_21
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_NodeBFunction_Carrier_Sccpch',
    INPUT_FILE_DESCRIPTION     => '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmMbmsSccpchTransmittedTfc)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier', 'moid_Sccpch',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_NodeBFunction_Carrier_Sccpch',
    INPUT_FILE_DESCRIPTION     => '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-PDF-#-FSC)\.pif$',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_NodeBFunction_Carrier_Sccpch',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_NodeBFunction_Carrier_Sccpch set

# Output INFOINSERT PIFs - P7.1 FP1
{
    RULE_TYPE               => 'PIF_2_OUTPUT',
    RULE_DESC               => 'Output INFOINSERT LIF files',
    INPUT_FILE_DESCRIPTION  => [
                                 '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#-I-#-S)\.pif$',
                                ],
    PRODUCE_PIF             => 0,
    OUTPUT_FORMAT           => 'LIF_Writer',
},

# Total up pmSumTransmittedBitsSpi<00-15>
{
    RULE_TYPE                  => 'PERLIZE',
    RULE_DESC                  => 'Total up pmSumTransmittedBitsSpi<00-15>',
    #INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S\.pif$', # P7.1 FP1
    DATA_COUNTERS_OP           => sub
    {
        my $c_ref = shift;
        my @c_names = qw( pmSumTransmittedBitsSpi00 pmSumTransmittedBitsSpi01 pmSumTransmittedBitsSpi02 pmSumTransmittedBitsSpi03
                          pmSumTransmittedBitsSpi04 pmSumTransmittedBitsSpi05 pmSumTransmittedBitsSpi06 pmSumTransmittedBitsSpi07
                          pmSumTransmittedBitsSpi08 pmSumTransmittedBitsSpi09 pmSumTransmittedBitsSpi10 pmSumTransmittedBitsSpi11
                          pmSumTransmittedBitsSpi12 pmSumTransmittedBitsSpi13 pmSumTransmittedBitsSpi14 pmSumTransmittedBitsSpi15 );
        my $total_pmSumTransmittedBitsSpi = 0;

        foreach my $c_name (@c_names) {
            if ( exists $c_ref->{$c_name} ) {
                $total_pmSumTransmittedBitsSpi += $c_ref->{$c_name};
                $c_ref->{Tot_pmSumTransmittedBitsSpi} = $total_pmSumTransmittedBitsSpi;
            }
        }
        return 0;
    },
    FILENAME_SUFFIX            => 'TOT',
    PRODUCE_PIF                => 'True',
    #OUTPUT_FORMAT              => 'LIF_Writer', # P7.1 FP1
},

# START: ME_NodeBFunction_HsDschResources set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_HsDschResources',
    INPUT_FILE_DESCRIPTION     => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT\.pif$',], # P7.1 FP1
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_HsDschResources',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmAck16Qam|pmAck64Qam|pmAckQpsk|pmAverageUserRate|pmCapacityHsDschUsers|pmCapacityHsPdschCodes|pmDelayDistributionSpi00|pmDelayDistributionSpi01|pmDelayDistributionSpi02|pmDelayDistributionSpi03|pmDelayDistributionSpi04|pmDelayDistributionSpi05|pmDelayDistributionSpi06|pmDelayDistributionSpi07|pmDelayDistributionSpi08|pmDelayDistributionSpi09|pmDelayDistributionSpi10|pmDelayDistributionSpi11|pmDelayDistributionSpi12|pmDelayDistributionSpi13|pmDelayDistributionSpi14|pmDelayDistributionSpi15)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmAck16Qam_0 pmAck16Qam_1 pmAck16Qam_2 pmAck16Qam_3 pmAck16Qam_4 pmAck16Qam_5 pmAck16Qam_6 pmAck16Qam_7 pmAck16Qam_8
        pmAck16Qam_9 pmAck16Qam_10 pmAck16Qam_11 pmAck16Qam_12 pmAck16Qam_13 pmAck16Qam_14 pmAck16Qam_15 pmAck16Qam_16
        pmAck16Qam_17 pmAck16Qam_18 pmAck16Qam_19 pmAck16Qam_20 pmAck16Qam_21 pmAck16Qam_22 pmAck16Qam_23 pmAck16Qam_24
        pmAck16Qam_25 pmAck16Qam_26 pmAck16Qam_27 pmAck16Qam_28 pmAck16Qam_29
        pmAck64Qam_0 pmAck64Qam_1 pmAck64Qam_2 pmAck64Qam_3 pmAck64Qam_4 pmAck64Qam_5 pmAck64Qam_6 pmAck64Qam_7 pmAck64Qam_8
        pmAck64Qam_9 pmAck64Qam_10 pmAck64Qam_11 pmAck64Qam_12 pmAck64Qam_13 pmAck64Qam_14 pmAck64Qam_15 pmAck64Qam_16
        pmAck64Qam_17 pmAck64Qam_18 pmAck64Qam_19 pmAck64Qam_20 pmAck64Qam_21 pmAck64Qam_22 pmAck64Qam_23 pmAck64Qam_24
        pmAck64Qam_25 pmAck64Qam_26 pmAck64Qam_27 pmAck64Qam_28 pmAck64Qam_29
        pmAckQpsk_0 pmAckQpsk_1 pmAckQpsk_2 pmAckQpsk_3 pmAckQpsk_4 pmAckQpsk_5 pmAckQpsk_6 pmAckQpsk_7 pmAckQpsk_8
        pmAckQpsk_9 pmAckQpsk_10 pmAckQpsk_11 pmAckQpsk_12 pmAckQpsk_13 pmAckQpsk_14 pmAckQpsk_15 pmAckQpsk_16
        pmAckQpsk_17 pmAckQpsk_18 pmAckQpsk_19 pmAckQpsk_20 pmAckQpsk_21 pmAckQpsk_22 pmAckQpsk_23 pmAckQpsk_24
        pmAckQpsk_25 pmAckQpsk_26 pmAckQpsk_27 pmAckQpsk_28 pmAckQpsk_29
        pmAverageUserRate_0 pmAverageUserRate_1 pmAverageUserRate_2 pmAverageUserRate_3 pmAverageUserRate_4
        pmAverageUserRate_5 pmAverageUserRate_6 pmAverageUserRate_7 pmAverageUserRate_8 pmAverageUserRate_9
        pmAverageUserRate_10 pmAverageUserRate_11 pmAverageUserRate_12 pmAverageUserRate_13 pmAverageUserRate_14
        pmAverageUserRate_15 pmAverageUserRate_16 pmAverageUserRate_17 pmAverageUserRate_18 pmAverageUserRate_19
        pmAverageUserRate_20 pmAverageUserRate_21 pmAverageUserRate_22 pmAverageUserRate_23
        pmCapacityHsDschUsers_0 pmCapacityHsDschUsers_1 pmCapacityHsDschUsers_2 pmCapacityHsDschUsers_3
        pmCapacityHsDschUsers_4 pmCapacityHsDschUsers_5 pmCapacityHsDschUsers_6 pmCapacityHsDschUsers_7
        pmCapacityHsDschUsers_8 pmCapacityHsDschUsers_9 pmCapacityHsDschUsers_10 pmCapacityHsDschUsers_11
        pmCapacityHsDschUsers_12 pmCapacityHsDschUsers_13 pmCapacityHsDschUsers_14 pmCapacityHsDschUsers_15
        pmCapacityHsDschUsers_16 pmCapacityHsDschUsers_17 pmCapacityHsDschUsers_18 pmCapacityHsDschUsers_19
        pmCapacityHsDschUsers_20
        pmCapacityHsPdschCodes_0 pmCapacityHsPdschCodes_1 pmCapacityHsPdschCodes_2 pmCapacityHsPdschCodes_3
        pmCapacityHsPdschCodes_4 pmCapacityHsPdschCodes_5 pmCapacityHsPdschCodes_6 pmCapacityHsPdschCodes_7
        pmCapacityHsPdschCodes_8 pmCapacityHsPdschCodes_9 pmCapacityHsPdschCodes_10
        pmDelayDistributionSpi00_0 pmDelayDistributionSpi00_1 pmDelayDistributionSpi00_2 pmDelayDistributionSpi00_3
        pmDelayDistributionSpi00_4 pmDelayDistributionSpi00_5 pmDelayDistributionSpi00_6 pmDelayDistributionSpi00_7
        pmDelayDistributionSpi00_8 pmDelayDistributionSpi00_9 pmDelayDistributionSpi00_10
        pmDelayDistributionSpi01_0 pmDelayDistributionSpi01_1 pmDelayDistributionSpi01_2 pmDelayDistributionSpi01_3
        pmDelayDistributionSpi01_4 pmDelayDistributionSpi01_5 pmDelayDistributionSpi01_6 pmDelayDistributionSpi01_7
        pmDelayDistributionSpi01_8 pmDelayDistributionSpi01_9 pmDelayDistributionSpi01_10
        pmDelayDistributionSpi02_0 pmDelayDistributionSpi02_1 pmDelayDistributionSpi02_2 pmDelayDistributionSpi02_3
        pmDelayDistributionSpi02_4 pmDelayDistributionSpi02_5 pmDelayDistributionSpi02_6 pmDelayDistributionSpi02_7
        pmDelayDistributionSpi02_8 pmDelayDistributionSpi02_9 pmDelayDistributionSpi02_10
        pmDelayDistributionSpi03_0 pmDelayDistributionSpi03_1 pmDelayDistributionSpi03_2 pmDelayDistributionSpi03_3
        pmDelayDistributionSpi03_4 pmDelayDistributionSpi03_5 pmDelayDistributionSpi03_6 pmDelayDistributionSpi03_7
        pmDelayDistributionSpi03_8 pmDelayDistributionSpi03_9 pmDelayDistributionSpi03_10
        pmDelayDistributionSpi04_0 pmDelayDistributionSpi04_1 pmDelayDistributionSpi04_2 pmDelayDistributionSpi04_3
        pmDelayDistributionSpi04_4 pmDelayDistributionSpi04_5 pmDelayDistributionSpi04_6 pmDelayDistributionSpi04_7
        pmDelayDistributionSpi04_8 pmDelayDistributionSpi04_9 pmDelayDistributionSpi04_10
        pmDelayDistributionSpi05_0 pmDelayDistributionSpi05_1 pmDelayDistributionSpi05_2 pmDelayDistributionSpi05_3
        pmDelayDistributionSpi05_4 pmDelayDistributionSpi05_5 pmDelayDistributionSpi05_6 pmDelayDistributionSpi05_7
        pmDelayDistributionSpi05_8 pmDelayDistributionSpi05_9 pmDelayDistributionSpi05_10
        pmDelayDistributionSpi06_0 pmDelayDistributionSpi06_1 pmDelayDistributionSpi06_2 pmDelayDistributionSpi06_3
        pmDelayDistributionSpi06_4 pmDelayDistributionSpi06_5 pmDelayDistributionSpi06_6 pmDelayDistributionSpi06_7
        pmDelayDistributionSpi06_8 pmDelayDistributionSpi06_9 pmDelayDistributionSpi06_10
        pmDelayDistributionSpi07_0 pmDelayDistributionSpi07_1 pmDelayDistributionSpi07_2 pmDelayDistributionSpi07_3
        pmDelayDistributionSpi07_4 pmDelayDistributionSpi07_5 pmDelayDistributionSpi07_6 pmDelayDistributionSpi07_7
        pmDelayDistributionSpi07_8 pmDelayDistributionSpi07_9 pmDelayDistributionSpi07_10
        pmDelayDistributionSpi08_0 pmDelayDistributionSpi08_1 pmDelayDistributionSpi08_2 pmDelayDistributionSpi08_3
        pmDelayDistributionSpi08_4 pmDelayDistributionSpi08_5 pmDelayDistributionSpi08_6 pmDelayDistributionSpi08_7
        pmDelayDistributionSpi08_8 pmDelayDistributionSpi08_9 pmDelayDistributionSpi08_10
        pmDelayDistributionSpi09_0 pmDelayDistributionSpi09_1 pmDelayDistributionSpi09_2 pmDelayDistributionSpi09_3
        pmDelayDistributionSpi09_4 pmDelayDistributionSpi09_5 pmDelayDistributionSpi09_6 pmDelayDistributionSpi09_7
        pmDelayDistributionSpi09_8 pmDelayDistributionSpi09_9 pmDelayDistributionSpi09_10
        pmDelayDistributionSpi10_0 pmDelayDistributionSpi10_1 pmDelayDistributionSpi10_2 pmDelayDistributionSpi10_3
        pmDelayDistributionSpi10_4 pmDelayDistributionSpi10_5 pmDelayDistributionSpi10_6 pmDelayDistributionSpi10_7
        pmDelayDistributionSpi10_8 pmDelayDistributionSpi10_9 pmDelayDistributionSpi10_10
        pmDelayDistributionSpi11_0 pmDelayDistributionSpi11_1 pmDelayDistributionSpi11_2 pmDelayDistributionSpi11_3
        pmDelayDistributionSpi11_4 pmDelayDistributionSpi11_5 pmDelayDistributionSpi11_6 pmDelayDistributionSpi11_7
        pmDelayDistributionSpi11_8 pmDelayDistributionSpi11_9 pmDelayDistributionSpi11_10
        pmDelayDistributionSpi12_0 pmDelayDistributionSpi12_1 pmDelayDistributionSpi12_2 pmDelayDistributionSpi12_3
        pmDelayDistributionSpi12_4 pmDelayDistributionSpi12_5 pmDelayDistributionSpi12_6 pmDelayDistributionSpi12_7
        pmDelayDistributionSpi12_8 pmDelayDistributionSpi12_9 pmDelayDistributionSpi12_10
        pmDelayDistributionSpi13_0 pmDelayDistributionSpi13_1 pmDelayDistributionSpi13_2 pmDelayDistributionSpi13_3
        pmDelayDistributionSpi13_4 pmDelayDistributionSpi13_5 pmDelayDistributionSpi13_6 pmDelayDistributionSpi13_7
        pmDelayDistributionSpi13_8 pmDelayDistributionSpi13_9 pmDelayDistributionSpi13_10
        pmDelayDistributionSpi14_0 pmDelayDistributionSpi14_1 pmDelayDistributionSpi14_2 pmDelayDistributionSpi14_3
        pmDelayDistributionSpi14_4 pmDelayDistributionSpi14_5 pmDelayDistributionSpi14_6 pmDelayDistributionSpi14_7
        pmDelayDistributionSpi14_8 pmDelayDistributionSpi14_9 pmDelayDistributionSpi14_10
        pmDelayDistributionSpi15_0 pmDelayDistributionSpi15_1 pmDelayDistributionSpi15_2 pmDelayDistributionSpi15_3
        pmDelayDistributionSpi15_4 pmDelayDistributionSpi15_5 pmDelayDistributionSpi15_6 pmDelayDistributionSpi15_7
        pmDelayDistributionSpi15_8 pmDelayDistributionSpi15_9 pmDelayDistributionSpi15_10
        pmNoOfHsUsersPerTti_0 pmNoOfHsUsersPerTti_1 pmNoOfHsUsersPerTti_2 pmNoOfHsUsersPerTti_3 pmNoOfHsUsersPerTti_4
        pmRemainingResourceCheck_0 pmRemainingResourceCheck_1 pmRemainingResourceCheck_2
        pmReportedCqi_0 pmReportedCqi_1 pmReportedCqi_2 pmReportedCqi_3 pmReportedCqi_4 pmReportedCqi_5
        pmReportedCqi_6 pmReportedCqi_7 pmReportedCqi_8 pmReportedCqi_9 pmReportedCqi_10 pmReportedCqi_11
        pmReportedCqi_12 pmReportedCqi_13 pmReportedCqi_14 pmReportedCqi_15 pmReportedCqi_16 pmReportedCqi_17
        pmReportedCqi_18 pmReportedCqi_19 pmReportedCqi_20 pmReportedCqi_21 pmReportedCqi_22 pmReportedCqi_23
        pmReportedCqi_24 pmReportedCqi_25 pmReportedCqi_26 pmReportedCqi_27 pmReportedCqi_28 pmReportedCqi_29
        pmReportedCqi_30 pmReportedCqi_31
        pmReportedCqi64Qam_0 pmReportedCqi64Qam_1 pmReportedCqi64Qam_2 pmReportedCqi64Qam_3 pmReportedCqi64Qam_4
        pmReportedCqi64Qam_5 pmReportedCqi64Qam_6 pmReportedCqi64Qam_7 pmReportedCqi64Qam_8 pmReportedCqi64Qam_9
        pmReportedCqi64Qam_10 pmReportedCqi64Qam_11 pmReportedCqi64Qam_12 pmReportedCqi64Qam_13 pmReportedCqi64Qam_14
        pmReportedCqi64Qam_15 pmReportedCqi64Qam_16 pmReportedCqi64Qam_17 pmReportedCqi64Qam_18 pmReportedCqi64Qam_19
        pmReportedCqi64Qam_20 pmReportedCqi64Qam_21 pmReportedCqi64Qam_22 pmReportedCqi64Qam_23 pmReportedCqi64Qam_24
        pmReportedCqi64Qam_25 pmReportedCqi64Qam_26 pmReportedCqi64Qam_27 pmReportedCqi64Qam_28 pmReportedCqi64Qam_29
        pmReportedCqi64Qam_30 pmReportedCqi64Qam_31
        pmReportedCqiMimoDs1_0 pmReportedCqiMimoDs1_1 pmReportedCqiMimoDs1_2 pmReportedCqiMimoDs1_3 pmReportedCqiMimoDs1_4
        pmReportedCqiMimoDs1_5 pmReportedCqiMimoDs1_6 pmReportedCqiMimoDs1_7 pmReportedCqiMimoDs1_8 pmReportedCqiMimoDs1_9
        pmReportedCqiMimoDs1_10 pmReportedCqiMimoDs1_11 pmReportedCqiMimoDs1_12 pmReportedCqiMimoDs1_13 pmReportedCqiMimoDs1_14
        pmReportedCqiMimoDs2_0 pmReportedCqiMimoDs2_1 pmReportedCqiMimoDs2_2 pmReportedCqiMimoDs2_3 pmReportedCqiMimoDs2_4
        pmReportedCqiMimoDs2_5 pmReportedCqiMimoDs2_6 pmReportedCqiMimoDs2_7 pmReportedCqiMimoDs2_8 pmReportedCqiMimoDs2_9
        pmReportedCqiMimoDs2_10 pmReportedCqiMimoDs2_11 pmReportedCqiMimoDs2_12 pmReportedCqiMimoDs2_13 pmReportedCqiMimoDs2_14
        pmReportedCqiMimoSs_0 pmReportedCqiMimoSs_1 pmReportedCqiMimoSs_2 pmReportedCqiMimoSs_3 pmReportedCqiMimoSs_4
        pmReportedCqiMimoSs_5 pmReportedCqiMimoSs_6 pmReportedCqiMimoSs_7 pmReportedCqiMimoSs_8 pmReportedCqiMimoSs_9
        pmReportedCqiMimoSs_10 pmReportedCqiMimoSs_11 pmReportedCqiMimoSs_12 pmReportedCqiMimoSs_13 pmReportedCqiMimoSs_14
        pmReportedCqiMimoSs_15 pmReportedCqiMimoSs_16 pmReportedCqiMimoSs_17 pmReportedCqiMimoSs_18 pmReportedCqiMimoSs_19
        pmReportedCqiMimoSs_20 pmReportedCqiMimoSs_21 pmReportedCqiMimoSs_22 pmReportedCqiMimoSs_23 pmReportedCqiMimoSs_24
        pmReportedCqiMimoSs_25 pmReportedCqiMimoSs_26 pmReportedCqiMimoSs_27 pmReportedCqiMimoSs_28 pmReportedCqiMimoSs_29
        pmReportedCqiMimoSs_30 pmReportedCqiMimoSs_31
        pmSumOfHsScchUsedPwr_0 pmSumOfHsScchUsedPwr_1 pmSumOfHsScchUsedPwr_2 pmSumOfHsScchUsedPwr_3 pmSumOfHsScchUsedPwr_4
        pmSumOfHsScchUsedPwr_5 pmSumOfHsScchUsedPwr_6 pmSumOfHsScchUsedPwr_7 pmSumOfHsScchUsedPwr_8 pmSumOfHsScchUsedPwr_9
        pmSumOfHsScchUsedPwr_10 pmSumOfHsScchUsedPwr_11 pmSumOfHsScchUsedPwr_12 pmSumOfHsScchUsedPwr_13 pmSumOfHsScchUsedPwr_14
        pmSumOfHsScchUsedPwr_15 pmSumOfHsScchUsedPwr_16 pmSumOfHsScchUsedPwr_17 pmSumOfHsScchUsedPwr_18 pmSumOfHsScchUsedPwr_19
        pmSumOfHsScchUsedPwr_20 pmSumOfHsScchUsedPwr_21 pmSumOfHsScchUsedPwr_22 pmSumOfHsScchUsedPwr_23 pmSumOfHsScchUsedPwr_24
        pmSumOfHsScchUsedPwr_25 pmSumOfHsScchUsedPwr_26 pmSumOfHsScchUsedPwr_27 pmSumOfHsScchUsedPwr_28 pmSumOfHsScchUsedPwr_29
        pmSumOfHsScchUsedPwr_30 pmSumOfHsScchUsedPwr_31 pmSumOfHsScchUsedPwr_32 pmSumOfHsScchUsedPwr_33 pmSumOfHsScchUsedPwr_34
        pmSumOfHsScchUsedPwr_35 pmSumOfHsScchUsedPwr_36 pmSumOfHsScchUsedPwr_37 pmSumOfHsScchUsedPwr_38 pmSumOfHsScchUsedPwr_39
        pmSumOfHsScchUsedPwr_40 pmSumOfHsScchUsedPwr_41 pmSumOfHsScchUsedPwr_42 pmSumOfHsScchUsedPwr_43 pmSumOfHsScchUsedPwr_44
        pmSumOfHsScchUsedPwr_45 pmSumOfHsScchUsedPwr_46 pmSumOfHsScchUsedPwr_47 pmSumOfHsScchUsedPwr_48 pmSumOfHsScchUsedPwr_49
        pmSumOfHsScchUsedPwr_50 pmSumOfHsScchUsedPwr_51 pmSumOfHsScchUsedPwr_52 pmSumOfHsScchUsedPwr_53 pmSumOfHsScchUsedPwr_54
        pmSumOfHsScchUsedPwr_55 pmSumOfHsScchUsedPwr_56 pmSumOfHsScchUsedPwr_57 pmSumOfHsScchUsedPwr_58 pmSumOfHsScchUsedPwr_59
        pmSumOfHsScchUsedPwr_60 pmSumOfHsScchUsedPwr_61 pmSumOfHsScchUsedPwr_62 pmSumOfHsScchUsedPwr_63 pmSumOfHsScchUsedPwr_64
        pmSumOfHsScchUsedPwr_65 pmSumOfHsScchUsedPwr_66 pmSumOfHsScchUsedPwr_67 pmSumOfHsScchUsedPwr_68 pmSumOfHsScchUsedPwr_69
        pmSumOfHsScchUsedPwr_70 pmSumOfHsScchUsedPwr_71 pmSumOfHsScchUsedPwr_72 pmSumOfHsScchUsedPwr_73 pmSumOfHsScchUsedPwr_74
        pmSumOfHsScchUsedPwr_75 pmSumOfHsScchUsedPwr_76 pmSumOfHsScchUsedPwr_77 pmSumOfHsScchUsedPwr_78 pmSumOfHsScchUsedPwr_79
        pmSumOfHsScchUsedPwr_80 pmSumOfHsScchUsedPwr_81 pmSumOfHsScchUsedPwr_82 pmSumOfHsScchUsedPwr_83 pmSumOfHsScchUsedPwr_84
        pmSumOfHsScchUsedPwr_85 pmSumOfHsScchUsedPwr_86 pmSumOfHsScchUsedPwr_87 pmSumOfHsScchUsedPwr_88 pmSumOfHsScchUsedPwr_89
        pmSumOfHsScchUsedPwr_90 pmSumOfHsScchUsedPwr_91 pmSumOfHsScchUsedPwr_92 pmSumOfHsScchUsedPwr_93 pmSumOfHsScchUsedPwr_94
        pmSumOfHsScchUsedPwr_95 pmSumOfHsScchUsedPwr_96 pmSumOfHsScchUsedPwr_97 pmSumOfHsScchUsedPwr_98 pmSumOfHsScchUsedPwr_99
        pmSumOfHsScchUsedPwr_100 pmSumOfHsScchUsedPwr_101 pmSumOfHsScchUsedPwr_102
        pmTransmittedCarrierPowerHs_0 pmTransmittedCarrierPowerHs_1 pmTransmittedCarrierPowerHs_2 pmTransmittedCarrierPowerHs_3
        pmTransmittedCarrierPowerHs_4 pmTransmittedCarrierPowerHs_5 pmTransmittedCarrierPowerHs_6 pmTransmittedCarrierPowerHs_7
        pmTransmittedCarrierPowerHs_8 pmTransmittedCarrierPowerHs_9 pmTransmittedCarrierPowerHs_10 pmTransmittedCarrierPowerHs_11
        pmTransmittedCarrierPowerHs_12 pmTransmittedCarrierPowerHs_13 pmTransmittedCarrierPowerHs_14 pmTransmittedCarrierPowerHs_15
        pmTransmittedCarrierPowerHs_16 pmTransmittedCarrierPowerHs_17 pmTransmittedCarrierPowerHs_18 pmTransmittedCarrierPowerHs_19
        pmTransmittedCarrierPowerHs_20 pmTransmittedCarrierPowerHs_21 pmTransmittedCarrierPowerHs_22 pmTransmittedCarrierPowerHs_23
        pmTransmittedCarrierPowerHs_24 pmTransmittedCarrierPowerHs_25 pmTransmittedCarrierPowerHs_26 pmTransmittedCarrierPowerHs_27
        pmTransmittedCarrierPowerHs_28 pmTransmittedCarrierPowerHs_29 pmTransmittedCarrierPowerHs_30 pmTransmittedCarrierPowerHs_31
        pmTransmittedCarrierPowerHs_32 pmTransmittedCarrierPowerHs_33 pmTransmittedCarrierPowerHs_34 pmTransmittedCarrierPowerHs_35
        pmTransmittedCarrierPowerHs_36 pmTransmittedCarrierPowerHs_37 pmTransmittedCarrierPowerHs_38 pmTransmittedCarrierPowerHs_39
        pmTransmittedCarrierPowerHs_40 pmTransmittedCarrierPowerHs_41 pmTransmittedCarrierPowerHs_42 pmTransmittedCarrierPowerHs_43
        pmTransmittedCarrierPowerHs_44 pmTransmittedCarrierPowerHs_45 pmTransmittedCarrierPowerHs_46 pmTransmittedCarrierPowerHs_47
        pmTransmittedCarrierPowerHs_48 pmTransmittedCarrierPowerHs_49 pmTransmittedCarrierPowerHs_50 pmTransmittedCarrierPowerHs_51
        pmTransmittedCarrierPowerNonHs_0 pmTransmittedCarrierPowerNonHs_1 pmTransmittedCarrierPowerNonHs_2
        pmTransmittedCarrierPowerNonHs_3 pmTransmittedCarrierPowerNonHs_4 pmTransmittedCarrierPowerNonHs_5
        pmTransmittedCarrierPowerNonHs_6 pmTransmittedCarrierPowerNonHs_7 pmTransmittedCarrierPowerNonHs_8
        pmTransmittedCarrierPowerNonHs_9 pmTransmittedCarrierPowerNonHs_10 pmTransmittedCarrierPowerNonHs_11
        pmTransmittedCarrierPowerNonHs_12 pmTransmittedCarrierPowerNonHs_13 pmTransmittedCarrierPowerNonHs_14
        pmTransmittedCarrierPowerNonHs_15 pmTransmittedCarrierPowerNonHs_16 pmTransmittedCarrierPowerNonHs_17
        pmTransmittedCarrierPowerNonHs_18 pmTransmittedCarrierPowerNonHs_19 pmTransmittedCarrierPowerNonHs_20
        pmTransmittedCarrierPowerNonHs_21 pmTransmittedCarrierPowerNonHs_22 pmTransmittedCarrierPowerNonHs_23
        pmTransmittedCarrierPowerNonHs_24 pmTransmittedCarrierPowerNonHs_25 pmTransmittedCarrierPowerNonHs_26
        pmTransmittedCarrierPowerNonHs_27 pmTransmittedCarrierPowerNonHs_28 pmTransmittedCarrierPowerNonHs_29
        pmTransmittedCarrierPowerNonHs_30 pmTransmittedCarrierPowerNonHs_31 pmTransmittedCarrierPowerNonHs_32
        pmTransmittedCarrierPowerNonHs_33 pmTransmittedCarrierPowerNonHs_34 pmTransmittedCarrierPowerNonHs_35
        pmTransmittedCarrierPowerNonHs_36 pmTransmittedCarrierPowerNonHs_37 pmTransmittedCarrierPowerNonHs_38
        pmTransmittedCarrierPowerNonHs_39 pmTransmittedCarrierPowerNonHs_40 pmTransmittedCarrierPowerNonHs_41
        pmTransmittedCarrierPowerNonHs_42 pmTransmittedCarrierPowerNonHs_43 pmTransmittedCarrierPowerNonHs_44
        pmTransmittedCarrierPowerNonHs_45 pmTransmittedCarrierPowerNonHs_46 pmTransmittedCarrierPowerNonHs_47
        pmTransmittedCarrierPowerNonHs_48 pmTransmittedCarrierPowerNonHs_49 pmTransmittedCarrierPowerNonHs_50
        pmTransmittedCarrierPowerNonHs_51
        pmUsedCqi_0 pmUsedCqi_1 pmUsedCqi_2 pmUsedCqi_3 pmUsedCqi_4 pmUsedCqi_5 pmUsedCqi_6 pmUsedCqi_7 pmUsedCqi_8 pmUsedCqi_9
        pmUsedCqi_10 pmUsedCqi_11 pmUsedCqi_12 pmUsedCqi_13 pmUsedCqi_14 pmUsedCqi_15 pmUsedCqi_16 pmUsedCqi_17 pmUsedCqi_18
        pmUsedCqi_19 pmUsedCqi_20 pmUsedCqi_21 pmUsedCqi_22 pmUsedCqi_23 pmUsedCqi_24 pmUsedCqi_25 pmUsedCqi_26 pmUsedCqi_27
        pmUsedCqi_28 pmUsedCqi_29 pmUsedCqi_30 pmUsedCqi_31
        pmUsedHsPdschCodes_0 pmUsedHsPdschCodes_1 pmUsedHsPdschCodes_2 pmUsedHsPdschCodes_3 pmUsedHsPdschCodes_4
        pmUsedHsPdschCodes_5 pmUsedHsPdschCodes_6 pmUsedHsPdschCodes_7 pmUsedHsPdschCodes_8 pmUsedHsPdschCodes_9
        pmUsedHsPdschCodes_10 pmUsedHsPdschCodes_11 pmUsedHsPdschCodes_12 pmUsedHsPdschCodes_13 pmUsedHsPdschCodes_14
        pmUsedHsPdschCodes_15
        pmUsedTbs16Qam_0 pmUsedTbs16Qam_1 pmUsedTbs16Qam_2 pmUsedTbs16Qam_3 pmUsedTbs16Qam_4 pmUsedTbs16Qam_5 pmUsedTbs16Qam_6
        pmUsedTbs16Qam_7 pmUsedTbs16Qam_8 pmUsedTbs16Qam_9 pmUsedTbs16Qam_10 pmUsedTbs16Qam_11 pmUsedTbs16Qam_12
        pmUsedTbs16Qam_13 pmUsedTbs16Qam_14 pmUsedTbs16Qam_15 pmUsedTbs16Qam_16 pmUsedTbs16Qam_17 pmUsedTbs16Qam_18
        pmUsedTbs16Qam_19 pmUsedTbs16Qam_20 pmUsedTbs16Qam_21 pmUsedTbs16Qam_22 pmUsedTbs16Qam_23 pmUsedTbs16Qam_24
        pmUsedTbs16Qam_25 pmUsedTbs16Qam_26 pmUsedTbs16Qam_27 pmUsedTbs16Qam_28 pmUsedTbs16Qam_29
        pmUsedTbs64Qam_0 pmUsedTbs64Qam_1 pmUsedTbs64Qam_2 pmUsedTbs64Qam_3 pmUsedTbs64Qam_4 pmUsedTbs64Qam_5
        pmUsedTbs64Qam_6 pmUsedTbs64Qam_7 pmUsedTbs64Qam_8 pmUsedTbs64Qam_9 pmUsedTbs64Qam_10 pmUsedTbs64Qam_11
        pmUsedTbs64Qam_12 pmUsedTbs64Qam_13 pmUsedTbs64Qam_14 pmUsedTbs64Qam_15 pmUsedTbs64Qam_16 pmUsedTbs64Qam_17
        pmUsedTbs64Qam_18 pmUsedTbs64Qam_19 pmUsedTbs64Qam_20 pmUsedTbs64Qam_21 pmUsedTbs64Qam_22 pmUsedTbs64Qam_23
        pmUsedTbs64Qam_24 pmUsedTbs64Qam_25 pmUsedTbs64Qam_26 pmUsedTbs64Qam_27 pmUsedTbs64Qam_28 pmUsedTbs64Qam_29
        pmUsedTbsQpsk_0 pmUsedTbsQpsk_1 pmUsedTbsQpsk_2 pmUsedTbsQpsk_3 pmUsedTbsQpsk_4 pmUsedTbsQpsk_5 pmUsedTbsQpsk_6
        pmUsedTbsQpsk_7 pmUsedTbsQpsk_8 pmUsedTbsQpsk_9 pmUsedTbsQpsk_10 pmUsedTbsQpsk_11 pmUsedTbsQpsk_12 pmUsedTbsQpsk_13
        pmUsedTbsQpsk_14 pmUsedTbsQpsk_15 pmUsedTbsQpsk_16 pmUsedTbsQpsk_17 pmUsedTbsQpsk_18 pmUsedTbsQpsk_19
        pmUsedTbsQpsk_20 pmUsedTbsQpsk_21 pmUsedTbsQpsk_22 pmUsedTbsQpsk_23 pmUsedTbsQpsk_24 pmUsedTbsQpsk_25
        pmUsedTbsQpsk_26 pmUsedTbsQpsk_27 pmUsedTbsQpsk_28 pmUsedTbsQpsk_29
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_HsDschResources',
    INPUT_FILE_DESCRIPTION     => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT\.pif$',], # P7.1 FP1
    SPLIT_CNAMES               => {
        'PDF'  => [
            '^(pmAck16Qam|pmAck64Qam|pmAckQpsk|pmAverageUserRate|pmCapacityHsDschUsers|pmCapacityHsPdschCodes|pmDelayDistributionSpi00|pmDelayDistributionSpi01|pmDelayDistributionSpi02|pmDelayDistributionSpi03|pmDelayDistributionSpi04|pmDelayDistributionSpi05|pmDelayDistributionSpi06|pmDelayDistributionSpi07|pmDelayDistributionSpi08|pmDelayDistributionSpi09|pmDelayDistributionSpi10|pmDelayDistributionSpi11|pmDelayDistributionSpi12|pmDelayDistributionSpi13|pmDelayDistributionSpi14|pmDelayDistributionSpi15)_\d+$',
        ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier', 'moid_HsDschResources',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_HsDschResources',
    INPUT_FILE_DESCRIPTION     => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT-#-PDF-#-FSC\.pif$',], # P7.1 FP1
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_HsDschResources',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_HsDschResources set

# Accumulate pmSumTransmittedBitsSpi counters up to Sector level for HsDschResources blocks
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate pmSumTransmittedBitsSpi counters up to Sector level for HsDschResources blocks',
        #INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-J-#-TOT\.pif$',],
        INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT\.pif$',], # P7.1 FP1
        COUNTERS_TO_SORT_ON    => ['moid_ManagedElement','moid_NodeBFunction','moid_Sector','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_ManagedElement','moid_NodeBFunction','moid_Sector','moid_Carrier','moid_HsDschResources','UtranCell_id','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ME_NodeBFunction_HsDschResources',
        OUTPUT_FILENAME_START  => 'ME_NodeBFunction_HsDschResources',
        PRODUCE_PIF            => 'True',
},

# JOIN UtranCell files
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of UtranCell files',
        INPUT_FILE_DESCRIPTION  => [
            '^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction_UtranCell_Rach-#-(.+)-#-\d+-#-I\.pif$',
        ],
        COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction', 'moid_UtranCell'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell2',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        PRODUCE_PIF            => 'True',
},

# Insert Tot_pmSumTransmittedBitsSpi from ME_NodeBFunction_HsDschResources block
{
    RULE_TYPE                           => 'INFOINSERT',
    RULE_DESC                           => 'Insert Tot_pmSumTransmittedBitsSpi from ME_NodeBFunction_HsDschResources block',
    INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UtranCell2-#-.+-#-.+-#-.+-#-.+-#-J\.pif$'],
    HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_SubNetwork'],
    NAMES_USED_TO_ID_DATA_RECORD        => ['moid_UtranCell','mts'],
    #INFO_FILE_DESCRIPTION               => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-J-#-TOT-#-ME_NodeBFunction_HsDschResources-#-A\.pif$'],
    INFO_FILE_DESCRIPTION               => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT-#-ME_NodeBFunction_HsDschResources-#-A\.pif$'], # P7.1 FP1
    HEADER_NAMES_USED_TO_ID_INFORMATION => ['nedn_SubNetwork'],
    NAMES_USED_TO_ID_INFORMATION        => ['UtranCell_id','mts'],
    REDUNDANT_DATA_COUNTERS             => [],
    ONLY_INSERT                         => ['Tot_pmSumTransmittedBitsSpi'],
    WRITE_DATA_LINE                     => 'True',
    PRODUCE_PIF                         => 'True',
    REMOVE_INFO_FILES                   => 'True',
    REMOVE_INPUT_FILES                  => 'True',
},

# Uncomment the rule, alm00227772
# No need to join initial pif and pif after INFORINSERT - P7.1 FP1
# Join all ManagedElement_RncFunction_UtranCell PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
{
   RULE_TYPE                  => 'JOIN',
   RULE_DESC                  => 'Join all ManagedElement_RncFunction_UtranCell PIF files into one single PIF file',
   INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_RncFunction_UtranCell2-#-.+-#-.+-#-.+-#-.+)-#-(J|J-#-S)\.pif$' ],
   COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_RncFunction moid_UtranCell ) ],
   HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
   OUTPUT_FILENAME_START      => 'ManagedElement_RncFunction_UtranCell3',
   HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
   OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell',
   PRODUCE_PIF                => 'True',
},

# Insert NodeB MeContext from hierarchy PIF into UtranCell block
# Note: The "vsDataRbsLocalCell-#-.+-#-J-#-S\.pif" file must be generated using the hierarchy parser first
{
    RULE_TYPE                           => 'INFOINSERT',
    RULE_DESC                           => 'Insert NodeB MeContext from hierarchy PIF into UtranCell block',
    #INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UtranCell3-#-.+-#-.+-#-.+-#-.+-#-J\.pif$'],
    #INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UtranCell2-#-.+-#-.+-#-.+-#-.+-#-J-#-S\.pif$'], # P7.1 FP1
	INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UtranCell3-#-.+-#-.+-#-.+-#-.+-#-J\.pif$'], #alm00227772
    HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_SubNetwork'],
    NAMES_USED_TO_ID_DATA_RECORD        => ['moid_UtranCell'],
    INFO_FILE_DESCRIPTION               => ['^vsDataRbsLocalCell-#-.+-#-J-#-S\.pif$'],
    HEADER_NAMES_USED_TO_ID_INFORMATION => [],
    NAMES_USED_TO_ID_INFORMATION        => ['carrierRef_SubNetwork_1','UtranCell_id'],
    REDUNDANT_DATA_COUNTERS             => [],
    ONLY_INSERT                         => ['carrierRef_MeContext'],
    WRITE_DATA_LINE                     => 'True',
    PRODUCE_PIF                         => 'True',
    REMOVE_INPUT_FILES                  => 'True',
	#commented in P7.1, FP3
    #OUTPUT_BLOCK_NAME                   => 'ManagedElement_RncFunction_UtranCell', #alm00227772
    #OUTPUT_FILENAME_START               => 'ManagedElement_RncFunction_UtranCell', #alm00227772
},

# Uncomment the rule, alm00227772
# No need to join initial pif and pif after INFORINSERT - P7.1 FP1
# Join all ManagedElement_RncFunction_UtranCell PIF files into one single PIF file
# This ensures a single PIF file is produced all the time after INFOINSERT rule
{
   RULE_TYPE                  => 'JOIN',
   RULE_DESC                  => 'Join all ManagedElement_RncFunction_UtranCell PIF files into one single PIF file',
   INPUT_FILE_DESCRIPTION     => [ '^(ManagedElement_RncFunction_UtranCell3-#-.+-#-.+-#-.+-#-.+)-#-(J|J-#-S)\.pif$' ],
   COUNTERS_TO_JOIN_ON        => [ qw( moid_ManagedElement moid_RncFunction moid_UtranCell ) ],
   HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
   OUTPUT_FILENAME_START      => 'ManagedElement_RncFunction_UtranCell',
   HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
   OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell',
   PRODUCE_PIF                => 'True',
},

# Calculate Cell Total Traffic
{
    RULE_TYPE                  => 'PERLIZE',
    RULE_DESC                  => 'Calculate Cell Total Traffic',
    #INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
    #INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-.+-#-.+-#-.+-#-J-#-S-#-S\.pif$', # P7.1 FP1
	INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-.+-#-.+-#-.+-#-J\.pif$', #alm00227772
    DATA_COUNTERS_OP           => sub
    {
        my $c_ref = shift;
        my @c_names = qw( pmDlTrafficVolumeAmr4750 pmDlTrafficVolumeAmr5900 pmDlTrafficVolumeAmr7950 pmDlTrafficVolumeCs12
                          pmDlTrafficVolumeCs57 pmDlTrafficVolumeCs64 pmDlTrafficVolumePs8 pmDlTrafficVolumePs64
                          pmDlTrafficVolumePs128 pmDlTrafficVolumePs384 pmDlTrafficVolumePsCommon pmDlTrafficVolumePsStr16
                          pmDlTrafficVolumePsStr128 pmDlTrafficVolumePsStr64 pmUlTrafficVolumeAmr4750 pmUlTrafficVolumeAmr5900
                          pmUlTrafficVolumeAmr7950 pmUlTrafficVolumeCs12 pmUlTrafficVolumeCs57 pmUlTrafficVolumeCs64
                          pmUlTrafficVolumePs8 pmUlTrafficVolumePs64 pmUlTrafficVolumePs128 pmUlTrafficVolumePs384
                          pmUlTrafficVolumePsCommon pmUlTrafficVolumePsStr16 pmUlTrafficVolumePsStr128 pmDlTrafficVolumePsStrMbms128
                          pmDlTrafficVolumePsStrMbms256 pmDlTrafficVolumePsStrMbms64 pmDlTrafficVolumeAmrWb pmDlTrafficVolumePs16
                          pmDlTrafficVolumePsIntHs pmDlTrafficVolumePsStrHs pmUlTrafficVolumeAmrWb pmUlTrafficVolumePs16
                          pmUlTrafficVolumePsIntEul pmUlTrafficVolumePsStr32 Tot_pmSumTransmittedBitsSpi );
        my $total_cell_traffic = 0;

        foreach my $c_name (@c_names) {
            if ( exists $c_ref->{$c_name} ) {
                $total_cell_traffic += $c_ref->{$c_name};
                $c_ref->{Cell_Total_Traffic} = $total_cell_traffic;
            }
        }

        if ( exists $c_ref->{carrierRef_MeContext} ) {
            $c_ref->{nedn_MeContext_NodeB} = $c_ref->{carrierRef_MeContext};
            $c_ref->{carrierRef_MeContext} = "";
        }

        ## 8 Aug 2008, LX, VN, section 6.2.3
        ## Deriving new counter Avg_number_RL_User
        my $Avg_number_RL_User=0;
        my $denominator=0;

        $denominator = $c_ref->{pmSumUesWith2Rls4RlInActSet} + $c_ref->{pmSumUesWith3Rls4RlInActSet} +
						$c_ref->{pmSumUesWith4Rls4RlInActSet} + $c_ref->{pmSumUesWith1Rls1RlInActSet} +
						$c_ref->{pmSumUesWith1Rls2RlInActSet} + $c_ref->{pmSumUesWith2Rls2RlInActSet} +
						$c_ref->{pmSumUesWith1Rls3RlInActSet} + $c_ref->{pmSumUesWith2Rls3RlInActSet} +
						$c_ref->{pmSumUesWith3Rls3RlInActSet};

		### DEBUGGING ONLY
		#LogMess ("LX: pmNoOfSampAseDl=[$c_ref->{pmNoOfSampAseDl}]",5);
		#
		#LogMess ("
		#	pmSumUesWith2Rls4RlInActSet = [$c_ref->{pmSumUesWith2Rls4RlInActSet}],
		#	pmSumUesWith3Rls4RlInActSet = [$c_ref->{pmSumUesWith3Rls4RlInActSet}],
		#	pmSumUesWith4Rls4RlInActSet = [$c_ref->{pmSumUesWith4Rls4RlInActSet}],
		#	pmSumUesWith1Rls1RlInActSet = [$c_ref->{pmSumUesWith1Rls1RlInActSet}],
		#	pmSumUesWith1Rls2RlInActSet = [$c_ref->{pmSumUesWith1Rls2RlInActSet}],
		#	pmSumUesWith2Rls2RlInActSet = [$c_ref->{pmSumUesWith2Rls2RlInActSet}],
		#	pmSumUesWith1Rls3RlInActSet = [$c_ref->{pmSumUesWith1Rls3RlInActSet}],
		#	pmSumUesWith2Rls3RlInActSet = [$c_ref->{pmSumUesWith2Rls3RlInActSet}],
		#	pmSumUesWith3Rls3RlInActSet = [$c_ref->{pmSumUesWith3Rls3RlInActSet}],
		#",5);
		#LogMess ("DEBUG: DENOMINATOR = [$denominator]",5);
		#
		#my ($value_A, $value_B, $value_C);
		#
		#$value_A = 4 * (
    	#				$c_ref->{pmSumUesWith2Rls4RlInActSet} + $c_ref->{pmSumUesWith3Rls4RlInActSet} +
    	#				$c_ref->{pmSumUesWith4Rls4RlInActSet}
    	#			);
    	#
		#LogMess ("pmSumUesWith2Rls4RlInActSet = [$c_ref->{pmSumUesWith2Rls4RlInActSet}],
		#	pmSumUesWith3Rls4RlInActSet = [$c_ref->{pmSumUesWith3Rls4RlInActSet}],
		#	pmSumUesWith4Rls4RlInActSet = [$c_ref->{pmSumUesWith4Rls4RlInActSet}],
		#	value_A = [$value_A]",5);
		#
		#LogMess ("pmSumUesWith1Rls1RlInActSet = [$c_ref->{pmSumUesWith1Rls1RlInActSet}]",5);
		#
		#$value_B = 2 * (
    	#				$c_ref->{pmSumUesWith1Rls2RlInActSet} + $c_ref->{pmSumUesWith2Rls2RlInActSet}
    	#			);
    	#
		#LogMess ("
		#	pmSumUesWith1Rls2RlInActSet = [$c_ref->{pmSumUesWith1Rls2RlInActSet}],
		#	pmSumUesWith2Rls2RlInActSet = [$c_ref->{pmSumUesWith2Rls2RlInActSet}],
		#	value_B = [$value_B]",5);
		#
		#$value_C = 	3 * (
		#				$c_ref->{pmSumUesWith1Rls3RlInActSet} + $c_ref->{pmSumUesWith2Rls3RlInActSet} +
		#				$c_ref->{pmSumUesWith3Rls3RlInActSet}
		#			);
		#
		#LogMess ("
		#	pmSumUesWith1Rls3RlInActSet = [$c_ref->{pmSumUesWith1Rls3RlInActSet}],
		#	pmSumUesWith2Rls3RlInActSet = [$c_ref->{pmSumUesWith2Rls3RlInActSet}],
		#	pmSumUesWith3Rls3RlInActSet = [$c_ref->{pmSumUesWith3Rls3RlInActSet}],
		#	value_C = [$value_C]",5);

		## end of DEBUGGING

		if ($denominator != 0) {
			$Avg_number_RL_User =
        	(
        		(
        			4 * (
    					$c_ref->{pmSumUesWith2Rls4RlInActSet} + $c_ref->{pmSumUesWith3Rls4RlInActSet} +
    					$c_ref->{pmSumUesWith4Rls4RlInActSet}
    				)
        		)
        		+ $c_ref->{pmSumUesWith1Rls1RlInActSet} +
        		(
        			2 *	(
    					$c_ref->{pmSumUesWith1Rls2RlInActSet} + $c_ref->{pmSumUesWith2Rls2RlInActSet}
    				)
        		)
				+
				(
					3 * (
						$c_ref->{pmSumUesWith1Rls3RlInActSet} + $c_ref->{pmSumUesWith2Rls3RlInActSet} +
						$c_ref->{pmSumUesWith3Rls3RlInActSet}
					)
				)
			) ## valnt00055416 - 23 Sept 2008 - LX - missing parentheses causing value to be wrong.
			/ (
				$c_ref->{pmSumUesWith2Rls4RlInActSet} + $c_ref->{pmSumUesWith3Rls4RlInActSet} +
				$c_ref->{pmSumUesWith4Rls4RlInActSet} + $c_ref->{pmSumUesWith1Rls1RlInActSet} +
				$c_ref->{pmSumUesWith1Rls2RlInActSet} + $c_ref->{pmSumUesWith2Rls2RlInActSet} +
				$c_ref->{pmSumUesWith1Rls3RlInActSet} + $c_ref->{pmSumUesWith2Rls3RlInActSet} +
				$c_ref->{pmSumUesWith3Rls3RlInActSet}
			);
		}
		else {
			LogMess ("WARNING: Denominator is zero. Set counter [Avg_number_RL_User] value to 0.",5);
		}

		## if put inside the if statement, RncFunction & Overview will not output this counter correctly.
		$c_ref->{Avg_number_RL_User} = $Avg_number_RL_User;

		## DEBUGGING ONLY
		#LogMess ("Avg_number_RL_User=[$c_ref->{Avg_number_RL_User}]",5);
		##

        ## Deriving new counter Avg_dl_speech_codes_active
        my $Avg_dl_speech_codes_active=0;

        if ($c_ref->{pmSamplesCs12RabEstablish} != 0 &&
        	$c_ref->{pmSamplesAmr4750RabEstablish} != 0 &&
        	$c_ref->{pmSamplesAmr5900RabEstablish} != 0 &&
        	$c_ref->{pmSamplesAmr7950RabEstablish} != 0 &&
        	$c_ref->{pmSamplesAmr12200RabEstablish} != 0
        ) {
	        $Avg_dl_speech_codes_active =
	        (
	        	($c_ref->{pmSumCs12RabEstablish}/$c_ref->{pmSamplesCs12RabEstablish})
		        + ($c_ref->{pmSumAmr4750RabEstablish}/$c_ref->{pmSamplesAmr4750RabEstablish})
		        + ($c_ref->{pmSumAmr5900RabEstablish}/$c_ref->{pmSamplesAmr5900RabEstablish})
		        + ($c_ref->{pmSumAmr7950RabEstablish}/$c_ref->{pmSamplesAmr7950RabEstablish})
		        + ($c_ref->{pmSumAmr12200RabEstablish}/$c_ref->{pmSamplesAmr12200RabEstablish})
	        );
        }
        else {
	     	LogMess ("Either one of the counter is 0, pmSamplesCs12RabEstablish=[$c_ref->{\"pmSamplesCs12RabEstablish\"}],
	     		pmSamplesAmr4750RabEstablish=[$c_ref->{\"pmSamplesAmr4750RabEstablish\"}],
	     		pmSamplesAmr5900RabEstablish=[$c_ref->{\"pmSamplesAmr5900RabEstablish\"}],
	     		pmSamplesAmr7950RabEstablish=[$c_ref->{\"pmSamplesAmr7950RabEstablish\"}],
	     		pmSamplesAmr12200RabEstablish=[$c_ref->{\"pmSamplesAmr12200RabEstablish\"}]",5);
        }

        $c_ref->{Avg_dl_speech_codes_active} = $Avg_dl_speech_codes_active;

        ## end of VN

        ## Reindex the following PDF counters by incrementing the index by 1.
        ## pmEulHarqTransmTti10PsRabs
        ## pmEulHarqTransmTti10Srb
        ## pmEulHarqTransmTti2PsRabs
        ## pmEulHarqTransmTti2Srb
        ## e.g.
        ## pmEulHarqTransmTti2Srb_0 reindexed to pmEulHarqTransmTti2Srb_1
        ## pmEulHarqTransmTti2Srb_1 reindexed to pmEulHarqTransmTti2Srb_2
        ## ...

        # Hash of counters to reindex consisting of pairs:
        # 'counter_name' => max_index
        my %reindex_counters = (
                'pmEulHarqTransmTti10PsRabs' => 4,
                'pmEulHarqTransmTti10Srb'    => 4,
                'pmEulHarqTransmTti2PsRabs'  => 4,
                'pmEulHarqTransmTti2Srb'     => 4,
        );

        # Loop through counters that require reindexing and rename counters
        foreach my $counter (%reindex_counters) {
                for (my $i = $reindex_counters{$counter}; $i > 0; $i--) {
                        my $cindex = $i - 1;
                        my $ocounter = "${counter}_${cindex}";
                        my $ncounter = "${counter}_${i}";
                        if ( exists $c_ref->{"$ocounter"} ) {
                                $c_ref->{"$ncounter"} = $c_ref->{"$ocounter"};
                                delete $c_ref->{$ocounter};
                        }
                }
        }

        ## End counter reindexing

        return 0;
    },
    FILENAME_SUFFIX            => 'CTT',
    PRODUCE_PIF                => 'True',
    # Do not output LIF first. Need to split & filter out PDF counters.
    #OUTPUT_FORMAT              => 'LIF_Writer',
},

## Split PDF counter
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncFunction_UtranCell',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '?(pmDchDlRlcUserPacketThp|pmDchUlRlcUserPacketThp|pmEulHarqTransmTti10PsRabs|pmEulHarqTransmTti10Srb|pmEulHarqTransmTti2PsRabs|pmEulHarqTransmTti2Srb|pmRes1|pmRes10|pmRes11|pmRes12|pmRes2|pmRes3|pmRes4|pmRes5|pmRes6|pmRes7|pmRes8|pmRes9|pmSamplesPacketDlDelay|pmSamplesPacketLatency|pmSamplesPacketLatencyPsStreamHs|pmSumPacketDlDelay|pmSumPacketLatency|pmSumPacketLatencyPsStreamHs|pmTotNoRrcConnectUeCapability)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmDchDlRlcUserPacketThp_0 pmDchDlRlcUserPacketThp_1 pmDchDlRlcUserPacketThp_2 pmDchDlRlcUserPacketThp_3
        pmDchDlRlcUserPacketThp_4 pmDchDlRlcUserPacketThp_5 pmDchDlRlcUserPacketThp_6 pmDchDlRlcUserPacketThp_7
        pmDchDlRlcUserPacketThp_8 pmDchDlRlcUserPacketThp_9 pmDchDlRlcUserPacketThp_10 pmDchDlRlcUserPacketThp_11
        pmDchDlRlcUserPacketThp_12 pmDchDlRlcUserPacketThp_13 pmDchDlRlcUserPacketThp_14 pmDchDlRlcUserPacketThp_15
        pmDchDlRlcUserPacketThp_16 pmDchDlRlcUserPacketThp_17 pmDchDlRlcUserPacketThp_18 pmDchDlRlcUserPacketThp_19
        pmDchUlRlcUserPacketThp_0 pmDchUlRlcUserPacketThp_1 pmDchUlRlcUserPacketThp_2 pmDchUlRlcUserPacketThp_3
        pmDchUlRlcUserPacketThp_4 pmDchUlRlcUserPacketThp_5 pmDchUlRlcUserPacketThp_6 pmDchUlRlcUserPacketThp_7
        pmDchUlRlcUserPacketThp_8 pmDchUlRlcUserPacketThp_9 pmDchUlRlcUserPacketThp_10 pmDchUlRlcUserPacketThp_11
        pmDchUlRlcUserPacketThp_12 pmDchUlRlcUserPacketThp_13 pmDchUlRlcUserPacketThp_14 pmDchUlRlcUserPacketThp_15
        pmDchUlRlcUserPacketThp_16 pmDchUlRlcUserPacketThp_17 pmDchUlRlcUserPacketThp_18 pmDchUlRlcUserPacketThp_19
        pmEulHarqTransmTti10PsRabs_1 pmEulHarqTransmTti10PsRabs_2 pmEulHarqTransmTti10PsRabs_3 pmEulHarqTransmTti10PsRabs_4
        pmEulHarqTransmTti10Srb_1 pmEulHarqTransmTti10Srb_2 pmEulHarqTransmTti10Srb_3 pmEulHarqTransmTti10Srb_4
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncFUnction_UtranCell',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$',
    SPLIT_CNAMES               => {
        'PDF' => [ '^(pmDchDlRlcUserPacketThp|pmDchUlRlcUserPacketThp|pmEulHarqTransmTti10PsRabs|pmEulHarqTransmTti10Srb|pmEulHarqTransmTti2PsRabs|pmEulHarqTransmTti2Srb|pmRes1|pmRes10|pmRes11|pmRes12|pmRes2|pmRes3|pmRes4|pmRes5|pmRes6|pmRes7|pmRes8|pmRes9|pmSamplesPacketDlDelay|pmSamplesPacketLatency|pmSamplesPacketLatencyPsStreamHs|pmSumPacketDlDelay|pmSumPacketLatency|pmSumPacketLatencyPsStreamHs|pmTotNoRrcConnectUeCapability)_\d+$', '(?<!carrierRef_SubNetwork)_\d+$' ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext_NodeB', 'moid_UtranCell'
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncFunction_UtranCell',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell',
    OUTPUT_FORMAT              => 'LIF_Writer',
},

{
    RULE_TYPE               => 'PIF_REMOVE',
    RULE_DESC               => 'Remove split PDF base files',
    #INPUT_FILE_DESCRIPTION  => [ '^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-(CTT|CTT-#-PDF-#-FSC)\.pif', ],
	INPUT_FILE_DESCRIPTION  => [ '^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT-#-PDF-#-FSC\.pif', ], #alm00227772
},
## End split PDF counter

## 7 Aug 2008, LX, VN, section 6.2.2
{
    RULE_TYPE                  => 'JOIN',
    RULE_DESC                  => 'Join all ManagedElement_RncFunction_UtranCell PIF files into one single PIF file',
    INPUT_FILE_DESCRIPTION     => [
    	#'^ManagedElement_RncFunction_UtranCell-#-.+-#-(RNC\d+-#-\d{14}Z)-#-.+-#-J-#-CTT\.pif$',
        #'^ManagedElement_RncFunction_UtranCell-#-.+-#-(RNC\d+-#-\d{14}Z)-#-.+-#-J-#-S-#-S-#-CTT\.pif$', # P7.1 FP1
		'^ManagedElement_RncFunction_UtranCell-#-.+-#-(RNC\d+-#-\d{14}Z)-#-.+-#-J-#-CTT\.pif$', #alm00227772
    	'^ManagedElement_RncFunction_UtranCell_GsmRelation-#-.*-#-(RNC\d+-#-\d{14}Z)-#-.*-#-I\.pif$',
    	'^ManagedElement_RncFunction_UtranCell_UtranRelation-#-.*-#-(RNC\d+-#-\d{14}Z)-#-.*-#-I\.pif$',
    ],
    COUNTERS_TO_JOIN_ON        => [ qw(moid_UtranCell) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_FILENAME_START      => 'ManagedElement_RncFunction_Overview',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_Overview',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
    PRODUCE_PIF                => 'True',
},

{
	RULE_TYPE              => 'ACCUMULATE',
    RULE_DESC              => 'Accumulate ManagedElement_RncFunction_Overview blocks',
    INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_Overview-#-.*-#-J\.pif$',],
    COUNTERS_TO_SORT_ON    => ['nedn_SubNetwork'],
    NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
    REDUNDANT_COUNTERS     => [],
    OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_Overview',
    PRODUCE_PIF            => 0,
    OUTPUT_FORMAT          => 'LIF_Writer',
},

{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join ',
    INPUT_FILE_DESCRIPTION  => [
    	'^ManagedElement_RncFunction_UtranCell_UtranRelation-#-.+-#-(RNC\d+-#-\d{14}Z)-#-\d+-#-I\.pif$',
    ],
    COUNTERS_TO_JOIN_ON    => [ qw(moid_UtranCell moid_UtranRelation nedn_SubNetwork) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell_UtranRelation_GRP',
    OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell_UtranRelation_GRP',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
    PRODUCE_PIF            => 'True',
},

{
	RULE_TYPE              => 'ACCUMULATE',
    RULE_DESC              => 'Accumulate ManagedElement_RncFunction_UtranCell_UtranRelation to ManagedElement_RncFunction_UtranCell_UtranRelation_GRP block based on moid_UtranCell',
    INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UtranCell_UtranRelation_GRP-#-.*-#-J\.pif$',],
    COUNTERS_TO_SORT_ON    => ['moid_UtranCell'],
    NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork', 'nedn_SubNetwork','moid_UtranCell'],
    REDUNDANT_COUNTERS     => [],
    OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell_UtranRelation_GRP',
    PRODUCE_PIF            => 0,
    OUTPUT_FORMAT          => 'LIF_Writer',
},
## end of VN

# Aggregation of UtranCell files to RNC level
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate UtranCell blocks',
        #INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$',],
        #INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-S-#-S-#-CTT\.pif$',], # P7.1 FP1
		INPUT_FILE_DESCRIPTION  => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$',], #alm00227772
        COUNTERS_TO_SORT_ON    => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_RncFunction','moid_ManagedElement','mts','SubNetwork'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell',
        PRODUCE_PIF            => 'True',
        OUTPUT_FORMAT          => 0,
},

# Insert pmNoDirRetryAtt and pmNoDirRetrySuccess from ManagedElement_RncFunction_UtranCell block - P7
{
    RULE_TYPE                           => 'INFOINSERT',
    RULE_DESC                           => 'Insert pmNoDirRetryAtt and pmNoDirRetrySuccess from ManagedElement_RncFunction_UtranCell block',
    INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UtranCell_GsmRelation-#-.+-#-.+-#-I\.pif$'],
    HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['StartTime', 'StartDate'],
    NAMES_USED_TO_ID_DATA_RECORD        => ['moid_ManagedElement', 'moid_RncFunction', 'moid_UtranCell'],
    #INFO_FILE_DESCRIPTION               => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$'],
    #INFO_FILE_DESCRIPTION               => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-S-#-S-#-CTT\.pif$'], # P7.1 FP1
	INFO_FILE_DESCRIPTION               => ['^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$'], #alm00227772
    HEADER_NAMES_USED_TO_ID_INFORMATION => ['StartTime', 'StartDate'],
    NAMES_USED_TO_ID_INFORMATION        => ['moid_ManagedElement', 'moid_RncFunction', 'moid_UtranCell'],
    REDUNDANT_DATA_COUNTERS             => [],
    ONLY_INSERT                         => ['pmNoDirRetryAtt', 'pmNoDirRetrySuccess'],
    WRITE_DATA_LINE                     => 'True',
    PRODUCE_PIF                         => '0',
    REMOVE_INFO_FILES                   => '0',
    #REMOVE_INPUT_FILES                  => 'True',
    OUTPUT_FORMAT                       => 'LIF_Writer',
},

# Remove joined UtranCell and accumulated PIFs
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove joined UtranCell and accumulated PIFs',
        INPUT_FILE_DESCRIPTION  => [
            '^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction_UtranCell_Rach-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction_UtranCell-#-.+-#-J\.pif$',\
            #'^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-J-#-TOT-#-ME_NodeBFunction_HsDschResources-#-A\.pif$',
               '^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-TOT-#-ME_NodeBFunction_HsDschResources-#-A\.pif$', # P7.1 FP1
            '^(ManagedElement_RncFunction_UtranCell2-#-.+-#-.+-#-.+-#-.+)-#-(J|J-#-S)\.pif$',
            #'^(ManagedElement_RncFunction_UtranCell3-#-.+-#-.+-#-.+-#-.+)-#-(J|J-#-S)\.pif$', # P7.1 FP1
			'^(ManagedElement_RncFunction_UtranCell3-#-.+-#-.+-#-.+-#-.+)-#-(J|J-#-S)\.pif$', #alm00227772
            #'^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$',
            #'^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-S-#-S-#-CTT\.pif$', # P7.1 FP1
			'^ManagedElement_RncFunction_UtranCell-#-.+-#-J-#-CTT\.pif$', #alm00227772
        ],
},

# JOIN RncFunction files
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join of RncFunction files',
        INPUT_FILE_DESCRIPTION  => [
            '^ManagedElement_RncFunction-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction_UePositioning-#-(.+)-#-\d+-#-I\.pif$',
            #'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-J-#-CTT-#-ManagedElement_RncFunction_UtranCell-#-A\.pif$',
            #'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-J-#-S-#-S-#-CTT-#-ManagedElement_RncFunction_UtranCell-#-A\.pif$', # P7.1 FP1
			'^ManagedElement_RncFunction_UtranCell-#-(.+)-#-\d+-#-J-#-CTT-#-ManagedElement_RncFunction_UtranCell-#-A\.pif$', #alm00227772
        ],
        COUNTERS_TO_JOIN_ON    => ['nedn_SubNetwork', 'nedn_MeContext', 'moid_ManagedElement', 'moid_RncFunction'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction',
        OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork', 'nedn_MeContext','mts'],
        ## Split PDF counter
        PRODUCE_PIF            => 'True',
        #OUTPUT_FORMAT   => 'LIF_Writer',
},

# START: ManagedElement_RncFunction set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncFunction',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction-#-.+-#-J\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmIuSccpConRate|pmSamplesDchDchDlRcvDelay|pmSamplesDchDchLatency|pmSamplesDchDlDelay|pmSamplesHsDchDlRcvDelay|pmSamplesHsDchLatency|pmSamplesHsDlDelay|pmSamplesHsDlDelayPsCnvUnk|pmSamplesHsDlDelayPsSpeech|pmSamplesHsEulDlRcvDelay|pmSamplesHsEulLatency|pmSumDchDchDlRcvDelay|pmSumDchDchLatency|pmSumDchDlDelay|pmSumHsDchDlRcvDelay|pmSumHsDchLatency|pmSumHsDlDelay|pmSumHsDlDelayPsCnvUnk|pmSumHsDlDelayPsSpeech|pmSumHsEulDlRcvDelay|pmSumHsEulLatency)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmIuSccpConRate_0 pmIuSccpConRate_1 pmIuSccpConRate_2 pmIuSccpConRate_3 pmIuSccpConRate_4
        pmIuSccpConRate_5 pmIuSccpConRate_6 pmIuSccpConRate_7 pmIuSccpConRate_8 pmIuSccpConRate_9
        pmIuSccpConRate_10 pmIuSccpConRate_11 pmIuSccpConRate_12 pmIuSccpConRate_13 pmIuSccpConRate_14
        pmIuSccpConRate_15 pmIuSccpConRate_16 pmIuSccpConRate_17 pmIuSccpConRate_18 pmIuSccpConRate_19
        pmIuSccpConRate_20 pmIuSccpConRate_21 pmIuSccpConRate_22 pmIuSccpConRate_23 pmIuSccpConRate_24
        pmIuSccpConRate_25 pmIuSccpConRate_26 pmIuSccpConRate_27 pmIuSccpConRate_28 pmIuSccpConRate_29
        pmIuSccpConRate_30 pmIuSccpConRate_31 pmIuSccpConRate_32 pmIuSccpConRate_33 pmIuSccpConRate_34
        pmIuSccpConRate_35 pmIuSccpConRate_36 pmIuSccpConRate_37 pmIuSccpConRate_38 pmIuSccpConRate_39
        pmSamplesDchDchDlRcvDelay_0 pmSamplesDchDchDlRcvDelay_1 pmSamplesDchDchDlRcvDelay_2 pmSamplesDchDchLatency_0
        pmSamplesDchDchLatency_1 pmSamplesDchDchLatency_2
        pmSamplesDchDlDelay_0 pmSamplesDchDlDelay_1 pmSamplesDchDlDelay_2
        pmSamplesHsDchDlRcvDelay_0 pmSamplesHsDchDlRcvDelay_1 pmSamplesHsDchDlRcvDelay_2
        pmSamplesHsDchLatency_0 pmSamplesHsDchLatency_1 pmSamplesHsDchLatency_2
        pmSamplesHsDlDelay_0 pmSamplesHsDlDelay_1 pmSamplesHsDlDelay_2
        pmSamplesHsDlDelayPsCnvUnk_0 pmSamplesHsDlDelayPsCnvUnk_1 pmSamplesHsDlDelayPsCnvUnk_2
        pmSamplesHsDlDelayPsSpeech_0 pmSamplesHsDlDelayPsSpeech_1 pmSamplesHsDlDelayPsSpeech_2
        pmSamplesHsEulDlRcvDelay_0 pmSamplesHsEulDlRcvDelay_1 pmSamplesHsEulDlRcvDelay_2
        pmSamplesHsEulLatency_0 pmSamplesHsEulLatency_1 pmSamplesHsEulLatency_2
        pmSumDchDchDlRcvDelay_0 pmSumDchDchDlRcvDelay_1 pmSumDchDchDlRcvDelay_2
        pmSumDchDchLatency_0 pmSumDchDchLatency_1 pmSumDchDchLatency_2
        pmSumDchDlDelay_0 pmSumDchDlDelay_1 pmSumDchDlDelay_2
        pmSumHsDchDlRcvDelay_0 pmSumHsDchDlRcvDelay_1 pmSumHsDchDlRcvDelay_2
        pmSumHsDchLatency_0 pmSumHsDchLatency_1 pmSumHsDchLatency_2
        pmSumHsDlDelay_0 pmSumHsDlDelay_1 pmSumHsDlDelay_2
        pmSumHsDlDelayPsCnvUnk_0 pmSumHsDlDelayPsCnvUnk_1 pmSumHsDlDelayPsCnvUnk_2
        pmSumHsDlDelayPsSpeech_0 pmSumHsDlDelayPsSpeech_1 pmSumHsDlDelayPsSpeech_2
        pmSumHsEulDlRcvDelay_0 pmSumHsEulDlRcvDelay_1 pmSumHsEulDlRcvDelay_2
        pmSumHsEulLatency_0 pmSumHsEulLatency_1 pmSumHsEulLatency_2
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncFunction',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction-#-.+-#-J\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [
            '^(pmIuSccpConRate|pmSamplesDchDchDlRcvDelay|pmSamplesDchDchLatency|pmSamplesDchDlDelay|pmSamplesHsDchDlRcvDelay|pmSamplesHsDchLatency|pmSamplesHsDlDelay|pmSamplesHsDlDelayPsCnvUnk|pmSamplesHsDlDelayPsSpeech|pmSamplesHsEulDlRcvDelay|pmSamplesHsEulLatency|pmSumDchDchDlRcvDelay|pmSumDchDchLatency|pmSumDchDlDelay|pmSumHsDchDlRcvDelay|pmSumHsDchLatency|pmSumHsDlDelay|pmSumHsDlDelayPsCnvUnk|pmSumHsDlDelayPsSpeech|pmSumHsEulDlRcvDelay|pmSumHsEulLatency)_\d+$',
        ],
            
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork',
    ], # BG
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncFunction',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction-#-.+-#-J-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_RncFunction set

# Remove joined RncFunction initial PIFs
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove joined RncFunction initial PIFs & PDF files',
        INPUT_FILE_DESCRIPTION  => [
            '^ManagedElement_RncFunction-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction_UePositioning-#-(.+)-#-\d+-#-I\.pif$',
            '^ManagedElement_RncFunction-#-(.+)-#-\d+-#-(J|J-#-PDF-#-FSC)\.pif$',
        ],
},

# Transplant nedn_SubNetwork and nedn_MeContext into data segment
# Needed to aggregrate pmSumTransmittedBitsSpi counters to SubNetwork level later
{
        RULE_TYPE                  => 'PERLIZE',
        RULE_DESC                  => 'Transplant nedn_SubNetwork and nedn_MeContext into data segment',
        #INPUT_FILE_DESCRIPTION     =>  ['^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-J-#-TOT\.pif$'],
        INPUT_FILE_DESCRIPTION     =>  ['^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-I-#-S-#-TOT\.pif$'], # P7.1 FP1
        HEADER_COUNTERS_OP         => sub
        {
            my $h_ref = shift;
            $tmp_SubNetwork = "";
            $tmp_MeContext = "";

            if ( exists $h_ref->{nedn_SubNetwork} ) {
                $tmp_SubNetwork = $h_ref->{nedn_SubNetwork};
            }
            if ( exists $h_ref->{nedn_MeContext} ) {
                $tmp_MeContext = $h_ref->{nedn_MeContext};
            }
            return 0;
        },
        DATA_COUNTERS_OP         => sub
        {
            my $c_ref = shift;

            if ( $tmp_SubNetwork ne "" ) {
                $c_ref->{nedn_SubNetwork} = $tmp_SubNetwork;
            }
            if ( $tmp_MeContext ne "" ) {
                $c_ref->{nedn_MeContext} = $tmp_MeContext;
            }
            return 0;
        },
        FILENAME_SUFFIX            => 'TRN',
        PRODUCE_PIF                => 'True',
},

# Join all ME_NodeBFunction_HsDschResources PIF files belonging to same SubNetwork and timestamp
{
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join all ME_NodeBFunction_HsDschResources PIF files belonging to same SubNetwork and timestamp',
        #INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-J-#-TOT-#-TRN\.pif$'],
        INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-I-#-S-#-TOT-#-TRN\.pif$'], # P7.1 FP1
        COUNTERS_TO_JOIN_ON    => [ qw( nedn_MeContext moid_ManagedElement moid_NodeBFunction moid_Sector moid_Carrier moid_HsDschResources ) ],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_BLOCK_NAME      => 'ME_NodeBFunction_HsDschResources',
        OUTPUT_FILENAME_START  => 'ME_NodeBFunction_HsDschResources_ALL',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
        PRODUCE_PIF            => 'True',
},

# Accumulate all counters in the same SubNetwork
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate all counters in the same SubNetwork',
        INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources_ALL-#-.+-(#-.+-#-.+-#)-.+-#-J\.pif$'],
        COUNTERS_TO_SORT_ON    => ['nedn_subNetwork'],
        NON_ADDITIVE_COUNTERS  => ['moid_ManagedElement','moid_NodeBFunction','moid_Sector','moid_Carrier','moid_HsDschResources','UtranCell_id','mts','nedn_SubNetwork','nedn_MeContext'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'ME_NodeBFunction_HsDschResources',
        OUTPUT_FILENAME_START  => 'ME_NodeBFunction_HsDschResources',
        PRODUCE_PIF            => 'True',
},

# Insert Tot_pmSumTransmittedBitsSpi from ME_NodeBFunction_HsDschResources block to UeRc_ACCUM
{
        RULE_TYPE                           => 'INFOINSERT',
        RULE_DESC                           => 'Insert Tot_pmSumTransmittedBitsSpi from ME_NodeBFunction_HsDschResources block to UeRc_ACCUM',
        INPUT_FILE_DESCRIPTION              => ['^ManagedElement_RncFunction_UeRc-#-.+-#-.+-#-.+-#-.+-#-J-#-ManagedElement_RncFunction_UeRc_ACCUM-#-A\.pif$'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['nedn_SubNetwork'],
        NAMES_USED_TO_ID_DATA_RECORD        => ['mts'],
        INFO_FILE_DESCRIPTION               => ['^ME_NodeBFunction_HsDschResources_ALL-#-.+-(#-.+-#-.+-#)-.+-#-J-#-ME_NodeBFunction_HsDschResources-#-A\.pif$'],
        HEADER_NAMES_USED_TO_ID_INFORMATION => ['nedn_SubNetwork'],
        NAMES_USED_TO_ID_INFORMATION        => ['mts'],
        REDUNDANT_DATA_COUNTERS             => [],
        ONLY_INSERT                         => ['Tot_pmSumTransmittedBitsSpi'],
        WRITE_DATA_LINE                     => 'True',
        PRODUCE_PIF                         => 0,
        REMOVE_INFO_FILES                   => 'True',
        REMOVE_INPUT_FILES                  => 'True',
        OUTPUT_FORMAT                       => 'LIF_Writer',
},

# Remove PIFs files
{
        RULE_TYPE                  => 'PIF_REMOVE',
        RULE_DESC                  => 'Remove PIFs files',
        INPUT_FILE_DESCRIPTION  => [
            #'^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-J-#-TOT-#-TRN\.pif$',
            '^ME_NodeBFunction_HsDschResources-#-.+-(#-.+-#-.+-#)-.+-#-I-#-S-#-TOT-#-TRN\.pif$', # P7.1 FP1
            '^ME_NodeBFunction_HsDschResources_ALL-#-.+-(#-.+-#-.+-#)-.+-#-J\.pif$',
            '^ManagedElement_RncFunction_UeRc-#-.+-#-.+-#-.+-#-.+-#-J-#-ManagedElement_RncFunction_UeRc_ACCUM-#-A\.pif$',
        ],
},

# START : NodeB_DLBasebandPool
# Aggregation of pmApomcOfSpreadersUsed counter
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Accumulate NodeB_DLBasebandPool blocks',
        INPUT_FILE_DESCRIPTION  => ['^NodeB_DLBasebandPool-#-.+-#-\d+-#-I\.pif$',],
        COUNTERS_TO_SORT_ON    => ['moid_ManagedElement','moid_Equipment','moid_Subrack','moid_DownlinkBaseBandPool','mts'],
        NON_ADDITIVE_COUNTERS  => ['moid_ManagedElement','moid_Equipment','moid_Subrack','moid_DownlinkBaseBandPool','mts'],
        REDUNDANT_COUNTERS     => [],
        OUTPUT_BLOCK_NAME      => 'Group_ManagedElement',
        OUTPUT_FILENAME_START  => 'Group_ManagedElement',
        AVERAGE_COUNTERS       => ['pmApomcOfSpreadersUsed'],
        AVERAGE_APPEND_STR     => "_AVG",
        AVERAGE_NO_APPEND_STR  => ['pmApomcOfSpreadersUsed'],
        PRODUCE_PIF            => 0, # P7.1 FP1
        OUTPUT_FORMAT          => 'LIF_Writer', # P7.1 FP1
},
# END : NodeB_DLBasebandPool

# START: Remove BATCHFILES, use LIF_Bucket feature to batch LIF files automatically - P7.1 FP1
# LIF output during UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_ATM_Physical_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_ATM_Physical_Link',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_ATM_Physical_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_ATM_Physical_Link',
#},
#
# LIF output during UNPEGGER rule - P7.1 FP1
# Batch LIF files for RXI_ATM_Physical_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for RXI_ATM_Physical_Link',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-RXI_ATM_Physical_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_RXI_ATM_Physical_Link',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NODEB_Virtual_Channel_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_Virtual_Channel_Link',
#    INPUT_FILE_DESCRIPTION  => ['^NODEB_Virtual_Channel_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NODEB_Virtual_Channel_Link',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for RXI_Virtual_Channel_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for RXI_Virtual_Channel_Link',
#    INPUT_FILE_DESCRIPTION  => ['^RXI_Virtual_Channel_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_RXI_Virtual_Channel_Link',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NODEB_Virtual_Path_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_Virtual_Path_Link',
#    INPUT_FILE_DESCRIPTION  => ['^NODEB_Virtual_Path_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NODEB_Virtual_Path_Link',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for RXI_Virtual_Path_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for RXI_Virtual_Path_Link',
#    INPUT_FILE_DESCRIPTION  => ['^RXI_Virtual_Path_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_RXI_Virtual_Path_Link',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NodeB_DLBasebandPool
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NodeB_DLBasebandPool',
#    INPUT_FILE_DESCRIPTION  => ['^NodeB_DLBasebandPool-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NodeB_DLBasebandPool',
#},
#
# LIF output during ACCUMULATE rule - P7.1 FP1
# Batch LIF files for Group_ManagedElement
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for Group_ManagedElement',
#    INPUT_FILE_DESCRIPTION  => ['^NodeB_DLBasebandPool-#-.+-#-.+-#-(.+)-#-.+-#-I-#-Group_ManagedElement-#-A\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_Group_ManagedElement',
#},

# Join ME_NodeBFunction_IubDataStreams blocks to avoid losing data - valnt00075226 - P7
{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join ME_NodeBFunction_IubDataStreams blocks to avoid losing data',
    INPUT_FILE_DESCRIPTION => ['^ME_NodeBFunction_IubDataStreams-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
    COUNTERS_TO_JOIN_ON    => [ 'moid_NodeBFunction', 'moid_ManagedElement', 'moid_Iub', 'moid_IubDataStreams', 'StartDate', 'StartTime' ],
    OUTPUT_BLOCK_NAME      => 'ME_NodeBFunction_IubDataStreams',
    OUTPUT_FILENAME_START  => 'ME_NodeBFunction_IubDataStreams',
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ 'nedn_SubNetwork','nedn_MeContext', 'mts' ],
    ## Split PDF counter
    PRODUCE_PIF            => 'True', # P7.1 FP1
    #OUTPUT_FORMAT          => 'LIF_Writer', # P7.1 FP1
},

# START: ME_NodeBFunction_IubDataStreams set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_IubDataStreams',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_IubDataStreams-#-.+-#-J\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_IubDataStreams',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmHsDataFrameDelayIubSpi00|pmHsDataFrameDelayIubSpi01|pmHsDataFrameDelayIubSpi02|pmHsDataFrameDelayIubSpi03|pmHsDataFrameDelayIubSpi04|pmHsDataFrameDelayIubSpi05|pmHsDataFrameDelayIubSpi06|pmHsDataFrameDelayIubSpi07|pmHsDataFrameDelayIubSpi08|pmHsDataFrameDelayIubSpi09|pmHsDataFrameDelayIubSpi10|pmHsDataFrameDelayIubSpi11|pmHsDataFrameDelayIubSpi12|pmHsDataFrameDelayIubSpi13|pmHsDataFrameDelayIubSpi14|pmHsDataFrameDelayIubSpi15|pmIubMacdPduRbsReceivedBits)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmHsDataFrameDelayIubSpi00_0 pmHsDataFrameDelayIubSpi00_1 pmHsDataFrameDelayIubSpi00_2 pmHsDataFrameDelayIubSpi00_3
        pmHsDataFrameDelayIubSpi00_4 pmHsDataFrameDelayIubSpi00_5 pmHsDataFrameDelayIubSpi00_6 pmHsDataFrameDelayIubSpi00_7
        pmHsDataFrameDelayIubSpi00_8 pmHsDataFrameDelayIubSpi00_9 pmHsDataFrameDelayIubSpi00_10 pmHsDataFrameDelayIubSpi00_11
        pmHsDataFrameDelayIubSpi00_12 pmHsDataFrameDelayIubSpi00_13 pmHsDataFrameDelayIubSpi00_14 pmHsDataFrameDelayIubSpi00_15
        pmHsDataFrameDelayIubSpi01_0 pmHsDataFrameDelayIubSpi01_1 pmHsDataFrameDelayIubSpi01_2 pmHsDataFrameDelayIubSpi01_3
        pmHsDataFrameDelayIubSpi01_4 pmHsDataFrameDelayIubSpi01_5 pmHsDataFrameDelayIubSpi01_6 pmHsDataFrameDelayIubSpi01_7
        pmHsDataFrameDelayIubSpi01_8 pmHsDataFrameDelayIubSpi01_9 pmHsDataFrameDelayIubSpi01_10 pmHsDataFrameDelayIubSpi01_11
        pmHsDataFrameDelayIubSpi01_12 pmHsDataFrameDelayIubSpi01_13 pmHsDataFrameDelayIubSpi01_14 pmHsDataFrameDelayIubSpi01_15
        pmHsDataFrameDelayIubSpi02_0 pmHsDataFrameDelayIubSpi02_1 pmHsDataFrameDelayIubSpi02_2 pmHsDataFrameDelayIubSpi02_3
        pmHsDataFrameDelayIubSpi02_4 pmHsDataFrameDelayIubSpi02_5 pmHsDataFrameDelayIubSpi02_6 pmHsDataFrameDelayIubSpi02_7
        pmHsDataFrameDelayIubSpi02_8 pmHsDataFrameDelayIubSpi02_9 pmHsDataFrameDelayIubSpi02_10 pmHsDataFrameDelayIubSpi02_11
        pmHsDataFrameDelayIubSpi02_12 pmHsDataFrameDelayIubSpi02_13 pmHsDataFrameDelayIubSpi02_14 pmHsDataFrameDelayIubSpi02_15
        pmHsDataFrameDelayIubSpi03_0 pmHsDataFrameDelayIubSpi03_1 pmHsDataFrameDelayIubSpi03_2 pmHsDataFrameDelayIubSpi03_3
        pmHsDataFrameDelayIubSpi03_4 pmHsDataFrameDelayIubSpi03_5 pmHsDataFrameDelayIubSpi03_6 pmHsDataFrameDelayIubSpi03_7
        pmHsDataFrameDelayIubSpi03_8 pmHsDataFrameDelayIubSpi03_9 pmHsDataFrameDelayIubSpi03_10 pmHsDataFrameDelayIubSpi03_11
        pmHsDataFrameDelayIubSpi03_12 pmHsDataFrameDelayIubSpi03_13 pmHsDataFrameDelayIubSpi03_14 pmHsDataFrameDelayIubSpi03_15
        pmHsDataFrameDelayIubSpi04_0 pmHsDataFrameDelayIubSpi04_1 pmHsDataFrameDelayIubSpi04_2 pmHsDataFrameDelayIubSpi04_3
        pmHsDataFrameDelayIubSpi04_4 pmHsDataFrameDelayIubSpi04_5 pmHsDataFrameDelayIubSpi04_6 pmHsDataFrameDelayIubSpi04_7
        pmHsDataFrameDelayIubSpi04_8 pmHsDataFrameDelayIubSpi04_9 pmHsDataFrameDelayIubSpi04_10 pmHsDataFrameDelayIubSpi04_11
        pmHsDataFrameDelayIubSpi04_12 pmHsDataFrameDelayIubSpi04_13 pmHsDataFrameDelayIubSpi04_14 pmHsDataFrameDelayIubSpi04_15
        pmHsDataFrameDelayIubSpi05_0 pmHsDataFrameDelayIubSpi05_1 pmHsDataFrameDelayIubSpi05_2 pmHsDataFrameDelayIubSpi05_3
        pmHsDataFrameDelayIubSpi05_4 pmHsDataFrameDelayIubSpi05_5 pmHsDataFrameDelayIubSpi05_6 pmHsDataFrameDelayIubSpi05_7
        pmHsDataFrameDelayIubSpi05_8 pmHsDataFrameDelayIubSpi05_9 pmHsDataFrameDelayIubSpi05_10 pmHsDataFrameDelayIubSpi05_11
        pmHsDataFrameDelayIubSpi05_12 pmHsDataFrameDelayIubSpi05_13 pmHsDataFrameDelayIubSpi05_14 pmHsDataFrameDelayIubSpi05_15
        pmHsDataFrameDelayIubSpi06_0 pmHsDataFrameDelayIubSpi06_1 pmHsDataFrameDelayIubSpi06_2 pmHsDataFrameDelayIubSpi06_3
        pmHsDataFrameDelayIubSpi06_4 pmHsDataFrameDelayIubSpi06_5 pmHsDataFrameDelayIubSpi06_6 pmHsDataFrameDelayIubSpi06_7
        pmHsDataFrameDelayIubSpi06_8 pmHsDataFrameDelayIubSpi06_9 pmHsDataFrameDelayIubSpi06_10 pmHsDataFrameDelayIubSpi06_11
        pmHsDataFrameDelayIubSpi06_12 pmHsDataFrameDelayIubSpi06_13 pmHsDataFrameDelayIubSpi06_14 pmHsDataFrameDelayIubSpi06_15
        pmHsDataFrameDelayIubSpi07_0 pmHsDataFrameDelayIubSpi07_1 pmHsDataFrameDelayIubSpi07_2 pmHsDataFrameDelayIubSpi07_3
        pmHsDataFrameDelayIubSpi07_4 pmHsDataFrameDelayIubSpi07_5 pmHsDataFrameDelayIubSpi07_6 pmHsDataFrameDelayIubSpi07_7
        pmHsDataFrameDelayIubSpi07_8 pmHsDataFrameDelayIubSpi07_9 pmHsDataFrameDelayIubSpi07_10 pmHsDataFrameDelayIubSpi07_11
        pmHsDataFrameDelayIubSpi07_12 pmHsDataFrameDelayIubSpi07_13 pmHsDataFrameDelayIubSpi07_14 pmHsDataFrameDelayIubSpi07_15
        pmHsDataFrameDelayIubSpi08_0 pmHsDataFrameDelayIubSpi08_1 pmHsDataFrameDelayIubSpi08_2 pmHsDataFrameDelayIubSpi08_3
        pmHsDataFrameDelayIubSpi08_4 pmHsDataFrameDelayIubSpi08_5 pmHsDataFrameDelayIubSpi08_6 pmHsDataFrameDelayIubSpi08_7
        pmHsDataFrameDelayIubSpi08_8 pmHsDataFrameDelayIubSpi08_9 pmHsDataFrameDelayIubSpi08_10 pmHsDataFrameDelayIubSpi08_11
        pmHsDataFrameDelayIubSpi08_12 pmHsDataFrameDelayIubSpi08_13 pmHsDataFrameDelayIubSpi08_14 pmHsDataFrameDelayIubSpi08_15
        pmHsDataFrameDelayIubSpi09_0 pmHsDataFrameDelayIubSpi09_1 pmHsDataFrameDelayIubSpi09_2 pmHsDataFrameDelayIubSpi09_3
        pmHsDataFrameDelayIubSpi09_4 pmHsDataFrameDelayIubSpi09_5 pmHsDataFrameDelayIubSpi09_6 pmHsDataFrameDelayIubSpi09_7
        pmHsDataFrameDelayIubSpi09_8 pmHsDataFrameDelayIubSpi09_9 pmHsDataFrameDelayIubSpi09_10 pmHsDataFrameDelayIubSpi09_11
        pmHsDataFrameDelayIubSpi09_12 pmHsDataFrameDelayIubSpi09_13 pmHsDataFrameDelayIubSpi09_14 pmHsDataFrameDelayIubSpi09_15
        pmHsDataFrameDelayIubSpi10_0 pmHsDataFrameDelayIubSpi10_1 pmHsDataFrameDelayIubSpi10_2 pmHsDataFrameDelayIubSpi10_3
        pmHsDataFrameDelayIubSpi10_4 pmHsDataFrameDelayIubSpi10_5 pmHsDataFrameDelayIubSpi10_6 pmHsDataFrameDelayIubSpi10_7
        pmHsDataFrameDelayIubSpi10_8 pmHsDataFrameDelayIubSpi10_9 pmHsDataFrameDelayIubSpi10_10 pmHsDataFrameDelayIubSpi10_11
        pmHsDataFrameDelayIubSpi10_12 pmHsDataFrameDelayIubSpi10_13 pmHsDataFrameDelayIubSpi10_14 pmHsDataFrameDelayIubSpi10_15
        pmHsDataFrameDelayIubSpi11_0 pmHsDataFrameDelayIubSpi11_1 pmHsDataFrameDelayIubSpi11_2 pmHsDataFrameDelayIubSpi11_3
        pmHsDataFrameDelayIubSpi11_4 pmHsDataFrameDelayIubSpi11_5 pmHsDataFrameDelayIubSpi11_6 pmHsDataFrameDelayIubSpi11_7
        pmHsDataFrameDelayIubSpi11_8 pmHsDataFrameDelayIubSpi11_9 pmHsDataFrameDelayIubSpi11_10 pmHsDataFrameDelayIubSpi11_11
        pmHsDataFrameDelayIubSpi11_12 pmHsDataFrameDelayIubSpi11_13 pmHsDataFrameDelayIubSpi11_14 pmHsDataFrameDelayIubSpi11_15
        pmHsDataFrameDelayIubSpi12_0 pmHsDataFrameDelayIubSpi12_1 pmHsDataFrameDelayIubSpi12_2 pmHsDataFrameDelayIubSpi12_3
        pmHsDataFrameDelayIubSpi12_4 pmHsDataFrameDelayIubSpi12_5 pmHsDataFrameDelayIubSpi12_6 pmHsDataFrameDelayIubSpi12_7
        pmHsDataFrameDelayIubSpi12_8 pmHsDataFrameDelayIubSpi12_9 pmHsDataFrameDelayIubSpi12_10 pmHsDataFrameDelayIubSpi12_11
        pmHsDataFrameDelayIubSpi12_12 pmHsDataFrameDelayIubSpi12_13 pmHsDataFrameDelayIubSpi12_14 pmHsDataFrameDelayIubSpi12_15
        pmHsDataFrameDelayIubSpi13_0 pmHsDataFrameDelayIubSpi13_1 pmHsDataFrameDelayIubSpi13_2 pmHsDataFrameDelayIubSpi13_3
        pmHsDataFrameDelayIubSpi13_4 pmHsDataFrameDelayIubSpi13_5 pmHsDataFrameDelayIubSpi13_6 pmHsDataFrameDelayIubSpi13_7
        pmHsDataFrameDelayIubSpi13_8 pmHsDataFrameDelayIubSpi13_9 pmHsDataFrameDelayIubSpi13_10 pmHsDataFrameDelayIubSpi13_11
        pmHsDataFrameDelayIubSpi13_12 pmHsDataFrameDelayIubSpi13_13 pmHsDataFrameDelayIubSpi13_14 pmHsDataFrameDelayIubSpi13_15
        pmHsDataFrameDelayIubSpi14_0 pmHsDataFrameDelayIubSpi14_1 pmHsDataFrameDelayIubSpi14_2 pmHsDataFrameDelayIubSpi14_3
        pmHsDataFrameDelayIubSpi14_4 pmHsDataFrameDelayIubSpi14_5 pmHsDataFrameDelayIubSpi14_6 pmHsDataFrameDelayIubSpi14_7
        pmHsDataFrameDelayIubSpi14_8 pmHsDataFrameDelayIubSpi14_9 pmHsDataFrameDelayIubSpi14_10 pmHsDataFrameDelayIubSpi14_11
        pmHsDataFrameDelayIubSpi14_12 pmHsDataFrameDelayIubSpi14_13 pmHsDataFrameDelayIubSpi14_14 pmHsDataFrameDelayIubSpi14_15
        pmHsDataFrameDelayIubSpi15_0 pmHsDataFrameDelayIubSpi15_1 pmHsDataFrameDelayIubSpi15_2 pmHsDataFrameDelayIubSpi15_3
        pmHsDataFrameDelayIubSpi15_4 pmHsDataFrameDelayIubSpi15_5 pmHsDataFrameDelayIubSpi15_6 pmHsDataFrameDelayIubSpi15_7
        pmHsDataFrameDelayIubSpi15_8 pmHsDataFrameDelayIubSpi15_9 pmHsDataFrameDelayIubSpi15_10 pmHsDataFrameDelayIubSpi15_11
        pmHsDataFrameDelayIubSpi15_12 pmHsDataFrameDelayIubSpi15_13 pmHsDataFrameDelayIubSpi15_14 pmHsDataFrameDelayIubSpi15_15
        pmIubMacdPduRbsReceivedBits_0 pmIubMacdPduRbsReceivedBits_1 pmIubMacdPduRbsReceivedBits_2 pmIubMacdPduRbsReceivedBits_3
        pmIubMacdPduRbsReceivedBits_4 pmIubMacdPduRbsReceivedBits_5 pmIubMacdPduRbsReceivedBits_6 pmIubMacdPduRbsReceivedBits_7
        pmIubMacdPduRbsReceivedBits_8 pmIubMacdPduRbsReceivedBits_9 pmIubMacdPduRbsReceivedBits_10 pmIubMacdPduRbsReceivedBits_11
        pmIubMacdPduRbsReceivedBits_12 pmIubMacdPduRbsReceivedBits_13 pmIubMacdPduRbsReceivedBits_14
        pmIubMacdPduRbsReceivedBits_15 pmIubMacdPduRbsReceivedBits_16 pmIubMacdPduRbsReceivedBits_17
        pmIubMacdPduRbsReceivedBits_18 pmIubMacdPduRbsReceivedBits_19 pmIubMacdPduRbsReceivedBits_20
        pmIubMacdPduRbsReceivedBits_21 pmIubMacdPduRbsReceivedBits_22 pmIubMacdPduRbsReceivedBits_23
        pmIubMacdPduRbsReceivedBits_24 pmIubMacdPduRbsReceivedBits_25 pmIubMacdPduRbsReceivedBits_26
        pmIubMacdPduRbsReceivedBits_27 pmIubMacdPduRbsReceivedBits_28 pmIubMacdPduRbsReceivedBits_29
        pmIubMacdPduRbsReceivedBits_30 pmIubMacdPduRbsReceivedBits_31 pmIubMacdPduRbsReceivedBits_32
        pmIubMacdPduRbsReceivedBits_33 pmIubMacdPduRbsReceivedBits_34 pmIubMacdPduRbsReceivedBits_35
        pmIubMacdPduRbsReceivedBits_36 pmIubMacdPduRbsReceivedBits_37 pmIubMacdPduRbsReceivedBits_38
        pmIubMacdPduRbsReceivedBits_39 pmIubMacdPduRbsReceivedBits_40 pmIubMacdPduRbsReceivedBits_41
        pmIubMacdPduRbsReceivedBits_42 pmIubMacdPduRbsReceivedBits_43 pmIubMacdPduRbsReceivedBits_44
        pmIubMacdPduRbsReceivedBits_45 pmIubMacdPduRbsReceivedBits_46 pmIubMacdPduRbsReceivedBits_47
        pmIubMacdPduRbsReceivedBits_48 pmIubMacdPduRbsReceivedBits_49 pmIubMacdPduRbsReceivedBits_50
        pmIubMacdPduRbsReceivedBits_51 pmIubMacdPduRbsReceivedBits_52 pmIubMacdPduRbsReceivedBits_53
        pmIubMacdPduRbsReceivedBits_54 pmIubMacdPduRbsReceivedBits_55 pmIubMacdPduRbsReceivedBits_56
        pmIubMacdPduRbsReceivedBits_57 pmIubMacdPduRbsReceivedBits_58 pmIubMacdPduRbsReceivedBits_59
        pmIubMacdPduRbsReceivedBits_60 pmIubMacdPduRbsReceivedBits_61 pmIubMacdPduRbsReceivedBits_62
        pmIubMacdPduRbsReceivedBits_63 pmIubMacdPduRbsReceivedBits_64 pmIubMacdPduRbsReceivedBits_65
        pmIubMacdPduRbsReceivedBits_66 pmIubMacdPduRbsReceivedBits_67 pmIubMacdPduRbsReceivedBits_68
        pmIubMacdPduRbsReceivedBits_69 pmIubMacdPduRbsReceivedBits_70 pmIubMacdPduRbsReceivedBits_71
        pmIubMacdPduRbsReceivedBits_72 pmIubMacdPduRbsReceivedBits_73 pmIubMacdPduRbsReceivedBits_74
        pmIubMacdPduRbsReceivedBits_75 pmIubMacdPduRbsReceivedBits_76 pmIubMacdPduRbsReceivedBits_77
        pmIubMacdPduRbsReceivedBits_78 pmIubMacdPduRbsReceivedBits_79 pmIubMacdPduRbsReceivedBits_80
        pmIubMacdPduRbsReceivedBits_81 pmIubMacdPduRbsReceivedBits_82 pmIubMacdPduRbsReceivedBits_83
        pmIubMacdPduRbsReceivedBits_84 pmIubMacdPduRbsReceivedBits_85 pmIubMacdPduRbsReceivedBits_86
        pmIubMacdPduRbsReceivedBits_87 pmIubMacdPduRbsReceivedBits_88 pmIubMacdPduRbsReceivedBits_89
        pmIubMacdPduRbsReceivedBits_90 pmIubMacdPduRbsReceivedBits_91 pmIubMacdPduRbsReceivedBits_92
        pmIubMacdPduRbsReceivedBits_93 pmIubMacdPduRbsReceivedBits_94 pmIubMacdPduRbsReceivedBits_95
        pmIubMacdPduRbsReceivedBits_96 pmIubMacdPduRbsReceivedBits_97 pmIubMacdPduRbsReceivedBits_98
        pmIubMacdPduRbsReceivedBits_99 pmIubMacdPduRbsReceivedBits_100
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_IubDataStreams',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_IubDataStreams-#-.+-#-J\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [
            '^(pmHsDataFrameDelayIubSpi00|pmHsDataFrameDelayIubSpi01|pmHsDataFrameDelayIubSpi02|pmHsDataFrameDelayIubSpi03|pmHsDataFrameDelayIubSpi04|pmHsDataFrameDelayIubSpi05|pmHsDataFrameDelayIubSpi06|pmHsDataFrameDelayIubSpi07|pmHsDataFrameDelayIubSpi08|pmHsDataFrameDelayIubSpi09|pmHsDataFrameDelayIubSpi10|pmHsDataFrameDelayIubSpi11|pmHsDataFrameDelayIubSpi12|pmHsDataFrameDelayIubSpi13|pmHsDataFrameDelayIubSpi14|pmHsDataFrameDelayIubSpi15|pmIubMacdPduRbsReceivedBits)_\d+$',
        ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement'
    ], # BG
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_IubDataStreams',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_IubDataStreams-#-.+-#-J-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_IubDataStreams',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_IubDataStreams set

# LIF output during JOIN rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_IubDataStreams
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_IubDataStreams',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_IubDataStreams-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_IubDataStreams',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_RbsLocalCell_Carrier
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_RbsLocalCell_Carrier',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_RbsLocalCell_Carrier-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_RbsLocalCell_Carrier',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NodeB_ULBasebandPool
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NodeB_ULBasebandPool',
#    INPUT_FILE_DESCRIPTION  => ['^NodeB_ULBasebandPool-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NodeB_ULBasebandPool',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NODEB_AAL2_AP
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_AAL2_AP',
#    INPUT_FILE_DESCRIPTION  => ['^NODEB_AAL2_AP-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NODEB_AAL2_AP',
#},
#
# LIF output during PERLIZE rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_HsDschResources
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_HsDschResources',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-(.+)-#-.+-#-J-#-TOT\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_HsDschResources',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ManagedElement_NodeBFunction_Sector_Carrier_Aich
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ManagedElement_NodeBFunction_Sector_Carrier_Aich',
#    INPUT_FILE_DESCRIPTION  => ['^ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ManagedElement_NodeBFunction_Sector_Carrier_Aich',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_Sector_Carrier_EDchResources
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_Sector_Carrier_EDchResources',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_Sector_Carrier_EDchResources',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_Sector_Carrier_Prach
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_Sector_Carrier_Prach',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_Sector_Carrier_Prach',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ManagedElement_NodeBFunction_Carrier_Sccpch
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ManagedElement_NodeBFunction_Carrier_Sccpch',
#    INPUT_FILE_DESCRIPTION  => ['^ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ManagedElement_NodeBFunction_Carrier_Sccpch',
#},

# Join NODEB_AAL2_Link with same keys to join counters - P7
{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join NODEB_AAL2_Link with same keys to join counters',
    INPUT_FILE_DESCRIPTION  => ['^NODEB_AAL2_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
    COUNTERS_TO_JOIN_ON    => [ qw(moid_ManagedElement moid_TransportNetwork moid_Aal2PathVccTp) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_BLOCK_NAME      => 'NODEB_AAL2_Link',
    OUTPUT_FILENAME_START  => 'NODEB_AAL2_Link',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
    PRODUCE_PIF            => 0, # P7.1 FP1
    OUTPUT_FORMAT           => 'LIF_Writer', # P7.1 FP1
},

# LIF output during JOIN rule - P7.1 FP1
# Batch LIF files for NODEB_AAL2_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_AAL2_Link',
#    INPUT_FILE_DESCRIPTION  => ['^NODEB_AAL2_Link-#-.+-#-.+-#-(.+)-#-.+-#-J\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NODEB_AAL2_Link',
#},
#
# LIF output during UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_AAL2_SP
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_AAL2_SP',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_AAL2_SP-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_AAL2_SP',
#},
#
# LIF output during last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for NODEB_E1_T1_J1_PHYSICAL_LINK
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_E1_T1_J1_PHYSICAL_LINK',
#    INPUT_FILE_DESCRIPTION  => ['^NODEB_E1_T1_J1_PHYSICAL_LINK-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_NODEB_E1_T1_J1_PHYSICAL_LINK',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_IMA_GROUP
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IMA_GROUP',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_IMA_GROUP-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IMA_GROUP',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_IMA_LINK
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IMA_LINK',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_IMA_LINK-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IMA_LINK',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_Virtual_Path_Connection
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_Virtual_Path_Connection',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_Virtual_Path_Connection-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_Virtual_Path_Connection',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_UniSAalTp_Signaling
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_UniSAalTp_Signaling',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_UniSAalTp_Signaling-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_UniSAalTp_Signaling',
#},

# Batch LIF files for NODEB_IP_ATM_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IP_ATM_Link',
#    INPUT_FILE_DESCRIPTION  => [
#        '^UNPEG-#-NODEB_ManagedElement_IpSystem_Ip_IpAtmLink-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$',
#        '^UNPEG-#-NODEB_ManagedElement_IpOam_Ip_IpAtmLink-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'
#    ],
#    OUTPUT_BLOCK_NAME       => 'NODEB_IP_ATM_Link',
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IP_ATM_Link',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_IP_Link
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IP_Link',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_IP_Link-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IP_Link',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_IpSystem_IpAccessHostGpb
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IpSystem_IpAccessHostGpb',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_IpSystem_IpAccessHostGpb-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IpSystem_IpAccessHostGpb',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_IpSystem_IpAccessUdpHostMsb
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_IpSystem_IpAccessUdpHostMsb',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_IpSystem_IpAccessUdpHostMsb-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_IpSystem_IpAccessUdpHostMsb',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_Mtp2tpItu
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_Mtp2tpItu',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_Mtp2tpItu-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_Mtp2tpItu',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_NniSAalTp_Signaling
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_NniSAalTp_Signaling',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_NniSAalTp_Signaling-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_NniSAalTp_Signaling',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_Ospf
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_Ospf',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_Ospf-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_Ospf',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_OspfArea
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_OspfArea',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_OspfArea-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_OspfArea',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_OspfInterface
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_OspfInterface',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_OspfInterface-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_OspfInterface',
#},
#
# LIF output during last UNPEGGER rule - P7.1 FP1
# Batch LIF files for NODEB_SCTP
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for NODEB_SCTP',
#    INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-NODEB_SCTP-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_UNPEG_NODEB_SCTP',
#},
#
# LIF output during last last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_Carrier_RadioLinks
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_Carrier_RadioLinks',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_Carrier_RadioLinks',
#},
#
# LIF output during last last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ME_NodeBFunction_NbapCommon
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ME_NodeBFunction_NbapCommon',
#    INPUT_FILE_DESCRIPTION  => ['^ME_NodeBFunction_NbapCommon-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ME_NodeBFunction_NbapCommon',
#},
#
# LIF output during last last PIF_2_OUTPUT rule - P7.1 FP1
# Batch LIF files for ManagedElement_NodeBFunction_Iub
#{
#    RULE_TYPE               => 'BATCHFILES' ,
#    RULE_DESC               => 'Batch LIF files for ManagedElement_NodeBFunction_Iub',
#    INPUT_FILE_DESCRIPTION  => ['^ManagedElement_NodeBFunction_Iub-#-.+-#-.+-#-(.+)-#-.+-#-I\.pif$'],
#    OUTPUT_FORMAT           => 'LIF_Writer',
#    PRODUCE_PIF             => 0,
#    OUTPUT_FILENAME_START   => 'BATCHED_ManagedElement_NodeBFunction_Iub',
#},
# END: Remove BATCHFILES, use LIF_Bucket feature to batch LIF files automatically - P7.1 FP1

# START: PDF Splitting from initial PIFs

# START: ManagedElement set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmCapacityNodeBDlCe|pmCapacityNodeBUlCe)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmCapacityNodeBDlCe_0 pmCapacityNodeBDlCe_1 pmCapacityNodeBDlCe_2 pmCapacityNodeBDlCe_3 pmCapacityNodeBDlCe_4
        pmCapacityNodeBDlCe_5 pmCapacityNodeBDlCe_6 pmCapacityNodeBDlCe_7 pmCapacityNodeBDlCe_8 pmCapacityNodeBDlCe_9
        pmCapacityNodeBDlCe_10
        pmCapacityNodeBUlCe_0 pmCapacityNodeBUlCe_1 pmCapacityNodeBUlCe_2 pmCapacityNodeBUlCe_3 pmCapacityNodeBUlCe_4
        pmCapacityNodeBUlCe_5 pmCapacityNodeBUlCe_6 pmCapacityNodeBUlCe_7 pmCapacityNodeBUlCe_8 pmCapacityNodeBUlCe_9
        pmCapacityNodeBUlCe_10
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmCapacityNodeBDlCe|pmCapacityNodeBUlCe)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement set

# START: ManagedElement_RncCapacity set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncCapacity',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncCapacity-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncCapacity',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmCapacityUtilization)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmCapacityUtilization_0 pmCapacityUtilization_1 pmCapacityUtilization_2 pmCapacityUtilization_3
        pmCapacityUtilization_4 pmCapacityUtilization_5 pmCapacityUtilization_6 pmCapacityUtilization_7
        pmCapacityUtilization_8 pmCapacityUtilization_9
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncCapacity',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncCapacity-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmCapacityUtilization)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_SystemFunctions',
        'moid_Licensing', 'moid_RncCapacity',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncCapacity',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncCapacity-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncCapacity',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_RncCapacity set

# START: ManagedElement_RncFunction_IurLink set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncFunction_IurLink',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_IurLink-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_IurLink',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmEdchDataFrameDelayIub)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmEdchDataFrameDelayIub_0 pmEdchDataFrameDelayIub_1 pmEdchDataFrameDelayIub_2 pmEdchDataFrameDelayIub_3
        pmEdchDataFrameDelayIub_4 pmEdchDataFrameDelayIub_5 pmEdchDataFrameDelayIub_6 pmEdchDataFrameDelayIub_7
        pmEdchDataFrameDelayIub_8 pmEdchDataFrameDelayIub_9 pmEdchDataFrameDelayIub_10 pmEdchDataFrameDelayIub_11
        pmEdchDataFrameDelayIub_12 pmEdchDataFrameDelayIub_13 pmEdchDataFrameDelayIub_14 pmEdchDataFrameDelayIub_15
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncFunction_IurLink',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_IurLink-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmEdchDataFrameDelayIub)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_IurLink',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncFunction_IurLink',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_IurLink-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_IurLink',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_RncFunction_IurLink set

# START: ManagedElement_RncFunction_UtranCell_Hsdsch set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncFunction_UtranCell_Hsdsch',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell_Hsdsch',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmHsDlRlcUserPacketThp)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmHsDlRlcUserPacketThp_0 pmHsDlRlcUserPacketThp_1 pmHsDlRlcUserPacketThp_2 pmHsDlRlcUserPacketThp_3
        pmHsDlRlcUserPacketThp_4 pmHsDlRlcUserPacketThp_5 pmHsDlRlcUserPacketThp_6 pmHsDlRlcUserPacketThp_7
        pmHsDlRlcUserPacketThp_8 pmHsDlRlcUserPacketThp_9 pmHsDlRlcUserPacketThp_10 pmHsDlRlcUserPacketThp_11
        pmHsDlRlcUserPacketThp_12 pmHsDlRlcUserPacketThp_13 pmHsDlRlcUserPacketThp_14 pmHsDlRlcUserPacketThp_15
        pmHsDlRlcUserPacketThp_16 pmHsDlRlcUserPacketThp_17 pmHsDlRlcUserPacketThp_18 pmHsDlRlcUserPacketThp_19
        pmHsDlRlcUserPacketThp_20 pmHsDlRlcUserPacketThp_21 pmHsDlRlcUserPacketThp_22 pmHsDlRlcUserPacketThp_23
        pmHsDlRlcUserPacketThp_24 pmHsDlRlcUserPacketThp_25 pmHsDlRlcUserPacketThp_26 pmHsDlRlcUserPacketThp_27
        pmHsDlRlcUserPacketThp_28 pmHsDlRlcUserPacketThp_29 pmHsDlRlcUserPacketThp_30 pmHsDlRlcUserPacketThp_31
        pmHsDlRlcUserPacketThp_32 pmHsDlRlcUserPacketThp_33 pmHsDlRlcUserPacketThp_34 pmHsDlRlcUserPacketThp_35
        pmHsDlRlcUserPacketThp_36
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncFunction_UtranCell_Hsdsch',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmHsDlRlcUserPacketThp)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_UtranCell'
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncFunction_UtranCell_Hsdsch',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell_Hsdsch',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_RncFunction_UtranCell_Hsdsch set

# START: ManagedElement_RncFunction_UtranCell_Hsdsch_Eul set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ManagedElement_RncFunction_UtranCell_Hsdsch_Eul',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch_Eul-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell_Hsdsch_Eul',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmEulRlcUserPacketThp)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmEulRlcUserPacketThp_0 pmEulRlcUserPacketThp_1 pmEulRlcUserPacketThp_2 pmEulRlcUserPacketThp_3
        pmEulRlcUserPacketThp_4 pmEulRlcUserPacketThp_5 pmEulRlcUserPacketThp_6 pmEulRlcUserPacketThp_7
        pmEulRlcUserPacketThp_8 pmEulRlcUserPacketThp_9 pmEulRlcUserPacketThp_10 pmEulRlcUserPacketThp_11
        pmEulRlcUserPacketThp_12 pmEulRlcUserPacketThp_13 pmEulRlcUserPacketThp_14 pmEulRlcUserPacketThp_15
        pmEulRlcUserPacketThp_16 pmEulRlcUserPacketThp_17 pmEulRlcUserPacketThp_18 pmEulRlcUserPacketThp_19
        pmEulRlcUserPacketThp_20 pmEulRlcUserPacketThp_21 pmEulRlcUserPacketThp_22 pmEulRlcUserPacketThp_23
        pmEulRlcUserPacketThp_24 pmEulRlcUserPacketThp_25
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ManagedElement_RncFunction_UtranCell_Hsdsch_Eul',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch_Eul-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmEulRlcUserPacketThp)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_UtranCell'
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ManagedElement_RncFunction_UtranCell_Hsdsch_Eul',
    INPUT_FILE_DESCRIPTION     => '^ManagedElement_RncFunction_UtranCell_Hsdsch_Eul-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ManagedElement_RncFunction_UtranCell_Hsdsch_Eul',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ManagedElement_RncFunction_UtranCell_Hsdsch_Eul set

# START: ME_Eqpt_Subrack_UplinkBaseBandPool set - BG
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_Eqpt_Subrack_UplinkBaseBandPool',
    INPUT_FILE_DESCRIPTION     => '^ME_Eqpt_Subrack_UplinkBaseBandPool-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_Eqpt_Subrack_UplinkBaseBandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmCapacityUlCe)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmCapacityUlCe_0 pmCapacityUlCe_1 pmCapacityUlCe_2 pmCapacityUlCe_3 pmCapacityUlCe_4 pmCapacityUlCe_5
        pmCapacityUlCe_6 pmCapacityUlCe_7 pmCapacityUlCe_8 pmCapacityUlCe_9 pmCapacityUlCe_10
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_Eqpt_Subrack_UplinkBaseBandPool',
    INPUT_FILE_DESCRIPTION     => '^ME_Eqpt_Subrack_UplinkBaseBandPool-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmCapacityUlCe)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement'
    ], # BG
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_Eqpt_Subrack_UplinkBaseBandPool',
    INPUT_FILE_DESCRIPTION     => '^ME_Eqpt_Subrack_UplinkBaseBandPool-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_Eqpt_Subrack_UplinkBaseBandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_Eqpt_Subrack_UplinkBaseBandPool set

# START: ME_NodeBFunction_Carrier_RadioLinks set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_Carrier_RadioLinks',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Carrier_RadioLinks',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmAverageSir|pmAverageSirError|pmBranchDeltaSir|pmDpcchBer|pmDpchCodePowerSf128|pmDpchCodePowerSf16|pmDpchCodePowerSf256|pmDpchCodePowerSf32)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmAverageSir_0 pmAverageSir_1 pmAverageSir_2 pmAverageSir_3 pmAverageSir_4 pmAverageSir_5 pmAverageSir_6
        pmAverageSir_7 pmAverageSir_8 pmAverageSir_9 pmAverageSir_10 pmAverageSir_11 pmAverageSir_12 pmAverageSir_13
        pmAverageSir_14 pmAverageSir_15 pmAverageSir_16 pmAverageSir_17 pmAverageSir_18 pmAverageSir_19 pmAverageSir_20
        pmAverageSir_21 pmAverageSir_22 pmAverageSir_23 pmAverageSir_24 pmAverageSir_25 pmAverageSir_26 pmAverageSir_27
        pmAverageSir_28 pmAverageSir_29 pmAverageSir_30 pmAverageSir_31 pmAverageSir_32 pmAverageSir_33 pmAverageSir_34
        pmAverageSir_35 pmAverageSir_36 pmAverageSir_37
        pmAverageSirError_0 pmAverageSirError_1 pmAverageSirError_2 pmAverageSirError_3 pmAverageSirError_4
        pmAverageSirError_5 pmAverageSirError_6 pmAverageSirError_7 pmAverageSirError_8 pmAverageSirError_9
        pmAverageSirError_10 pmAverageSirError_11 pmAverageSirError_12 pmAverageSirError_13 pmAverageSirError_14
        pmAverageSirError_15 pmAverageSirError_16 pmAverageSirError_17 pmAverageSirError_18 pmAverageSirError_19
        pmAverageSirError_20 pmAverageSirError_21 pmAverageSirError_22 pmAverageSirError_23 pmAverageSirError_24
        pmAverageSirError_25 pmAverageSirError_26 pmAverageSirError_27 pmAverageSirError_28 pmAverageSirError_29
        pmAverageSirError_30 pmAverageSirError_31 pmAverageSirError_32 pmAverageSirError_33 pmAverageSirError_34
        pmAverageSirError_35 pmAverageSirError_36 pmAverageSirError_37 pmAverageSirError_38 pmAverageSirError_39
        pmAverageSirError_40 pmAverageSirError_41
        pmBranchDeltaSir_0 pmBranchDeltaSir_1 pmBranchDeltaSir_2 pmBranchDeltaSir_3 pmBranchDeltaSir_4
        pmBranchDeltaSir_5 pmBranchDeltaSir_6 pmBranchDeltaSir_7 pmBranchDeltaSir_8 pmBranchDeltaSir_9
        pmBranchDeltaSir_10 pmBranchDeltaSir_11 pmBranchDeltaSir_12 pmBranchDeltaSir_13 pmBranchDeltaSir_14
        pmBranchDeltaSir_15 pmBranchDeltaSir_16 pmBranchDeltaSir_17 pmBranchDeltaSir_18 pmBranchDeltaSir_19
        pmBranchDeltaSir_20 pmBranchDeltaSir_21 pmBranchDeltaSir_22 pmBranchDeltaSir_23 pmBranchDeltaSir_24
        pmBranchDeltaSir_25 pmBranchDeltaSir_26 pmBranchDeltaSir_27 pmBranchDeltaSir_28 pmBranchDeltaSir_29
        pmBranchDeltaSir_30 pmBranchDeltaSir_31 pmBranchDeltaSir_32 pmBranchDeltaSir_33 pmBranchDeltaSir_34
        pmBranchDeltaSir_35 pmBranchDeltaSir_36 pmBranchDeltaSir_37 pmBranchDeltaSir_38 pmBranchDeltaSir_39
        pmBranchDeltaSir_40 pmBranchDeltaSir_41 pmBranchDeltaSir_42 pmBranchDeltaSir_43 pmBranchDeltaSir_44
        pmBranchDeltaSir_45 pmBranchDeltaSir_46 pmBranchDeltaSir_47 pmBranchDeltaSir_48 pmBranchDeltaSir_49
        pmBranchDeltaSir_50 pmBranchDeltaSir_51 pmBranchDeltaSir_52 pmBranchDeltaSir_53 pmBranchDeltaSir_54
        pmBranchDeltaSir_55 pmBranchDeltaSir_56 pmBranchDeltaSir_57 pmBranchDeltaSir_58 pmBranchDeltaSir_59 pmBranchDeltaSir_60
        pmDpcchBer_0 pmDpcchBer_1 pmDpcchBer_2 pmDpcchBer_3 pmDpcchBer_4 pmDpcchBer_5 pmDpcchBer_6 pmDpcchBer_7 pmDpcchBer_8
        pmDpcchBer_9 pmDpcchBer_10 pmDpcchBer_11 pmDpcchBer_12 pmDpcchBer_13 pmDpcchBer_14 pmDpcchBer_15 pmDpcchBer_16
        pmDpcchBer_17 pmDpcchBer_18 pmDpcchBer_19 pmDpcchBer_20 pmDpcchBer_21 pmDpcchBer_22 pmDpcchBer_23 pmDpcchBer_24
        pmDpchCodePowerSf128_0 pmDpchCodePowerSf128_1 pmDpchCodePowerSf128_2 pmDpchCodePowerSf128_3 pmDpchCodePowerSf128_4
        pmDpchCodePowerSf128_5 pmDpchCodePowerSf128_6 pmDpchCodePowerSf128_7 pmDpchCodePowerSf128_8 pmDpchCodePowerSf128_9
        pmDpchCodePowerSf128_10 pmDpchCodePowerSf128_11 pmDpchCodePowerSf128_12 pmDpchCodePowerSf128_13 pmDpchCodePowerSf128_14
        pmDpchCodePowerSf128_15 pmDpchCodePowerSf128_16 pmDpchCodePowerSf128_17 pmDpchCodePowerSf128_18 pmDpchCodePowerSf128_19
        pmDpchCodePowerSf128_20 pmDpchCodePowerSf128_21 pmDpchCodePowerSf128_22 pmDpchCodePowerSf128_23 pmDpchCodePowerSf128_24
        pmDpchCodePowerSf128_25 pmDpchCodePowerSf128_26 pmDpchCodePowerSf128_27 pmDpchCodePowerSf128_28 pmDpchCodePowerSf128_29
        pmDpchCodePowerSf128_30 pmDpchCodePowerSf128_31 pmDpchCodePowerSf128_32 pmDpchCodePowerSf128_33 pmDpchCodePowerSf128_34
        pmDpchCodePowerSf128_35 pmDpchCodePowerSf128_36 pmDpchCodePowerSf128_37
        pmDpchCodePowerSf16_0 pmDpchCodePowerSf16_1 pmDpchCodePowerSf16_2 pmDpchCodePowerSf16_3 pmDpchCodePowerSf16_4
        pmDpchCodePowerSf16_5 pmDpchCodePowerSf16_6 pmDpchCodePowerSf16_7 pmDpchCodePowerSf16_8 pmDpchCodePowerSf16_9
        pmDpchCodePowerSf16_10 pmDpchCodePowerSf16_11 pmDpchCodePowerSf16_12 pmDpchCodePowerSf16_13 pmDpchCodePowerSf16_14
        pmDpchCodePowerSf16_15 pmDpchCodePowerSf16_16 pmDpchCodePowerSf16_17 pmDpchCodePowerSf16_18 pmDpchCodePowerSf16_19
        pmDpchCodePowerSf16_20 pmDpchCodePowerSf16_21 pmDpchCodePowerSf16_22 pmDpchCodePowerSf16_23 pmDpchCodePowerSf16_24
        pmDpchCodePowerSf16_25 pmDpchCodePowerSf16_26 pmDpchCodePowerSf16_27 pmDpchCodePowerSf16_28 pmDpchCodePowerSf16_29
        pmDpchCodePowerSf16_30 pmDpchCodePowerSf16_31 pmDpchCodePowerSf16_32 pmDpchCodePowerSf16_33 pmDpchCodePowerSf16_34
        pmDpchCodePowerSf16_35 pmDpchCodePowerSf16_36 pmDpchCodePowerSf16_37
        pmDpchCodePowerSf256_0 pmDpchCodePowerSf256_1 pmDpchCodePowerSf256_2 pmDpchCodePowerSf256_3 pmDpchCodePowerSf256_4
        pmDpchCodePowerSf256_5 pmDpchCodePowerSf256_6 pmDpchCodePowerSf256_7 pmDpchCodePowerSf256_8 pmDpchCodePowerSf256_9
        pmDpchCodePowerSf256_10 pmDpchCodePowerSf256_11 pmDpchCodePowerSf256_12 pmDpchCodePowerSf256_13 pmDpchCodePowerSf256_14
        pmDpchCodePowerSf256_15 pmDpchCodePowerSf256_16 pmDpchCodePowerSf256_17 pmDpchCodePowerSf256_18 pmDpchCodePowerSf256_19
        pmDpchCodePowerSf256_20 pmDpchCodePowerSf256_21 pmDpchCodePowerSf256_22 pmDpchCodePowerSf256_23 pmDpchCodePowerSf256_24
        pmDpchCodePowerSf256_25 pmDpchCodePowerSf256_26 pmDpchCodePowerSf256_27 pmDpchCodePowerSf256_28 pmDpchCodePowerSf256_29
        pmDpchCodePowerSf256_30 pmDpchCodePowerSf256_31 pmDpchCodePowerSf256_32 pmDpchCodePowerSf256_33 pmDpchCodePowerSf256_34
        pmDpchCodePowerSf256_35 pmDpchCodePowerSf256_36 pmDpchCodePowerSf256_37
        pmDpchCodePowerSf32_0 pmDpchCodePowerSf32_1 pmDpchCodePowerSf32_2 pmDpchCodePowerSf32_3 pmDpchCodePowerSf32_4
        pmDpchCodePowerSf32_5 pmDpchCodePowerSf32_6 pmDpchCodePowerSf32_7 pmDpchCodePowerSf32_8 pmDpchCodePowerSf32_9
        pmDpchCodePowerSf32_10 pmDpchCodePowerSf32_11 pmDpchCodePowerSf32_12 pmDpchCodePowerSf32_13 pmDpchCodePowerSf32_14
        pmDpchCodePowerSf32_15 pmDpchCodePowerSf32_16 pmDpchCodePowerSf32_17 pmDpchCodePowerSf32_18 pmDpchCodePowerSf32_19
        pmDpchCodePowerSf32_20 pmDpchCodePowerSf32_21 pmDpchCodePowerSf32_22 pmDpchCodePowerSf32_23 pmDpchCodePowerSf32_24
        pmDpchCodePowerSf32_25 pmDpchCodePowerSf32_26 pmDpchCodePowerSf32_27 pmDpchCodePowerSf32_28 pmDpchCodePowerSf32_29
        pmDpchCodePowerSf32_30 pmDpchCodePowerSf32_31 pmDpchCodePowerSf32_32 pmDpchCodePowerSf32_33 pmDpchCodePowerSf32_34
        pmDpchCodePowerSf32_35 pmDpchCodePowerSf32_36 pmDpchCodePowerSf32_37
        pmDpchCodePowerSf4_0 pmDpchCodePowerSf4_1 pmDpchCodePowerSf4_2 pmDpchCodePowerSf4_3 pmDpchCodePowerSf4_4
        pmDpchCodePowerSf4_5 pmDpchCodePowerSf4_6 pmDpchCodePowerSf4_7 pmDpchCodePowerSf4_8 pmDpchCodePowerSf4_9
        pmDpchCodePowerSf4_10 pmDpchCodePowerSf4_11 pmDpchCodePowerSf4_12 pmDpchCodePowerSf4_13 pmDpchCodePowerSf4_14
        pmDpchCodePowerSf4_15 pmDpchCodePowerSf4_16 pmDpchCodePowerSf4_17 pmDpchCodePowerSf4_18 pmDpchCodePowerSf4_19
        pmDpchCodePowerSf4_20 pmDpchCodePowerSf4_21 pmDpchCodePowerSf4_22 pmDpchCodePowerSf4_23 pmDpchCodePowerSf4_24
        pmDpchCodePowerSf4_25 pmDpchCodePowerSf4_26 pmDpchCodePowerSf4_27 pmDpchCodePowerSf4_28 pmDpchCodePowerSf4_29
        pmDpchCodePowerSf4_30 pmDpchCodePowerSf4_31 pmDpchCodePowerSf4_32 pmDpchCodePowerSf4_33 pmDpchCodePowerSf4_34
        pmDpchCodePowerSf4_35 pmDpchCodePowerSf4_36 pmDpchCodePowerSf4_37
        pmDpchCodePowerSf64_0 pmDpchCodePowerSf64_1 pmDpchCodePowerSf64_2 pmDpchCodePowerSf64_3 pmDpchCodePowerSf64_4
        pmDpchCodePowerSf64_5 pmDpchCodePowerSf64_6 pmDpchCodePowerSf64_7 pmDpchCodePowerSf64_8 pmDpchCodePowerSf64_9
        pmDpchCodePowerSf64_10 pmDpchCodePowerSf64_11 pmDpchCodePowerSf64_12 pmDpchCodePowerSf64_13 pmDpchCodePowerSf64_14
        pmDpchCodePowerSf64_15 pmDpchCodePowerSf64_16 pmDpchCodePowerSf64_17 pmDpchCodePowerSf64_18 pmDpchCodePowerSf64_19
        pmDpchCodePowerSf64_20 pmDpchCodePowerSf64_21 pmDpchCodePowerSf64_22 pmDpchCodePowerSf64_23 pmDpchCodePowerSf64_24
        pmDpchCodePowerSf64_25 pmDpchCodePowerSf64_26 pmDpchCodePowerSf64_27 pmDpchCodePowerSf64_28 pmDpchCodePowerSf64_29
        pmDpchCodePowerSf64_30 pmDpchCodePowerSf64_31 pmDpchCodePowerSf64_32 pmDpchCodePowerSf64_33 pmDpchCodePowerSf64_34
        pmDpchCodePowerSf64_35 pmDpchCodePowerSf64_36 pmDpchCodePowerSf64_37
        pmDpchCodePowerSf8_0 pmDpchCodePowerSf8_1 pmDpchCodePowerSf8_2 pmDpchCodePowerSf8_3 pmDpchCodePowerSf8_4
        pmDpchCodePowerSf8_5 pmDpchCodePowerSf8_6 pmDpchCodePowerSf8_7 pmDpchCodePowerSf8_8 pmDpchCodePowerSf8_9
        pmDpchCodePowerSf8_10 pmDpchCodePowerSf8_11 pmDpchCodePowerSf8_12 pmDpchCodePowerSf8_13 pmDpchCodePowerSf8_14
        pmDpchCodePowerSf8_15 pmDpchCodePowerSf8_16 pmDpchCodePowerSf8_17 pmDpchCodePowerSf8_18 pmDpchCodePowerSf8_19
        pmDpchCodePowerSf8_20 pmDpchCodePowerSf8_21 pmDpchCodePowerSf8_22 pmDpchCodePowerSf8_23 pmDpchCodePowerSf8_24
        pmDpchCodePowerSf8_25 pmDpchCodePowerSf8_26 pmDpchCodePowerSf8_27 pmDpchCodePowerSf8_28 pmDpchCodePowerSf8_29
        pmDpchCodePowerSf8_30 pmDpchCodePowerSf8_31 pmDpchCodePowerSf8_32 pmDpchCodePowerSf8_33 pmDpchCodePowerSf8_34
        pmDpchCodePowerSf8_35 pmDpchCodePowerSf8_36 pmDpchCodePowerSf8_37
        pmDpdchBer_0 pmDpdchBer_1 pmDpdchBer_2 pmDpdchBer_3 pmDpdchBer_4 pmDpdchBer_5 pmDpdchBer_6 pmDpdchBer_7
        pmDpdchBer_8 pmDpdchBer_9 pmDpdchBer_10 pmDpdchBer_11 pmDpdchBer_12 pmDpdchBer_13 pmDpdchBer_14 pmDpdchBer_15
        pmDpdchBer_16 pmDpdchBer_17 pmDpdchBer_18 pmDpdchBer_19 pmDpdchBer_20 pmDpdchBer_21 pmDpdchBer_22 pmDpdchBer_23
        pmDpdchBer_24
        pmOutOfSynch_0 pmOutOfSynch_1 pmOutOfSynch_2 pmOutOfSynch_3 pmOutOfSynch_4 pmOutOfSynch_5 pmOutOfSynch_6
        pmOutOfSynch_7 pmOutOfSynch_8 pmOutOfSynch_9 pmOutOfSynch_10 pmOutOfSynch_11 pmOutOfSynch_12 pmOutOfSynch_13
        pmOutOfSynch_14 pmOutOfSynch_15 pmOutOfSynch_16 pmOutOfSynch_17 pmOutOfSynch_18 pmOutOfSynch_19 pmOutOfSynch_20
        pmOutOfSynch_21 pmOutOfSynch_22 pmOutOfSynch_23 pmOutOfSynch_24 pmOutOfSynch_25 pmOutOfSynch_26 pmOutOfSynch_27
        pmOutOfSynch_28 pmOutOfSynch_29 pmOutOfSynch_30 pmOutOfSynch_31 pmOutOfSynch_32 pmOutOfSynch_33 pmOutOfSynch_34
        pmOutOfSynch_35 pmOutOfSynch_36 pmOutOfSynch_37 pmOutOfSynch_38 pmOutOfSynch_39 pmOutOfSynch_40 pmOutOfSynch_41
        pmOutOfSynch_42 pmOutOfSynch_43 pmOutOfSynch_44 pmOutOfSynch_45 pmOutOfSynch_46 pmOutOfSynch_47 pmOutOfSynch_48
        pmOutOfSynch_49
        pmUlSynchTime_0 pmUlSynchTime_1 pmUlSynchTime_2 pmUlSynchTime_3 pmUlSynchTime_4 pmUlSynchTime_5 pmUlSynchTime_6
        pmUlSynchTime_7 pmUlSynchTime_8 pmUlSynchTime_9 pmUlSynchTime_10 pmUlSynchTime_11 pmUlSynchTime_12 pmUlSynchTime_13
        pmUlSynchTime_14 pmUlSynchTime_15
        pmUlSynchTimeSHO_0 pmUlSynchTimeSHO_1 pmUlSynchTimeSHO_2 pmUlSynchTimeSHO_3 pmUlSynchTimeSHO_4 pmUlSynchTimeSHO_5
        pmUlSynchTimeSHO_6 pmUlSynchTimeSHO_7 pmUlSynchTimeSHO_8 pmUlSynchTimeSHO_9 pmUlSynchTimeSHO_10 pmUlSynchTimeSHO_11
        pmUlSynchTimeSHO_12 pmUlSynchTimeSHO_13 pmUlSynchTimeSHO_14 pmUlSynchTimeSHO_15
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_Carrier_RadioLinks',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [
            '^(pmAverageSir|pmAverageSirError|pmBranchDeltaSir|pmDpcchBer|pmDpchCodePowerSf128|pmDpchCodePowerSf16|pmDpchCodePowerSf256|pmDpchCodePowerSf32)_\d+$',
        ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier', 'moid_RadioLinks',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_Carrier_RadioLinks',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_Carrier_RadioLinks',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_Carrier_RadioLinks set

# START: ME_NodeBFunction_RbsLocalCell_Carrier set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_NodeBFunction_RbsLocalCell_Carrier',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_RbsLocalCell_Carrier-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_RbsLocalCell_Carrier',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmAverageRssi|pmTransmittedCarrierPower)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmAverageRssi_0 pmAverageRssi_1 pmAverageRssi_2 pmAverageRssi_3 pmAverageRssi_4 pmAverageRssi_5
        pmAverageRssi_6 pmAverageRssi_7 pmAverageRssi_8 pmAverageRssi_9 pmAverageRssi_10 pmAverageRssi_11
        pmAverageRssi_12 pmAverageRssi_13 pmAverageRssi_14 pmAverageRssi_15 pmAverageRssi_16 pmAverageRssi_17
        pmAverageRssi_18 pmAverageRssi_19 pmAverageRssi_20 pmAverageRssi_21 pmAverageRssi_22 pmAverageRssi_23
        pmAverageRssi_24 pmAverageRssi_25 pmAverageRssi_26 pmAverageRssi_27 pmAverageRssi_28 pmAverageRssi_29
        pmAverageRssi_30 pmAverageRssi_31 pmAverageRssi_32 pmAverageRssi_33 pmAverageRssi_34 pmAverageRssi_35
        pmAverageRssi_36 pmAverageRssi_37 pmAverageRssi_38 pmAverageRssi_39 pmAverageRssi_40 pmAverageRssi_41
        pmAverageRssi_42 pmAverageRssi_43 pmAverageRssi_44
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_NodeBFunction_RbsLocalCell_Carrier',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_RbsLocalCell_Carrier-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmAverageRssi|pmTransmittedCarrierPower)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Sector', 'moid_Carrier',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_NodeBFunction_RbsLocalCell_Carrier',
    INPUT_FILE_DESCRIPTION     => '^ME_NodeBFunction_RbsLocalCell_Carrier-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_NodeBFunction_RbsLocalCell_Carrier',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_NodeBFunction_RbsLocalCell_Carrier set

# START: ME_RNC_IubLink set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_RNC_IubLink',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_RNC_IubLink',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmDlCredits|pmTnAdmUsedBandwidthDl|pmTnAdmUsedBandwidthUl|pmUlCredits)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmDlCredits_0 pmDlCredits_1 pmDlCredits_2 pmDlCredits_3 pmDlCredits_4 pmDlCredits_5 pmDlCredits_6 pmDlCredits_7
        pmDlCredits_8 pmDlCredits_9
        pmTnAdmUsedBandwidthDl_0 pmTnAdmUsedBandwidthDl_1 pmTnAdmUsedBandwidthDl_2 pmTnAdmUsedBandwidthDl_3
        pmTnAdmUsedBandwidthDl_4 pmTnAdmUsedBandwidthDl_5 pmTnAdmUsedBandwidthDl_6
        pmTnAdmUsedBandwidthUl_0 pmTnAdmUsedBandwidthUl_1 pmTnAdmUsedBandwidthUl_2 pmTnAdmUsedBandwidthUl_3
        pmTnAdmUsedBandwidthUl_4 pmTnAdmUsedBandwidthUl_5 pmTnAdmUsedBandwidthUl_6
        pmUlCredits_0 pmUlCredits_1 pmUlCredits_2 pmUlCredits_3 pmUlCredits_4 pmUlCredits_5 pmUlCredits_6 pmUlCredits_7
        pmUlCredits_8 pmUlCredits_9
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_RNC_IubLink',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmDlCredits|pmTnAdmUsedBandwidthDl|pmTnAdmUsedBandwidthUl|pmUlCredits)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_IubLink',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_RNC_IubLink',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_RNC_IubLink',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_RNC_IubLink set

# START: ME_RNC_IubLink_IubEdch set - BG
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for ME_RNC_IubLink_IubEdch',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink_IubEdch-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_RNC_IubLink_IubEdch',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmEdchDataFrameDelayIub)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmEdchDataFrameDelayIub_0 pmEdchDataFrameDelayIub_1 pmEdchDataFrameDelayIub_2 pmEdchDataFrameDelayIub_3
        pmEdchDataFrameDelayIub_4 pmEdchDataFrameDelayIub_5 pmEdchDataFrameDelayIub_6 pmEdchDataFrameDelayIub_7
        pmEdchDataFrameDelayIub_8 pmEdchDataFrameDelayIub_9 pmEdchDataFrameDelayIub_10 pmEdchDataFrameDelayIub_11
        pmEdchDataFrameDelayIub_12 pmEdchDataFrameDelayIub_13 pmEdchDataFrameDelayIub_14 pmEdchDataFrameDelayIub_15
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from ME_RNC_IubLink_IubEdch',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink_IubEdch-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmEdchDataFrameDelayIub)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_IubLink',
        'moid_IubEdch',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for ME_RNC_IubLink_IubEdch',
    INPUT_FILE_DESCRIPTION     => '^ME_RNC_IubLink_IubEdch-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'ME_RNC_IubLink_IubEdch',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: ME_RNC_IubLink_IubEdch set

# START: NodeB_DLBasebandPool set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for NodeB_DLBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_DLBasebandPool-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'NodeB_DLBasebandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmCapacityDlCe|pmUsedADch)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmCapacityDlCe_0 pmCapacityDlCe_1 pmCapacityDlCe_2 pmCapacityDlCe_3 pmCapacityDlCe_4 pmCapacityDlCe_5
        pmCapacityDlCe_6 pmCapacityDlCe_7 pmCapacityDlCe_8 pmCapacityDlCe_9 pmCapacityDlCe_10
        pmUsedADch_0 pmUsedADch_1 pmUsedADch_2 pmUsedADch_3 pmUsedADch_4 pmUsedADch_5 pmUsedADch_6
        pmUsedADch_7 pmUsedADch_8 pmUsedADch_9 pmUsedADch_10
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from NodeB_DLBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_DLBasebandPool-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmCapacityDlCe|pmUsedADch)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Equipment', 'moid_Subrack', 'moid_DownlinkBaseBandPool',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for NodeB_DLBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_DLBasebandPool-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'NodeB_DLBasebandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: NodeB_DLBasebandPool set

# START: NodeB_ULBasebandPool set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for NodeB_ULBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_ULBasebandPool-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'NodeB_ULBasebandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmHwCePoolEul)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmHwCePoolEul_0 pmHwCePoolEul_1 pmHwCePoolEul_2 pmHwCePoolEul_3 pmHwCePoolEul_4 pmHwCePoolEul_5 pmHwCePoolEul_6
        pmHwCePoolEul_7 pmHwCePoolEul_8 pmHwCePoolEul_9 pmHwCePoolEul_10 pmHwCePoolEul_11 pmHwCePoolEul_12 pmHwCePoolEul_13
        pmHwCePoolEul_14 pmHwCePoolEul_15 pmHwCePoolEul_16 pmHwCePoolEul_17 pmHwCePoolEul_18 pmHwCePoolEul_19 pmHwCePoolEul_20
        pmHwCePoolEul_21 pmHwCePoolEul_22 pmHwCePoolEul_23 pmHwCePoolEul_24 pmHwCePoolEul_25 pmHwCePoolEul_26 pmHwCePoolEul_27
        pmHwCePoolEul_28 pmHwCePoolEul_29 pmHwCePoolEul_30 pmHwCePoolEul_31 pmHwCePoolEul_32 pmHwCePoolEul_33 pmHwCePoolEul_34
        pmHwCePoolEul_35 pmHwCePoolEul_36 pmHwCePoolEul_37 pmHwCePoolEul_38 pmHwCePoolEul_39 pmHwCePoolEul_40 pmHwCePoolEul_41
        pmHwCePoolEul_42 pmHwCePoolEul_43 pmHwCePoolEul_44 pmHwCePoolEul_45 pmHwCePoolEul_46 pmHwCePoolEul_47 pmHwCePoolEul_48
        pmHwCePoolEul_49 pmHwCePoolEul_50 pmHwCePoolEul_51 pmHwCePoolEul_52 pmHwCePoolEul_53 pmHwCePoolEul_54 pmHwCePoolEul_55
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from NodeB_ULBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_ULBasebandPool-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmHwCePoolEul)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'nedn_MeContext',
        'moid_Equipment', 'moid_Subrack', 'moid_UplinkBaseBandPool',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for NodeB_ULBasebandPool',
    INPUT_FILE_DESCRIPTION     => '^NodeB_ULBasebandPool-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'NodeB_ULBasebandPool',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: NodeB_ULBasebandPool set

# START: RNC_PIU_GeneralProcessorUnit_LoadControl set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for RNC_PIU_GeneralProcessorUnit_LoadControl',
    INPUT_FILE_DESCRIPTION     => '^RNC_PIU_GeneralProcessorUnit_LoadControl-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_PIU_GeneralProcessorUnit_LoadControl',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmMeasuredLoad)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmMeasuredLoad_0 pmMeasuredLoad_1 pmMeasuredLoad_2 pmMeasuredLoad_3
        pmMeasuredLoad_4 pmMeasuredLoad_5 pmMeasuredLoad_6 pmMeasuredLoad_7
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from RNC_PIU_GeneralProcessorUnit_LoadControl',
    INPUT_FILE_DESCRIPTION     => '^RNC_PIU_GeneralProcessorUnit_LoadControl-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmMeasuredLoad)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_Equipment',
        'moid_Subrack', 'moid_Slot', 'moid_PlugInUnit',
        'moid_GeneralProcessorUnit', 'moid_LoadControl',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for RNC_PIU_GeneralProcessorUnit_LoadControl',
    INPUT_FILE_DESCRIPTION     => '^RNC_PIU_GeneralProcessorUnit_LoadControl-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_PIU_GeneralProcessorUnit_LoadControl',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: RNC_PIU_GeneralProcessorUnit_LoadControl set

# START: RNC_SwitchFabric_InternalLinkGroup set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for RNC_SwitchFabric_InternalLinkGroup',
    INPUT_FILE_DESCRIPTION     => '^RNC_SwitchFabric_InternalLinkGroup-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_SwitchFabric_InternalLinkGroup',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmPeakBwLevel)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmPeakBwLevel_0 pmPeakBwLevel_1 pmPeakBwLevel_2 pmPeakBwLevel_3
        pmPeakBwLevel_4 pmPeakBwLevel_5 pmPeakBwLevel_6 pmPeakBwLevel_7
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from RNC_SwitchFabric_InternalLinkGroup',
    INPUT_FILE_DESCRIPTION     => '^RNC_SwitchFabric_InternalLinkGroup-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmPeakBwLevel)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_SwitchFabric',
        'moid_InternalLinkGroup',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for RNC_SwitchFabric_InternalLinkGroup',
    INPUT_FILE_DESCRIPTION     => '^RNC_SwitchFabric_InternalLinkGroup-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_SwitchFabric_InternalLinkGroup',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: RNC_SwitchFabric_InternalLinkGroup set

# START: RNC_Virtual_Channel_Link set
{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PM counters to LIF for RNC_Virtual_Channel_Link',
    INPUT_FILE_DESCRIPTION     => '^RNC_Virtual_Channel_Link-#-.+-#-I\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_Virtual_Channel_Link',
    OUTPUT_FORMAT              => 'LIF_Writer',
    # REDUNDANT_DATA_COUNTERS doesn't take general expressions. Specify the entire list of redundant PDF counters to be removed.
    #REDUNDANT_DATA_COUNTERS    => [ '^(pmBwUtilizationRx|pmBwUtilizationTx)_\d+$' ],
    REDUNDANT_DATA_COUNTERS    => [ qw (
        pmBwUtilizationRx_0 pmBwUtilizationRx_1 pmBwUtilizationRx_2 pmBwUtilizationRx_3 pmBwUtilizationRx_4
        pmBwUtilizationRx_5 pmBwUtilizationRx_6 pmBwUtilizationRx_7 pmBwUtilizationRx_8 pmBwUtilizationRx_9
        pmBwUtilizationRx_10 pmBwUtilizationRx_11 pmBwUtilizationRx_12 pmBwUtilizationRx_13 pmBwUtilizationRx_14
        pmBwUtilizationRx_15 pmBwUtilizationRx_16 pmBwUtilizationRx_17 pmBwUtilizationRx_18 pmBwUtilizationRx_19
        pmBwUtilizationRx_20
        pmBwUtilizationTx_0 pmBwUtilizationTx_1 pmBwUtilizationTx_2 pmBwUtilizationTx_3 pmBwUtilizationTx_4
        pmBwUtilizationTx_5 pmBwUtilizationTx_6 pmBwUtilizationTx_7 pmBwUtilizationTx_8 pmBwUtilizationTx_9
        pmBwUtilizationTx_10 pmBwUtilizationTx_11 pmBwUtilizationTx_12 pmBwUtilizationTx_13 pmBwUtilizationTx_14
        pmBwUtilizationTx_15 pmBwUtilizationTx_16 pmBwUtilizationTx_17 pmBwUtilizationTx_18 pmBwUtilizationTx_19
        pmBwUtilizationTx_20
    ) ],
},

{
    RULE_TYPE                  => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                  => 'Split PDF counters from RNC_Virtual_Channel_Link',
    INPUT_FILE_DESCRIPTION     => '^RNC_Virtual_Channel_Link-#-.+-#-I\.pif$',
    SPLIT_CNAMES               => {
        'PDF'  => [ '^(pmBwUtilizationRx|pmBwUtilizationTx)_\d+$', ],
    },
    ONLY_INSERT                => [
        'moid_ManagedElement', 'nedn_SubNetwork', 'moid_AtmPort', 'moid_VplTp',
        'moid_VpcTp', 'moid_VclTp',
    ],
    PRODUCE_PIF                => 'True',
    PRODUCE_LIF                => 0,
},

{
    RULE_TYPE                  => 'PIF_2_OUTPUT',
    RULE_DESC                  => 'Output PDF counters to LIF for RNC_Virtual_Channel_Link',
    INPUT_FILE_DESCRIPTION     => '^RNC_Virtual_Channel_Link-#-.+-#-I-#-PDF-#-FSC\.pif',
    OUTPUT_BLOCK_NAME          => 'RNC_Virtual_Channel_Link',
    OUTPUT_FORMAT              => 'LIF_Writer',
},
# END: RNC_Virtual_Channel_Link set

# Remove initial PDF PIFs that have been split
{
    RULE_TYPE               => 'PIF_REMOVE',
    RULE_DESC               => 'Remove batched PIF files',
    INPUT_FILE_DESCRIPTION  => [
                                '^ManagedElement-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ManagedElement_RncCapacity-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ManagedElement_RncFunction_IurLink-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ManagedElement_RncFunction_UtranCell_Hsdsch-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ManagedElement_RncFunction_UtranCell_Hsdsch_Eul-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ME_Eqpt_Subrack_UplinkBaseBandPool-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ME_NodeBFunction_Carrier_RadioLinks-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ME_RNC_IubLink-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^ME_RNC_IubLink_IubEdch-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^NodeB_DLBasebandPool-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^NodeB_ULBasebandPool-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^RNC_PIU_GeneralProcessorUnit_LoadControl-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^RNC_SwitchFabric_InternalLinkGroup-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                '^RNC_Virtual_Channel_Link-#-.+-#-(I|I-#-PDF-#-FSC)\.pif',
                                ],
},
# END: PDF Splitting from initial PIFs

# Remove batched PIF files
{
    RULE_TYPE               => 'PIF_REMOVE',
    RULE_DESC               => 'Remove batched PIF files',
    INPUT_FILE_DESCRIPTION  => [
                                #'^(UNPEG-#-NODEB_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-RXI_ATM_Physical_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NODEB_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(RXI_Virtual_Channel_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NODEB_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(RXI_Virtual_Path_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NodeB_DLBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NodeB_DLBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I-#-Group_ManagedElement-#-A\.pif$',
                                '^(ME_NodeBFunction_IubDataStreams)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                '^(ME_NodeBFunction_IubDataStreams)-#-.+-#-.+-#-.+-#-.+-#-(J|J-#-PDF-#-FSC)\.pif$',
                                #'^(ME_NodeBFunction_RbsLocalCell_Carrier)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NodeB_ULBasebandPool)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NODEB_AAL2_AP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                #'^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-J-#-TOT\.pif$',
                                '^(ME_NodeBFunction_HsDschResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                '^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-I-#-S\.pif$', # P7.1 FP1
                                '^(ME_NodeBFunction_HsDschResources)-#-.+-#-.+-#-.+-#-.+-#-I-#-S-#-(TOT|TOT-#-PDF-#-FSC)\.pif$', # P7.1 FP1
                                #'^(ManagedElement_NodeBFunction_Sector_Carrier_Aich)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Sector_Carrier_Aich-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S)\.pif$',
                                #'^(ME_NodeBFunction_Sector_Carrier_EDchResources)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_EDchResources-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S|I-#-S-#-PDF-#-FSC)\.pif$',
                                #'^(ME_NodeBFunction_Sector_Carrier_Prach)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ME_NodeBFunction_Sector_Carrier_Prach-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S|I-#-S-#-PDF-#-FSC)\.pif$',
                                #'^(ManagedElement_NodeBFunction_Carrier_Sccpch)-#-.+-#-.+-#-.+-#-.+-#-J\.pif$',
                                '^(ManagedElement_NodeBFunction_Carrier_Sccpch-#-.+-#-.+-#-.+-#-.+-#)-(I|I-#-S|I-#-S-#-PDF-#-FSC)\.pif$',
                                '^(NODEB_AAL2_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_AAL2_SP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(NODEB_E1_T1_J1_PHYSICAL_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IMA_GROUP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IMA_LINK)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_Virtual_Path_Connection)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_UniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IP_ATM_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_ManagedElement_IpSystem_Ip_IpAtmLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_ManagedElement_IpOam_Ip_IpAtmLink)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IP_Link)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IpSystem_IpAccessHostGpb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_IpSystem_IpAccessUdpHostMsb)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_Mtp2tpItu)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_NniSAalTp_Signaling)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_Ospf)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_OspfArea)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_OspfInterface)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(UNPEG-#-NODEB_SCTP)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(ME_NodeBFunction_Carrier_RadioLinks)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(ME_NodeBFunction_NbapCommon)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                #'^(ManagedElement_NodeBFunction_Iub)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
                                ],
},

## 7 Aug 2008, LX, VN P6
{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join ',
    INPUT_FILE_DESCRIPTION  => [
    	## valnt00054766 - 25 Sept 2008, LX
    	## Remove in valnt00054766, '^ManagedElement_RncFunction_UtranCell-#-.+-(RNC\d+-#-\d{14}Z)-#-.*-#-A\.pif$',
    	'^ManagedElement_RncFunction_UtranCell_GsmRelation-#-.+-#-(RNC\d+-#-\d{14}Z)-#-\d+-#-I\.pif$',
    ],
    COUNTERS_TO_JOIN_ON    => [ qw(moid_UtranCell moid_GsmRelation nedn_SubNetwork) ], ## valnt00054766 - adding in moid_GsmRelation nedn_SubNetwork
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_UtranCell_GsmRelation_GRP',
    OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_UtranCell_GsmRelation_GRP',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
    PRODUCE_PIF            => 'True',
},

{
    RULE_TYPE                  => 'PIF_REMOVE',
    RULE_DESC                  => 'Remove ManagedElement_RncFunction_UtranCell_GsmRelation initial pif',
    INPUT_FILE_DESCRIPTION  => [
        '^(ManagedElement_RncFunction_UtranCell_GsmRelation)-#-.+-#-.+-#-.+-#-.+-#-I\.pif$',
    ],
},

{
	RULE_TYPE => 'ACCUMULATE',
	RULE_DESC => 'Accumulate all counters for block ManagedElement_RncFunction_UtranCell_GsmRelation with key moid_UtranCell',
	INPUT_FILE_DESCRIPTION => ['^ManagedElement_RncFunction_UtranCell_GsmRelation_GRP-#-.*-#-J\.pif$'],
	COUNTERS_TO_SORT_ON => [qw(moid_UtranCell)],
	OUTPUT_BLOCK_NAME => 'ManagedElement_RncFunction_UtranCell_GsmRelation_GRP',
	PRODUCE_PIF => 0,
	OUTPUT_FORMAT => 'LIF_Writer',
},

{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join ',
    INPUT_FILE_DESCRIPTION  => [
    	'^ME_RNC_UtranCell_MbmsCch-#-.+-#-I\.pif$',
    ],
    COUNTERS_TO_JOIN_ON    => [ qw(moid_UtranCell nedn_SubNetwork) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_BLOCK_NAME      => 'ME_RNC_UtranCell_MBMS',
    OUTPUT_FILENAME_START  => 'ME_RNC_UtranCell_MBMS',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_SubNetwork','mts','moid_UtranCell'],
    PRODUCE_PIF            => 'True',
},

{
	RULE_TYPE => 'ACCUMULATE',
	RULE_DESC => 'Accumulate all counters for block ME_RNC_UtranCell_MBMS with key moid_UtranCell',
	INPUT_FILE_DESCRIPTION => ['^ME_RNC_UtranCell_MBMS-#-.*-#-J\.pif$'],
	COUNTERS_TO_SORT_ON => [qw(moid_UtranCell)],
	OUTPUT_BLOCK_NAME => 'ME_RNC_UtranCell_MBMS',
	PRODUCE_PIF => 0,
	OUTPUT_FORMAT => 'LIF_Writer',
},

{
    RULE_TYPE              => 'JOIN',
    RULE_DESC              => 'Join ',
    INPUT_FILE_DESCRIPTION  => [
    	'^ManagedElement_RncFunction_UtranCell-#-.+-(RNC\d+-#-\d{14}Z)-#-.*-#-A\.pif$',
    	'^ManagedElement_RncFunction_Paging-#-.+-#-(RNC\d+-#-\d{14}Z)-#-\d+-#-I\.pif$',
    ],
    COUNTERS_TO_JOIN_ON    => [ qw(nedn_SubNetwork) ],
    HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    OUTPUT_BLOCK_NAME      => 'ManagedElement_RncFunction_Paging',
    OUTPUT_FILENAME_START  => 'ManagedElement_RncFunction_Paging',
    HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['nedn_MeContext','nedn_SubNetwork','mts'],
    PRODUCE_PIF            => 0,
    OUTPUT_FORMAT           => 'LIF_Writer',
},
## end of VN

{
    RULE_TYPE                  => 'PIF_REMOVE',
    RULE_DESC                  => 'Remove Paging pif',
    INPUT_FILE_DESCRIPTION  => [
        '^ManagedElement_RncFunction_Paging-#-.+-#-(RNC\d+-#-\d{14}Z)-#-\d+-#-I\.pif$',
    ],
},

# Output all initial PIFs
{
    RULE_TYPE               => 'PIF_2_OUTPUT',
    RULE_DESC               => 'Output all unprocessed initial PIF files',
    INPUT_FILE_DESCRIPTION  => '^(?!SAVED-#-?).+-#-I\.pif$',
    PRODUCE_PIF             => 0,
    OUTPUT_FORMAT           => 'LIF_Writer',
},

);

#------------------------------------------------------------------------------------------------

sub postparser_config {
    return \@rules;
}

1;

